
%% [MATLAB GUI] Initial code 
function varargout = UDIR(varargin)

% UDIR reads *.dir file generated by UVIEW, automatically calculates component 
% directions using selectable demagnetization range(s) with anchored or free 
% origin, and displays Zijderveld plots and stepwise intensity plots for any 
% position. UDIR can also display data on equal area stereographic projections 
% and draw virtual geomagnetic poles (VGPs) on various map projections. 

% Last Modified by Chuang Xuan 20-Apr-2009 10:57:28

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @UDIR_OpeningFcn, ...
                   'gui_OutputFcn',  @UDIR_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


%% [MATLAB GUI] Opening Function
function UDIR_OpeningFcn(hObject, eventdata, handles, varargin)

handles.Columns2g = [1,2,5,6,7,8,9,10,11];
handles.FormatString2g = '%f %f %s %f %f %f %f %f %f %f %f %f %f';

% Column numbers of parameters in the *.dir file that will be used in
% the analysis. Above is the default convension of files generated by this
% software. This matrix need to be defined (using the text file) if a 
% different *.dir convension is used. 

% Default *.dir file format
% ---------	  -------------
% Parameter	  Column Number
% ---------	  -------------
% Position	  1
% Treat	      2
% IC	      3
% CD	      4
% J	          5
% CDECL	      6
% CINCL	      7
% GDECL	      8
% GINCL	      9
% BDECL	      10
% BINCL	      11
% SUSC	      12
% V/M	      13

% Initialize Axes

axes(handles.axes1),
   xlimit = get(gca,'xlim');
   ylimit = get(gca,'ylim');
   text((xlimit(2)+xlimit(1))./2,(ylimit(2)+ylimit(1))./2,...
       {'\fontsize{14}Zijderveld Plot'; 'OR'; '3D Plot'},...
       'HorizontalAlignment','center','BackgroundColor','w');
   set(gca,'XMinorTick','on');
   set(gca,'YMinorTick','on');
   set(gca,'XTickLabel','');  
   set(gca,'YTickLabel',''); 
   set(gca,'Ticklength',[0.015;0.04]);
   box on;
axes(handles.axes2),
   xlimit = get(gca,'xlim');
   ylimit = get(gca,'ylim');
   text((xlimit(2)+xlimit(1))./2,(ylimit(2)+ylimit(1))./2,...
       {'\fontsize{14}Int vs Demag Plot'},...
       'HorizontalAlignment','center','BackgroundColor','w');
   set(gca,'XMinorTick','on');
   set(gca,'YMinorTick','on');
   set(gca,'XTickLabel','');  
   set(gca,'YTickLabel',''); 
   set(gca,'Ticklength',[0.02;0.05]);
   box on;
axes(handles.axes3),
   xlim([0 160]);
   xlimit = get(gca,'xlim');
   ylimit = get(gca,'ylim');
   text((xlimit(2)+xlimit(1))./2,(ylimit(2)+ylimit(1))./2,...
       {'\fontsize{14}Decl & Incl vs Position Plot'},...
       'HorizontalAlignment','center','BackgroundColor','w');
   set(gca,'XTick',0:20:160);
   set(gca,'XMinorTick','on');
   set(gca,'XTickLabel','');  
   set(gca,'YTickLabel',''); 
   set(gca,'YMinorTick','on');
   set(gca,'Ticklength',[0.015;0.04]);
   box on;
axes(handles.axes4),
   xlim([0 160]);
   xlimit = get(gca,'xlim');
   ylimit = get(gca,'ylim');
   text((xlimit(2)+xlimit(1))./2,(ylimit(2)+ylimit(1))./2,...
       {'\fontsize{14}MAD & Int vs Position Plot'},...
       'HorizontalAlignment','center','BackgroundColor','w');
    set(gca,'XTick',0:20:160); 
    set(gca,'YTickLabel',''); 
    set(gca,'XTickLabel','');  
    set(gca,'XMinorTick','on');
    set(gca,'YMinorTick','on');
    set(gca,'Ticklength',[0.015;0.04]);
    box on;
   
handles.output = hObject;
guidata(hObject, handles);

%% [MATLAB GUI] Outputs
function varargout = UDIR_OutputFcn(hObject, eventdata, handles) 

varargout{1} = handles.output;


%% [Push] Load *.dir file
function pushbutton3_Callback(hObject, eventdata, handles)

button = questdlg('Is the *.dir file in default UF format? ',...
                  '*.dir file format confirmation','Yes');
switch button
case 'Yes'
    % no command needed, pass to codes after 'return'
case 'No'
    % locate and read format values from format file
    [FileName,PathName] = uigetfile2({'*.txt'},'Locate Your *.dir Format File');
    if  ~isequal(FileName,0),
        file  = [PathName,FileName];
        fid = fopen(file);
        filestring = textscan(fid, '%s   %s','delimiter','\t','headerlines',31);
        fclose(fid); 
        handles.FormatString2g = filestring{2}{1};
        kkend = length(filestring{2})-1;
        Columns2g = zeros(kkend, 1);
        for kk = 1:kkend,
            Columns2g(kk) = str2num(filestring{2}{kk+1});
        end
        handles.Columns2g = Columns2g;
        button2 = questdlg('Your *.dir Format File has been loaded. Locate and load your *.dir File now?','Load *.dir File Confirmation','Yes');
        if ~strcmp(button2, 'Yes'), return; end;    
    else 
        msgbox('Operation cancelled by user, no *.dir file loaded.', '*.dir file loading confirmation','warn') ; return; 
    end
case 'Cancel'
    return; % abort loading *.dir files
end

[FileName,PathName] = uigetfile2({'*.dir';'*.2g'},'PICK A *.dir FILE');
if ~isequal(FileName,0), % continue only when file is selected by user
    fid                 = fopen([PathName,FileName]);
    filedata            = textscan(fid, handles.FormatString2g,'headerlines', 5);
    fclose(fid);

    handles.filedata         = filedata;
    handles.PathName         = PathName;
    handles.SampleID         = strtok(FileName,'.');
    handles.Positions        = filedata{handles.Columns2g(1)};
    handles.UniquePositions  = unique(handles.Positions);
    handles.DemagSteps       = filedata{handles.Columns2g(2)};
    handles.UniqueDemagSteps = unique(handles.DemagSteps);
    handles.Intensity        = filedata{handles.Columns2g(3)};
    handles.decl             = filedata{handles.Columns2g(8)};
    handles.incl             = filedata{handles.Columns2g(9)};
    
    % Default coordinate is bedding corrected (column 8 and 9 in handles.Colums2g)
    handles.East             = handles.Intensity.*cosd(filedata{handles.Columns2g(9)}).*sind(filedata{handles.Columns2g(8)});
    handles.North            = handles.Intensity.*cosd(filedata{handles.Columns2g(9)}).*cosd(filedata{handles.Columns2g(8)});
    handles.Vertical         = handles.Intensity.*sind(filedata{handles.Columns2g(9)});
    set(handles.radiobutton6,'Value',get(handles.radiobutton6,'Max'));
    set(handles.radiobutton8,'Value',get(handles.radiobutton8,'Max'));
    
    handles.grid  = 0; 
    handles.holdon = 0;
    handles.titleon = 0;
    handles.Dimension       = 2;
    handles.AutoRot         = 0;
    handles.WestUp          = 0;
    handles.AnchorOrigin    = 0;
    handles.vgpSiteLat      = 999;
    handles.OptimumPCA      = zeros(length(handles.UniquePositions),7); % record optimum PCA values determined position by position
    handles.OptimumPCA(:,1) = handles.UniquePositions; 
    handles.UniformPCA      = zeros(length(handles.UniquePositions),4); 
    handles.UniformPCA(:,1) = handles.UniquePositions; 
    handles.H33 = 0; handles.H34 = 0; handles.H43 = 0; handles.H44 = 0;

    handles.PositionIndexNow = 1;
    handles.CurrentPosition  = handles.UniquePositions(handles.PositionIndexNow);
    handles.CurrentIndexes   = find(handles.Positions == handles.CurrentPosition); % Assumes Positions are Numeric
    handles.DemagStart4Plot  = handles.DemagSteps(handles.CurrentIndexes(1));      % Assumes that *.dir file were sorted ascending first by Position then by demag steps 
    handles.DemagEnd4Plot    = handles.DemagSteps(handles.CurrentIndexes(end));
    
    if length(handles.CurrentIndexes) < 5,
       handles.DemagStart4PCA   = handles.DemagSteps(handles.CurrentIndexes(1));
       handles.DemagEnd4PCA     = handles.DemagSteps(handles.CurrentIndexes(end));
       handles.IntPlotDemag     = ceil(length(handles.CurrentIndexes)./2);
    else 
       handles.DemagStart4PCA   = handles.DemagSteps(handles.CurrentIndexes(2)); % if >= dmage steps done for this position, PCA calculating start from 2nd demag step
       handles.DemagEnd4PCA     = handles.DemagSteps(handles.CurrentIndexes(end-1));
       handles.IntPlotDemag     = 5;
    end
    
    handles.IntPlot = handles.Intensity(handles.DemagSteps == handles.UniqueDemagSteps(handles.IntPlotDemag)); 

    handles.HoldZplotAxesNorthUp = [min(handles.East) max(handles.East) min([handles.North; -handles.Vertical]) max([handles.North; -handles.Vertical])];
    handles.HoldZplotAxesWestUp  = [min(handles.North) max(handles.North) min([-handles.East; -handles.Vertical]) max([-handles.East; -handles.Vertical])];
    handles.Hold3dAxes           = [min(handles.East) max(handles.East) min(handles.North) max(handles.North) min(-handles.Vertical) max(-handles.Vertical)];

    guidata(hObject,handles);

    % UDIR Assumes that all positions have the same demag steps, which is generally
    % true for U channel samples. The fact that demag steps may be different for different
    % samples need to be considered when develope software for discrete sample data.
    
    set(handles.popupmenu_PlotDemagBegin,'String',num2str(handles.UniqueDemagSteps));
    set(handles.popupmenu_PlotDemagBegin,'Value',1);    
    set(handles.popupmenu_PlotDemagEnd,'String',num2str(handles.UniqueDemagSteps));
    set(handles.popupmenu_PlotDemagEnd,'Value',length(handles.CurrentIndexes));  
    
    set(handles.popupmenu_PcaDemagBegin,'String',num2str(handles.UniqueDemagSteps));
    set(handles.popupmenu_PcaDemagBegin,'Value',find(handles.UniqueDemagSteps == handles.DemagStart4PCA));    
    set(handles.popupmenu_PcaDemagEnd,'String',num2str(handles.UniqueDemagSteps));
    set(handles.popupmenu_PcaDemagEnd,'Value',find(handles.UniqueDemagSteps == handles.DemagEnd4PCA)); 
      
    set(handles.edit1,'String',FileName);
    set(handles.edit27,'String',num2str(length(handles.UniquePositions)));
    set(handles.edit30,'String','No Data/Plots Exported.');
    
    cla(handles.axes5);    
    cla(handles.axes6);
    cla(handles.axes7);

    set(handles.axes5, 'Visible','off');
    set(handles.axes6, 'Visible','off');
    set(handles.axes7, 'Visible','off');
    [hObject, eventdata, handles] = Update_UniformPCA(hObject, eventdata, handles);
    [hObject, eventdata, handles] = Update_PCAplots(hObject, eventdata, handles);
    [hObject, eventdata, handles] = Update_PositionRelated(hObject, eventdata, handles);
    guidata(hObject,handles);
    
else 
    msgbox('Operation cancelled by user, no *.dir file loaded.', '*.dir file loading confirmation','warn') ;  
end

  
%% [Push] Next Position
function pushbutton4_Callback(hObject, eventdata, handles)

handles.PositionIndexNow = handles.PositionIndexNow + 1;

if handles.PositionIndexNow <= length(handles.UniquePositions),
   [hObject, eventdata, handles] = Update_PositionRelated(hObject, eventdata, handles);
else
   handles.PositionIndexNow = handles.PositionIndexNow - 1;
   set(handles.edit2,'String','Reach End');         
end

guidata(hObject,handles);


%% [Push] Previous Position
function pushbutton7_Callback(hObject, eventdata, handles)

handles.PositionIndexNow = handles.PositionIndexNow - 1;

if handles.PositionIndexNow >= 1,
   [hObject, eventdata, handles] = Update_PositionRelated(hObject, eventdata, handles);
else
   handles.PositionIndexNow = handles.PositionIndexNow + 1;
   set(handles.edit2,'String','Reach Start');         
end

guidata(hObject,handles);


%% [Push] Go to Position
function pushbutton28_Callback(hObject, eventdata, handles)

previousindex = handles.PositionIndexNow;

InputPosition = str2double(get(handles.edit4,'String'));
handles.PositionIndexNow = find(handles.UniquePositions == InputPosition);

if ~isempty(handles.PositionIndexNow),
   [hObject, eventdata, handles] = Update_PositionRelated(hObject, eventdata, handles);
else
   handles.PositionIndexNow = previousindex;
   set(handles.edit2,'String','Not valid');         
end

guidata(hObject,handles);


%% [Push] Update plots
function pushbutton27_Callback(hObject, eventdata, handles)

handles.DemagStart4Plot = handles.UniqueDemagSteps(get(handles.popupmenu_PlotDemagBegin,'Value'));
handles.DemagEnd4Plot   = handles.UniqueDemagSteps(get(handles.popupmenu_PlotDemagEnd,'Value'));
if handles.DemagStart4Plot > handles.DemagEnd4Plot,
   msgbox('Wrong Demag Range Selected. Plese Try Again', 'Wrong Demag Range Error','error') ;  return;
end
Update_zdplots(hObject, eventdata, handles);
Update_IntDemagPlot(hObject, eventdata, handles);

guidata(hObject,handles);


%% [Push] Update PCA
function pushbutton26_Callback(hObject, eventdata, handles)

[hObject, eventdata, handles] = Update_UniformPCA(hObject, eventdata, handles);
Update_PCAboxes(hObject, eventdata, handles);
[hObject, eventdata, handles] = Update_PCAplots(hObject, eventdata, handles);
guidata(hObject,handles);


%% [Push] Uniform PCA export
function pushbutton33_Callback(hObject, eventdata, handles)

Uniformoutput = [handles.UniformPCA,...
                 handles.DemagStart4PCA.*ones(size(handles.UniformPCA(:,1))),...
                 handles.DemagEnd4PCA.*ones(size(handles.UniformPCA(:,1))),...
                 handles.AnchorOrigin.*ones(size(handles.UniformPCA(:,1)))];

fid = fopen([handles.PathName,'PCA - ',handles.SampleID,' (',num2str(handles.UniqueDemagSteps(get(handles.popupmenu_PcaDemagBegin,'Value'))),...
             '-',num2str(handles.UniqueDemagSteps(get(handles.popupmenu_PcaDemagEnd,'Value'))),').txt'], 'wt');
fprintf(fid, 'Sample_ID	Position(cm)	Decl	Incl	MAD	Demag_Start	Demag_End	Anchor_Origin\n');
fprintf(fid, [handles.SampleID, '	%6.1f	%6.2f	%6.2f	%6.2f	%6.0f	%6.0f	%6.0f\n'], Uniformoutput');
fclose(fid);
set(handles.edit30,'String','Uniform PCA exported');  
msgbox(['PCA values calculated using a uniform demag range between ', num2str(handles.UniqueDemagSteps(get(handles.popupmenu_PcaDemagBegin,'Value'))),...
        ' and ',num2str(handles.UniqueDemagSteps(get(handles.popupmenu_PcaDemagEnd,'Value'))),...
        ' have been exported to file: ', '''PCA-',handles.SampleID,' (',num2str(handles.UniqueDemagSteps(get(handles.popupmenu_PcaDemagBegin,'Value'))),...
        '-',num2str(handles.UniqueDemagSteps(get(handles.popupmenu_PcaDemagEnd,'Value'))),').txt.'''],...
        'Uniform PCA values export confirmation','help');


%% [Push] Optimum PCA export
function pushbutton31_Callback(hObject, eventdata, handles)

CurrentPCA = find(handles.UniformPCA(:,1) == handles.UniquePositions(handles.PositionIndexNow));
optpca = [handles.UniformPCA(CurrentPCA,1:4),handles.DemagStart4PCA,handles.DemagEnd4PCA,handles.AnchorOrigin];

filePathName = [handles.PathName,'OPT PCA - ',handles.SampleID,'.txt'];
if fopen(filePathName)==-1,
   fid = fopen(filePathName,'at');
   fprintf(fid, 'Sample_ID	Position(cm)	Opt_Decl	Opt_Incl	Opt_MAD	Demag_Start	Demag_Ends	Anchor_Origin\n');
   fclose(fid);
   msgbox(['File: ','''OPT PCA - ',handles.SampleID,'.txt''', ' has been created for saving Opt. PCA values of sample: ''', handles.SampleID,''''],...
           'Uniform PCA values export confirmation','help');
end
   
fid = fopen(filePathName, 'at'); % 'a' here means append, 't' means text mode
fprintf(fid, [handles.SampleID, '	%6.1f	%6.2f	%6.2f	%6.2f	%6.0f	%6.0f	%6.0f\n'], optpca');
fclose(fid);

set(handles.edit30,'String',['Opt_PCA @ ',num2str(handles.CurrentPosition),' cm added!']);  


%% [Push] Export VGP Data
function pushbutton47_Callback(hObject, eventdata, handles)

if  handles.vgpSiteLat == 999,
    button = questdlg('VGP data has not been calculated yet. Do you want to calculate now? ',...
                      'VGP Calculation Confirmation','Yes');
    switch button
    case 'Yes'
        set(handles.radiobutton9,'Value', 1);
        [hObject, eventdata, handles] = radiobutton9_Callback(hObject, eventdata, handles);
    case 'No'
        set(handles.edit30,'String','VGP data not exported.');  return;
    case 'Cancel'
        set(handles.edit30,'String','VGP data not exported.');  return;
    end
end
    
VGPoutput =     [handles.UniformPCA(:,1),...
                 handles.vgpSiteLat.*ones(size(handles.UniformPCA(:,1))),...
                 handles.vgpSiteLong.*ones(size(handles.UniformPCA(:,1))),...
                 handles.vgplat,...
                 handles.vgplong,...
                 handles.vgpDeclCorr.*ones(size(handles.UniformPCA(:,1)))];

fid = fopen([handles.PathName,'VGP - ',handles.SampleID,'.txt'], 'wt');
fprintf(fid, 'Sample_ID	Position(cm)	Site_Lat.	Site_Long.	VGP_Lat.	VGP_Long.	Dec.Corr.\n');
fprintf(fid, [handles.SampleID, '	%6.0f	%6.2f	%6.2f	%6.2f	%6.2f	%6.2f\n'], VGPoutput');
fclose(fid);
set(handles.edit30,'String','VGP data exported');  
msgbox(['VGP data has been exported to file: ', '''VGP -',handles.SampleID,'.txt.'''],...
        'VGP data export confirmation','help');

%% [Push] Save Figure(s)
function pushbutton23_Callback(hObject, eventdata, handles)

H = udir_SavePlotOption_dlg;
uiwait(H);

savePlotOptionUDIR = getappdata(0, 'savePlotOptionUDIR');
rmappdata(0, 'savePlotOptionUDIR');

switch savePlotOptionUDIR
    case 0    % cancelled, no data for saving
         return;
    case 1    
         plotstring = [num2str(handles.CurrentPosition),' DemagData.bmp'];
         h  = findobj(handles.axes1,'type','axes');
         xlimit = get(handles.axes1,'xlim');
         ylimit = get(handles.axes1,'ylim');        
    case 2    
         plotstring = [num2str(handles.CurrentPosition),' StepwiseInt.bmp'];
         h  = findobj(handles.axes2,'type','axes');   
         xlimit = get(handles.axes2,'xlim');
         ylimit = get(handles.axes2,'ylim');         
    case 3    
         plotstring = 'VGP.bmp';
         h  = findobj(handles.axes5,'type','axes');
         xlimit = get(handles.axes5,'xlim');
         ylimit = get(handles.axes5,'ylim');        
    case 4    
         plotstring = [num2str(handles.CurrentPosition),' EqualArea.bmp'];   
         h  = findobj(handles.axes7,'type','axes'); 
         xlimit = get(handles.axes7,'xlim');
         ylimit = get(handles.axes7,'ylim');         
    case 5    
         plotstring = 'EqualAreaAll.bmp';
         h  = findobj(handles.axes6,'type','axes');
         xlimit = get(handles.axes6,'xlim');
         ylimit = get(handles.axes6,'ylim');         
end

[filename, pathname, FilterIndex] =  uiputfile({  '*.bmp','Windows bitmap (*.bmp)';
                                    '*.fig','MATLAB figure (*.fig)';
                                    '*.eps','EPS Level2 (*.eps)';
                                    '*.tif','TIFF image (*.tif)';
                                    '*.png','Portable Network Graphics (*.png)';
                                    '*.ai','Adobe Illustrator (*.ai)';
                                    '*.jpg','JPEG image (*.jpg)';
                                    '*.pdf','Portable Document Format (*.pdf)';
                                    '*.emf','Enhanced metafile (*.emf)'},...
                                    'Save selected plot as',...
                                    [handles.PathName,handles.SampleID, ' ', plotstring]);

if  ~isequal(filename,0), 
    
    newFig = figure('Units', 'default', 'Position', 'default');
    newAxes = copyobj(h,newFig); 
    set(newAxes,'Units','default','Position','default');
    set(newAxes, 'xlim', xlimit);
    set(newAxes, 'ylim', ylimit);
    if FilterIndex == 3,
       saveas(newFig,[pathname,filename], 'psc2');
    else   
       saveas(newFig,[pathname,filename]);
    end

    close(newFig);
    set(handles.edit30,'String','Selected Plot Exported');  
    
end



%% [Toggle] Mouse control plot range
function togglebutton5_Callback(hObject, eventdata, handles)

if get(handles.togglebutton5,'Value') == get(handles.togglebutton5,'Max'),
    if ~(handles.Dimension == 2),
       return;%        set(handles.edit30,'String','Only function on 2D!');
    else
       rect = getrect(handles.axes1);      
       if handles.WestUp == 1,
          inclrange = find(rect(1) <= handles.North(handles.CurrentIndexes) & handles.North(handles.CurrentIndexes) <= rect(1) + rect(3) & ...
                           rect(2) <= -handles.Vertical(handles.CurrentIndexes) & -handles.Vertical(handles.CurrentIndexes) <= rect(2) + rect(4));
          declrange = find(rect(1) <= handles.North(handles.CurrentIndexes) & handles.North(handles.CurrentIndexes) <= rect(1) + rect(3) & ...
                           rect(2) <= -handles.East(handles.CurrentIndexes) & -handles.East(handles.CurrentIndexes) <= rect(2) + rect(4));  
       else
          inclrange = find(rect(1) <= handles.East(handles.CurrentIndexes) & handles.East(handles.CurrentIndexes) <= rect(1) + rect(3) & ...
                           rect(2) <= -handles.Vertical(handles.CurrentIndexes) & -handles.Vertical(handles.CurrentIndexes) <= rect(2) + rect(4));
          declrange = find(rect(1) <= handles.East(handles.CurrentIndexes) & handles.East(handles.CurrentIndexes) <= rect(1) + rect(3) & ...
                           rect(2) <= handles.North(handles.CurrentIndexes) & handles.North(handles.CurrentIndexes) <= rect(2) + rect(4));
       end      
       if length(inclrange) >= length(declrange),
          demagrange = inclrange;
       else demagrange = declrange;
       end
       demagsteps = handles.DemagSteps(handles.CurrentIndexes);
       handles.DemagStart4Plot = min(demagsteps(demagrange));
       handles.DemagEnd4Plot = max(demagsteps(demagrange));       
       set(handles.popupmenu_PlotDemagBegin,'Value',find(handles.UniqueDemagSteps == handles.DemagStart4Plot));
       set(handles.popupmenu_PlotDemagEnd,'Value',find(handles.UniqueDemagSteps == handles.DemagEnd4Plot));       
       Update_zdplots(hObject, eventdata, handles);
       Update_IntDemagPlot(hObject, eventdata, handles);
    end
    set(handles.togglebutton5,'Value',get(handles.togglebutton5,'Min'));
end

guidata(hObject,handles);


%% [Toggle] Mouse control PCA range
function togglebutton6_Callback(hObject, eventdata, handles)

if get(handles.togglebutton6,'Value') == get(handles.togglebutton6,'Max'),
    if ~(handles.Dimension == 2),
       return; %set(handles.edit30,'String','Only function on 2D!');
    else
       rect = getrect(handles.axes1);      
       if handles.WestUp == 1,
          inclrange = find(rect(1) <= handles.North(handles.CurrentIndexes) & handles.North(handles.CurrentIndexes) <= rect(1) + rect(3) & ...
                           rect(2) <= -handles.Vertical(handles.CurrentIndexes) & -handles.Vertical(handles.CurrentIndexes) <= rect(2) + rect(4));
          declrange = find(rect(1) <= handles.North(handles.CurrentIndexes) & handles.North(handles.CurrentIndexes) <= rect(1) + rect(3) & ...
                           rect(2) <= -handles.East(handles.CurrentIndexes) & -handles.East(handles.CurrentIndexes) <= rect(2) + rect(4));  
       else
          inclrange = find(rect(1) <= handles.East(handles.CurrentIndexes) & handles.East(handles.CurrentIndexes) <= rect(1) + rect(3) & ...
                           rect(2) <= -handles.Vertical(handles.CurrentIndexes) & -handles.Vertical(handles.CurrentIndexes) <= rect(2) + rect(4));
          declrange = find(rect(1) <= handles.East(handles.CurrentIndexes) & handles.East(handles.CurrentIndexes) <= rect(1) + rect(3) & ...
                           rect(2) <= handles.North(handles.CurrentIndexes) & handles.North(handles.CurrentIndexes) <= rect(2) + rect(4));
       end      
       if length(inclrange) >= length(declrange),
          demagrange = inclrange;
       else demagrange = declrange;
       end
       demagsteps = handles.DemagSteps(handles.CurrentIndexes);
       set(handles.popupmenu_PcaDemagBegin,'Value',find(handles.UniqueDemagSteps == min(demagsteps(demagrange))));
       set(handles.popupmenu_PcaDemagEnd,'Value',find(handles.UniqueDemagSteps == max(demagsteps(demagrange))));
       [hObject, eventdata, handles] = Update_UniformPCA(hObject, eventdata, handles);
       Update_PCAboxes(hObject, eventdata, handles);
       [hObject, eventdata, handles] = Update_PCAplots(hObject, eventdata, handles);
    end
    set(handles.togglebutton6,'Value',get(handles.togglebutton6,'Min'));
end

guidata(hObject,handles);


%% [Toggle] 3D/zijderveld switch
function togglebutton11_Callback(hObject, eventdata, handles)

if get(handles.togglebutton11,'Value') == get(handles.togglebutton11,'Max'),
   handles.Dimension = 3;
   Update_zdplots(hObject, eventdata, handles);
else
    handles.Dimension = 2;
    Update_zdplots(hObject, eventdata, handles);
end
guidata(hObject,handles);


%% [Toggle] West/up switch
function togglebutton9_Callback(hObject, eventdata, handles)

if ~(handles.Dimension == 2),
    return; %set(handles.edit30,'String','Works only on 2D!'); 
else 
    % set(handles.edit30,'String','Status Info: ok!'); 
    if get(handles.togglebutton9,'Value') == get(handles.togglebutton9,'Max'),
       handles.WestUp = 1;
       Update_zdplots(hObject, eventdata, handles);
    else    handles.WestUp = 0;
       Update_zdplots(hObject, eventdata, handles);
    end
end

guidata(hObject,handles);


%% [Toggle] Hold on/off plots
function togglebutton8_Callback(hObject, eventdata, handles)

button_state = get(handles.togglebutton8,'Value');
if button_state == get(handles.togglebutton8,'Max')
   handles.holdon = 1;
   axes(handles.axes1),
   hold on;
   axes(handles.axes2),
   hold on;
else
   handles.holdon = 0;
   axes(handles.axes1),
   hold off;
   axes(handles.axes2),
   hold off;
end
guidata(hObject,handles);   


%% [Toggle] Zoom on/off switch
function togglebutton2_Callback(hObject, eventdata, handles)

button_state = get(handles.togglebutton2,'Value');
if button_state == get(handles.togglebutton2,'Max')
   zoom on;
else
   zoom off;
end


%% [Toggle] Datacursor on/off switch
function togglebutton1_Callback(hObject, eventdata, handles)

button_state = get(handles.togglebutton1,'Value');
if button_state == get(handles.togglebutton1,'Max')
    datacursormode on;
else 
    datacursormode off;
end


%% [Toggle] Rotate on/off
function togglebutton12_Callback(hObject, eventdata, handles)

button_state = get(handles.togglebutton12,'Value');
if button_state == get(handles.togglebutton12,'Max')
    rotate3d on;
else
    rotate3d off;
end


%% [Toggle] Grid on/off;
function togglebutton17_Callback(hObject, eventdata, handles)


button_state = get(handles.togglebutton17,'Value');
if button_state == get(handles.togglebutton17,'Max')
    handles.grid  = 1;
    axes(handles.axes2),grid on;
    if strcmpi(get(handles.axes3, 'visible'),'on'),
       axes(handles.axes3),grid on;
       axes(handles.axes4),grid on;
    end
elseif button_state == get(handles.togglebutton17,'Min')
    handles.grid  = 0;    
    axes(handles.axes2),grid off;
    if strcmpi(get(handles.axes3, 'visible'),'on'),
       axes(handles.axes3),grid off;
       axes(handles.axes4),grid off;
    end
end

guidata(hObject, handles);


%% [Toggle] Title on/off
function togglebutton18_Callback(hObject, eventdata, handles)


button_state = get(handles.togglebutton18,'Value');
if button_state == get(handles.togglebutton18,'Max'),
   handles.titleon = 1;
   axes(handles.axes2),title([handles.SampleID, ' at position: ', num2str(handles.CurrentPosition)]);
else
    handles.titleon = 0;
   axes(handles.axes2),title('');
end

guidata(hObject, handles);


%% [Checkbox] Anchor origin option
function checkbox1_Callback(hObject, eventdata, handles)

if (get(handles.checkbox1,'Value') == get(handles.checkbox1,'Max')),
    handles.origindetector = 1;  
else
    handles.origindetector = 0; 
end

[hObject, eventdata, handles] = Update_UniformPCA(hObject, eventdata, handles);
Update_PCAboxes(hObject, eventdata, handles);
[hObject, eventdata, handles] = Update_PCAplots(hObject, eventdata, handles);
guidata(hObject,handles);


%% [Checkbox] Backward move option
function checkbox6_Callback(hObject, eventdata, handles)


%% [Function] zdplot
function zdplot(east, north, vertical, demagsteps, demagstar, demagend, westup)

% zdplot generates zijderveld plot for the given data within the specified
% demagnetization range;

% define demag range and scaling factor
demagrange = find(demagsteps >= demagstar & demagsteps <= demagend);

if length(demagrange) >  4, demaglabel = 1;
else demaglabel = 0;
end

if westup ==1, % West/Up Axes

    verticalscaling = 0.08*(max([-east(demagrange);-vertical(demagrange)])-min([-east(demagrange);-vertical(demagrange)])); % tick related
    horizontalscaling = 0.14*(max(north(demagrange))-min(north(demagrange))); % tick related
    % Horizontal Projection
    plot([north(demagrange);0], [-east(demagrange);0], 'b-','LineWidth',1); hold on;
    plot(north(demagrange), -east(demagrange), 'bs','MarkerFaceColor','w','MarkerSize',5); hold on;
    % Vertical Projection
    plot([north(demagrange);0],[-vertical(demagrange);0],'r-','LineWidth',1); hold on;
    plot(north(demagrange),-vertical(demagrange),'ro','MarkerFaceColor','w','MarkerSize',5); hold on;
    % label 2 demag steps
    text(north(demagrange(1+demaglabel)), -vertical(demagrange(1+demaglabel)),['  ',num2str(demagsteps(demagrange(1+demaglabel)))],'HorizontalAlignment','left','VerticalAlignment','Middle','FontSize',9);
    text(north(demagrange(end-demaglabel)), -vertical(demagrange(end-demaglabel)),['  ',num2str(demagsteps(demagrange(end-demaglabel)))],'HorizontalAlignment','left','VerticalAlignment','Middle','FontSize',9);    
    % add x axis  
    line([min([min(north(demagrange))-horizontalscaling;-horizontalscaling]) max([max(north(demagrange))+horizontalscaling;horizontalscaling])], [0 0],'LineWidth',0.5,'color',[0 0.5 0]);hold on
    text(max([max(north(demagrange))+horizontalscaling;horizontalscaling]),0,'   N','fontsize',9,'color',[0 0.5 0]); 
    text(min([min(north(demagrange))-horizontalscaling;-horizontalscaling]),0,'S   ','HorizontalAlignment','right','fontsize',9,'color',[0 0.5 0]); 
    plot([min([min(north(demagrange))-horizontalscaling;-horizontalscaling]) min([min(north(demagrange))-horizontalscaling;-horizontalscaling])],...
         [-0.35*verticalscaling 0.35*verticalscaling],'-','color',[0 0.5 0]);
    plot([max([max(north(demagrange))+horizontalscaling;horizontalscaling]) max([max(north(demagrange))+horizontalscaling;horizontalscaling])],...
         [-0.35*verticalscaling 0.35*verticalscaling],'-','color',[0 0.5 0]);
    % add y-axis
    line([0 0], [min([min([-east(demagrange);-vertical(demagrange);])-verticalscaling;-verticalscaling]) max([max([-east(demagrange);-vertical(demagrange)])+verticalscaling; verticalscaling])],'LineWidth',0.5,'color',[0 0.5 0]); hold on;
    text(0,max([max([-east(demagrange);-vertical(demagrange)])+verticalscaling; verticalscaling]),'W,Up','HorizontalAlignment','center','VerticalAlignment','Bottom','fontsize',9,'color',[0 0.5 0]); 
    text(0,min([min([-east(demagrange);-vertical(demagrange);])-verticalscaling;-verticalscaling]),'E,Down','HorizontalAlignment','center','VerticalAlignment','Top','fontsize',9,'color',[0 0.5 0]); 
    plot([-0.35*verticalscaling 0.35*verticalscaling],...
        [min([min([-east(demagrange);-vertical(demagrange);])-verticalscaling;-verticalscaling]) min([min([-east(demagrange);-vertical(demagrange);])-verticalscaling;-verticalscaling])],'-','color',[0 0.5 0]);
    plot([-0.35*verticalscaling 0.35*verticalscaling],...
        [max([max([-east(demagrange);-vertical(demagrange)])+verticalscaling; verticalscaling]) max([max([-east(demagrange);-vertical(demagrange)])+verticalscaling; verticalscaling])],'-','color',[0 0.5 0]);

else % North/Up Axes

    verticalscaling = 0.08*(max([north(demagrange);-vertical(demagrange)])-min([north(demagrange);-vertical(demagrange)])); % tick related
    horizontalscaling = 0.14*(max(east(demagrange))-min(east(demagrange))); % tick related
    % Horizontal Projection
    plot([east(demagrange);0], [north(demagrange);0], 'b-','LineWidth',1); hold on;
    plot(east(demagrange), north(demagrange), 'bs','MarkerFaceColor','w','MarkerSize',5); hold on;
    % Vertical Projection
    plot([east(demagrange);0],[-vertical(demagrange);0],'r-','LineWidth',1); hold on;
    plot(east(demagrange),-vertical(demagrange),'ro','MarkerFaceColor','w','MarkerSize',5); hold on;
    % label 2 demag steps
    text(east(demagrange(1+demaglabel)), -vertical(demagrange(1+demaglabel)),['  ',num2str(demagsteps(demagrange(1+demaglabel)))],'HorizontalAlignment','left','VerticalAlignment','Middle','FontSize',9);
    text(east(demagrange(end-demaglabel)), -vertical(demagrange(end-demaglabel)),['  ',num2str(demagsteps(demagrange(end-demaglabel)))],'HorizontalAlignment','left','VerticalAlignment','Middle','FontSize',9);    
    % add x axis
    line([min([min(east(demagrange))-horizontalscaling;-horizontalscaling]) max([max(east(demagrange))+horizontalscaling;horizontalscaling])], [0 0],'LineWidth',0.5,'color',[0 0.5 0]);hold on
    text(max([max(east(demagrange))+horizontalscaling;horizontalscaling]),0,'   E','fontsize',9,'color',[0 0.5 0]); 
    text(min([min(east(demagrange))-horizontalscaling;-horizontalscaling]),0,'W   ','HorizontalAlignment','right','fontsize',9,'color',[0 0.5 0]); 
    plot([min([min(east(demagrange))-horizontalscaling;-horizontalscaling]) min([min(east(demagrange))-horizontalscaling;-horizontalscaling])],...
         [-0.35*verticalscaling 0.35*verticalscaling],'-','color',[0 0.5 0]);
    plot([max([max(east(demagrange))+horizontalscaling;horizontalscaling]) max([max(east(demagrange))+horizontalscaling;horizontalscaling])],...
         [-0.35*verticalscaling 0.35*verticalscaling],'-','color',[0 0.5 0]);
    % add y-axis
    line([0 0], [min([min([north(demagrange);-vertical(demagrange);])-verticalscaling;-verticalscaling]) max([max([north(demagrange);-vertical(demagrange)])+verticalscaling; verticalscaling])],'LineWidth',0.5,'color',[0 0.5 0]); hold on;
    text(0,max([max([north(demagrange);-vertical(demagrange)])+verticalscaling; verticalscaling]),'N,Up','HorizontalAlignment','center','VerticalAlignment','Bottom','fontsize',9,'color',[0 0.5 0]); 
    text(0,min([min([north(demagrange);-vertical(demagrange);])-verticalscaling;-verticalscaling]),'S,Down','HorizontalAlignment','center','VerticalAlignment','Top','fontsize',9,'color',[0 0.5 0]); 
    plot([-0.35*verticalscaling 0.35*verticalscaling],...
        [min([min([north(demagrange);-vertical(demagrange);])-verticalscaling;-verticalscaling]) min([min([north(demagrange);-vertical(demagrange);])-verticalscaling;-verticalscaling])],'-','color',[0 0.5 0]);
    plot([-0.35*verticalscaling 0.35*verticalscaling],...
        [max([max([north(demagrange);-vertical(demagrange)])+verticalscaling; verticalscaling]) max([max([north(demagrange);-vertical(demagrange)])+verticalscaling; verticalscaling])],'-','color',[0 0.5 0]);

end

axis tight;
% GET TICKS
X=get(gca,'Xtick');
Y=get(gca,'Ytick');

% GET LABELS
XL=get(gca,'XtickLabel');
YL=get(gca,'YtickLabel');

% Plot new ticks  
for i=1:length(X)
    plot([X(i) X(i)],[0 0.35*verticalscaling],'-','color',[0 0.5 0]);
end;
for i=1:length(Y)
   plot([0.35*verticalscaling, 0],[Y(i) Y(i)],'-','color',[0 0.5 0]);
end;

% ADD LABELS
text(X([1,end]),0.35*verticalscaling*ones(1,2),XL([1,end],:),'HorizontalAlignment','center','VerticalAlignment','Bottom','fontsize',8,'color',[0 0.5 0]);
text(0.55*verticalscaling*ones(1,2),Y([1,end]),YL([1,end],:),'HorizontalAlignment','left','VerticalAlignment','middle','fontsize',8,'color',[0 0.5 0]);

axis equal;
axis off;
hold off;

%% [Function] zdplot3d
function zdplot3d(east, north, vertical, demagsteps, demagstar, demagend)

  % zdplot3d plots demagnetization curves in 3D space using the giving
  % values for each direction and the specified demagnetization range.
  % Scaling on each direction is the same (axis equal).

  % get demag range for plotting and demag step (middle step within the range) for labeling
    demagrange = find(demagsteps >= demagstar & demagsteps <= demagend);
    demaglabel = num2str(demagsteps(ceil(length(demagrange)./2)));
    markersizevalue = 5; % set size of markers on the plot
  % show horizontal projection
    plot3(east(demagrange),north(demagrange),zeros(size(demagrange)),...
          'bo-','MarkerFaceColor','b','Markersize', markersizevalue);hold on; 
  % show vertical projection
    plot3(east(demagrange),zeros(size(demagrange)),-vertical(demagrange),...
          'ro-','MarkerFaceColor','r','Markersize', markersizevalue); 
  % show 3D demag curve
    plot3([east(demagrange);0],[north(demagrange);0],[-vertical(demagrange);0],...
          '-','color',[0 0.5 0]); 
  % show 3D demag steps on curve
    plot3(east(demagrange),north(demagrange),-vertical(demagrange),...
          'o','color',[0 0.5 0],'MarkerFaceColor','w','Markersize', markersizevalue); 
  % show origin of the 3D plot (closed black circle)
    plot3(0,0,0,'ko','MarkerFaceColor','k','Markersize', markersizevalue);                                                                     
    xlabel('East'); ylabel('North'); zlabel('Vertical');
  % lable the middle step within the demag range
    text(east(demagrange(ceil(length(demagrange)./2))),north(demagrange(ceil(length(demagrange)./2))), -vertical(demagrange(ceil(length(demagrange)./2))),...                                  
        ['  \leftarrow',demaglabel],'VerticalAlignment','Middle');
    axis equal; grid on; box on; hold off;
  

%% [Function] pmagpca
function [decl, incl, mad] = pmgpca(east, north, vertical, demagsteps, demagstar, demagend, origindectector)
    
    data = [east,north,vertical];
    pcadata = data(find(demagsteps>=demagstar & demagsteps<=demagend),:);
    
    if  origindectector == 1,
        pcadata = [[0, 0, 0];pcadata];
        covdata = cov(pcadata);       % calculate covariance matrix of east-north-vetical varibles at certain position
        [xx,yy,zz] = pcacov(covdata); % calculate eigen values, eigen vectors (sorted) and corresponding var% for the cov matrix
        pcadirection = xx(:,1)*xx(:,1)'*pcadata';      % calculate coordinates of projection of points on pca line; positive constant 1./sum(xx(:,1).^2) is neglected.
        if sign(pcadirection(3,2)-pcadirection(3,end))~=sign(xx(3,1)),  % NEED TO BE CHECKED
        xx=-xx;                                     % check whether pca got the right direction by comparing sign of pca vertical coordinate (eigen vector associated with 
        end                                            % biggest eigen value) with vertical projection cordinates of demag200 and demag800 on pca line;                      
        mad = atand(sqrt((yy(2)+yy(3))/yy(1))); % 2nd column of pca(output data) is mad value
        decl = atand(abs(xx(1,1)/xx(2,1)));      % 4th column of pca(output data) is pca declination
        if xx(1,1)>0 && xx(2,1)<0, 
        decl = 180 - decl;
        end
        if xx(1,1)<0 && xx(2,1)>0, 
        decl = 360 - decl;
        end
        if xx(1,1)<0 && xx(2,1)<0,
        decl = 180 + decl;
        end  
        incl = asind(xx(3,1)/sqrt(sum(xx(:,1).^2))); % 5th column of pca(output data) is pca inclination
        
    else
        
        covdata = cov(pcadata);       % calculate covariance matrix of east-north-vetical varibles at certain position
        [xx,yy,zz] = pcacov(covdata); % calculate eigen values, eigen vectors (sorted) and corresponding var% for the cov matrix
        pcadirection = xx(:,1)*xx(:,1)'*pcadata';      % calculate coordinates of projection of points on pca line; positive constant 1./sum(xx(:,1).^2) is neglected.
        if sign(pcadirection(3,1)-pcadirection(3,end))~=sign(xx(3,1)), 
        xx=-xx;                                     % check whether pca got the right direction by comparing sign of pca vertical coordinate (eigen vector associated with 
        end                                            % biggest eigen value) with vertical projection cordinates of demag200 and demag800 on pca line;                      
        mad = atand(sqrt((yy(2)+yy(3))/yy(1))); % 2nd column of pca(output data) is mad value
        decl = atand(abs(xx(1,1)/xx(2,1)));      % 4th column of pca(output data) is pca declination
        if xx(1,1)>0 && xx(2,1)<0, 
        decl = 180 - decl;
        end
        if xx(1,1)<0 && xx(2,1)>0, 
        decl = 360 - decl;
        end
        if xx(1,1)<0 && xx(2,1)<0,
        decl = 180 + decl;
        end  
        incl = asind(xx(3,1)/sqrt(sum(xx(:,1).^2))); % 5th column of pca(output data) is pca inclination


    end
    
    
%% [Function] Update_UniformPCA
function [hObject, eventdata, handles] = Update_UniformPCA(hObject, eventdata, handles)

handles.DemagStart4PCA = handles.UniqueDemagSteps(get(handles.popupmenu_PcaDemagBegin,'Value'));
handles.DemagEnd4PCA   = handles.UniqueDemagSteps(get(handles.popupmenu_PcaDemagEnd,'Value'));

if get(handles.checkbox1,'Value') == get(handles.checkbox1,'Max'), 
    handles.AnchorOrigin = 1; 
else handles.AnchorOrigin = 0; 
end

for kk = 1:length(handles.UniformPCA),
    kkPositionIndex = find(handles.Positions == handles.UniquePositions(kk));
    [handles.UniformPCA(kk,2), handles.UniformPCA(kk,3), handles.UniformPCA(kk,4)] =...
                                                 pmgpca( handles.East(kkPositionIndex),...
                                                         handles.North(kkPositionIndex),...
                                                         handles.Vertical(kkPositionIndex),...
                                                         handles.DemagSteps(kkPositionIndex),...
                                                         handles.DemagStart4PCA,...
                                                         handles.DemagEnd4PCA,...
                                                         handles.AnchorOrigin);
end


%% [Function] Update_PCAplots
function [hObject, eventdata, handles] = Update_PCAplots(hObject, eventdata, handles)
 
if  strcmpi(get(handles.axes3, 'Visible'), 'off'),
    set(handles.radiobutton8,'Value',1);
    cla(handles.axes5);    
    cla(handles.axes6);
    cla(handles.axes7);

    set(handles.axes3, 'Visible','on');
    set(handles.axes4, 'Visible','on');
    set(handles.AX3, 'Visible','on');
    set(handles.AX4, 'Visible','on');
    set(handles.axes5, 'Visible','off');
    set(handles.axes6, 'Visible','off');
    set(handles.axes7, 'Visible','off');
end

CurrentPCA = find(handles.UniformPCA(:,1) == handles.UniquePositions(handles.PositionIndexNow));

axes(handles.axes3),
    hold off;
    [handles.AX3, handles.H31, handles.H32] = plotyy(handles.UniformPCA(:,1),handles.UniformPCA(:,3),handles.UniformPCA(:,1),handles.UniformPCA(:,2)); hold on;
    set(get(handles.AX3(1),'ylabel'),'String','Inc. ( \circ)');
    set(get(handles.AX3(2),'ylabel'),'String','Dec. ( \circ)');
    set(handles.AX3(2),'color','none');
    set(handles.AX3(1),'YLim',[-90 90]);
    set(handles.AX3(1),'Ycolor',[1 0 0]);
    set(handles.AX3(1),'Ytick',-90:45:90);
    set(handles.AX3(1),'Yticklabel',{'' '-45' '0' '45' '90'});
    set(handles.AX3(2),'YLim',[0 360]);
    set(handles.AX3(2),'Ycolor',[0 0 1]);
    set(handles.AX3(2),'Ytick',0:90:360);
    set(handles.AX3(2),'Yticklabel',{'' '90' '180' '270' '360'});
    set(handles.AX3(2),'Layer', 'Top');
    set(handles.H31,'marker','o','MarkerSize',4,'color', [1 0 0],'MarkerFaceColor','w');
    set(handles.H32,'marker','s','MarkerSize',4,'color', [0 0 1],'MarkerFaceColor','w');
    set(gca,'XMinorTick','on');
    set(handles.AX3,'YMinorTick','on');
    set(gca,'XTick',min(handles.UniformPCA(:,1)):10:max(handles.UniformPCA(:,1)));
    set(handles.AX3, 'Xticklabel','');
    set(gca,'Ticklength',[0.015;0.03]);
    hold on;
    handles.lineonax3 = line([handles.UniformPCA(CurrentPCA ,1),handles.UniformPCA(CurrentPCA ,1)], [-90, 90]);        
    set(handles.lineonax3,'linestyle',':','linewidth', 1,'color', 'r', 'EraseMode','xor','parent',handles.AX3(1));
    handles.markeronincl = plot(handles.UniformPCA(CurrentPCA,1),handles.UniformPCA(CurrentPCA,3),...
                                'marker','o','markerfacecolor','r','markeredgecolor','r','markersize',4,'EraseMode','xor','parent',handles.AX3(1));
    handles.markerondecl = line(handles.UniformPCA(CurrentPCA,1),handles.UniformPCA(CurrentPCA,2),...
                                'marker','s','markerfacecolor','b','markeredgecolor','b','markersize',4,'EraseMode','xor','parent',handles.AX3(2));
        
axes(handles.axes4),
    hold off;
    [handles.AX4, handles.H41, handles.H42] = plotyy(handles.UniformPCA(:,1),handles.UniformPCA(:,4),handles.UniformPCA(:,1),handles.IntPlot); 
    xlabel('Position (cm)');
    set(handles.AX4(2),'color','none');
    set(get(handles.AX4(1),'ylabel'),'String','\color[rgb]{0 0.5 0}MAD ( \circ)');
    set(get(handles.AX4(2),'ylabel'),'String',['\color{black}Intensity (',num2str(handles.UniqueDemagSteps(handles.IntPlotDemag)),')']);
    set(handles.AX4(1),'Ycolor',[0 0.5 0]);
    set(handles.AX4(2),'Xticklabel','');
    set(handles.AX4(2),'Ycolor',[0 0 0]);
    set(handles.H41,'marker','o','MarkerSize',4,'color', [0 0.5 0],'MarkerFaceColor','w');
    set(handles.H42,'marker','o','MarkerSize',4,'color', [0 0 0],'MarkerFaceColor','w');
    set(gca,'XTick',min(handles.UniformPCA(:,1)):10:max(handles.UniformPCA(:,1)));
    set(gca,'XMinorTick','on');
    set(gca,'YMinorTick','on');
    set(gca,'Ticklength',[0.015;0.03]);
    hold on;
    ylimitax41 = get(handles.AX4(1),'ylim');
    handles.lineonax4 = line([handles.UniformPCA(CurrentPCA ,1),handles.UniformPCA(CurrentPCA ,1)], ylimitax41);   
    set(handles.lineonax4,'linestyle',':','linewidth', 1,'color', 'r', 'EraseMode','xor','parent',handles.AX4(1));
    handles.markeronmad = line(handles.UniformPCA(CurrentPCA,1),handles.UniformPCA(CurrentPCA,4),...
                                'marker','o','markerfacecolor',[0 0.5 0],'markeredgecolor',[0 0.5 0],'markersize',4,'EraseMode','xor','parent',handles.AX4(1));
    handles.markeronint = line(handles.UniformPCA(CurrentPCA,1),handles.IntPlot(CurrentPCA),...
                                'marker','o','markerfacecolor','k','markeredgecolor','k','markersize',4,'EraseMode','xor','parent',handles.AX4(2));
    linkaxes([handles.AX3, handles.AX4], 'x');
    
   
%% [Function] Update_PCAplotsAtPosition
function [hObject, eventdata, handles] = Update_PCAplotsAtPosition(hObject, eventdata, handles)

CurrentPCA = find(handles.UniformPCA(:,1) == handles.UniquePositions(handles.PositionIndexNow));
ylimitax41 = get(handles.AX4(1),'ylim');

set(handles.lineonax3, 'xdata',[handles.UniformPCA(CurrentPCA,1),handles.UniformPCA(CurrentPCA,1)],'ydata',[-90, 90]);
set(handles.markeronincl, 'xdata',handles.UniformPCA(CurrentPCA,1),'ydata',handles.UniformPCA(CurrentPCA,3));
set(handles.markerondecl, 'xdata',handles.UniformPCA(CurrentPCA,1),'ydata',handles.UniformPCA(CurrentPCA,2));

set(handles.lineonax4, 'xdata',[handles.UniformPCA(CurrentPCA,1),handles.UniformPCA(CurrentPCA,1)],'ydata',ylimitax41);
set(handles.markeronmad, 'xdata',handles.UniformPCA(CurrentPCA,1),'ydata',handles.UniformPCA(CurrentPCA,4));
set(handles.markeronint, 'xdata',handles.UniformPCA(CurrentPCA,1),'ydata',handles.IntPlot(CurrentPCA));

drawnow;

   
%% [Function] Update_PCAboxes
function Update_PCAboxes(hObject, eventdata, handles)

CurrentPCA = find(handles.UniformPCA(:,1) == handles.UniquePositions(handles.PositionIndexNow));
set(handles.edit19,'String',num2str(handles.UniformPCA(CurrentPCA,2))); 
set(handles.edit21,'String',num2str(handles.UniformPCA(CurrentPCA,3))); 
set(handles.edit22,'String',num2str(handles.UniformPCA(CurrentPCA,4))); 


%% [Function] Update_PositionBoxes
function Update_PositionBoxes(hObject, eventdata, handles)

set(handles.edit2,'String',num2str(handles.CurrentPosition));
set(handles.edit4,'String',num2str(handles.CurrentPosition));


%% [Function] Update_PositionRelated
function [hObject, eventdata, handles] = Update_PositionRelated(hObject, eventdata, handles)

handles.CurrentPosition = handles.UniquePositions(handles.PositionIndexNow);
handles.CurrentIndexes  = find(handles.Positions == handles.CurrentPosition);
Update_PositionBoxes(hObject, eventdata, handles);
Update_PCAboxes(hObject, eventdata, handles);
Update_IntDemagPlot(hObject, eventdata, handles);
Update_zdplots(hObject, eventdata, handles);
if  strcmpi(get(handles.axes3, 'Visible'), 'off'),
    [hObject, eventdata, handles] = Update_PCAplots(hObject, eventdata, handles);
end
[hObject, eventdata, handles] = Update_PCAplotsAtPosition(hObject, eventdata, handles);


%% [Function] Update_IntDemagPlot
function Update_IntDemagPlot(hObject, eventdata, handles)

demagrange = find(handles.DemagSteps(handles.CurrentIndexes) >= handles.DemagStart4Plot & handles.DemagSteps(handles.CurrentIndexes) <= handles.DemagEnd4Plot);
axes(handles.axes2),
plot(handles.DemagSteps(handles.CurrentIndexes),...
     handles.Intensity(handles.CurrentIndexes),...
     'o-',...
     'color',[0 0.5 0],...
     'MarkerFaceColor','w',...
     'MarkerSize',5);
hold on, plot(handles.DemagSteps(handles.CurrentIndexes(demagrange)),...
     handles.Intensity(handles.CurrentIndexes(demagrange)),...
     'o',...
     'color',[0 0.5 0],...
     'MarkerFaceColor','r',...
     'MarkerSize',5); 
if handles.grid == 1, grid on; end;
if handles.holdon == 0, hold off; end;
if handles.titleon == 1, title([handles.SampleID, ' at position: ', num2str(handles.CurrentPosition)]); end 
xlabel('Demag Steps');
ylabel('Intensity');
set(gca,'XMinorTick','on');
set(gca,'YMinorTick','on');
set(gca,'Ticklength',[0.02;0.05]);
 

%% [Function] Update_zdplots
function Update_zdplots(hObject, eventdata, handles)

  % update_zdplots updates the zdplot/zdplot3d base on the updated
  % parameters that controls the zdplot and zdplot3d .
  
  axes(handles.axes1),
  if handles.Dimension == 3,
     zdplot3d(handles.East(handles.CurrentIndexes),...
              handles.North(handles.CurrentIndexes),...
              handles.Vertical(handles.CurrentIndexes),...
              handles.DemagSteps(handles.CurrentIndexes),...
              handles.DemagStart4Plot,...
              handles.DemagEnd4Plot);

  else zdplot(handles.East(handles.CurrentIndexes),...
              handles.North(handles.CurrentIndexes),...
              handles.Vertical(handles.CurrentIndexes),...
              handles.DemagSteps(handles.CurrentIndexes),...
              handles.DemagStart4Plot,...
              handles.DemagEnd4Plot,...
              handles.WestUp);
  end

  if handles.holdon == 1, hold on; end;

%% [Function] uigetfile2
function [filename, pathname, filterindex] = uigetfile2(varargin)

%UIGETFILE2 Standard open file dialog box which remembers last opened folder
%   UIGETFILE2 is a wrapper for Matlab's UIGETFILE function which adds the
%   ability to remember the last folder opened.  UIGETFILE2 stores
%   information about the last folder opened in a mat file which it looks
%   for when called.
%
%   UIGETFILE2 can only remember the folder used if the current directory
%   is writable so that a mat file can be stored.  Only successful file
%   selections update the folder remembered.  If the user cancels the file
%   dialog box then the remembered path is left the same.
%
%   Usage is the same as UIGETFILE.
%
%
%   See also UIGETFILE, UIPUTFILE, UIGETDIR.

%   Written by Chris J Cannell and Aditya Gadre
%   Contact ccannell@mindspring.com for questions or comments.
%   12/05/2005

% name of mat file to save last used directory information
lastDirMat = 'lastUsedDir.mat';

% save the present working directory
savePath = pwd;
% set default dialog open directory to the present working directory
lastDir = savePath;
% load last data directory
if exist(lastDirMat, 'file') ~= 0
    % lastDirMat mat file exists, load it
    load('-mat', lastDirMat)
    % check if lastDataDir variable exists and contains a valid path
    if (exist('lastUsedDir', 'var') == 1) && ...
            (exist(lastUsedDir, 'dir') == 7)
        % set default dialog open directory
        lastDir = lastUsedDir;
    end
end

% load folder to open dialog box in
cd(lastDir);
% call uigetfile with arguments passed from uigetfile2 function
[filename, pathname, filterindex] = uigetfile(varargin{:});
% change path back to original working folder
cd(savePath);

% if the user did not cancel the file dialog then update lastDirMat mat
% file with the folder used
if ~isequal(filename,0) && ~isequal(pathname,0)
    try
        % save last folder used to lastDirMat mat file
        lastUsedDir = pathname;
        save(lastDirMat, 'lastUsedDir');
    catch
        % error saving lastDirMat mat file, display warning, the folder
        % will not be remembered
        disp(['Warning: Could not save file ''', lastDirMat, '''']);
    end
end


%% [Edits] Totally 12 edit boxes

function edit1_Callback(hObject, eventdata, handles)
function edit1_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit2_Callback(hObject, eventdata, handles)
function edit2_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit4_Callback(hObject, eventdata, handles)
function edit4_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit17_Callback(hObject, eventdata, handles)
function edit17_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit19_Callback(hObject, eventdata, handles)
function edit19_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit21_Callback(hObject, eventdata, handles)
function edit21_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit22_Callback(hObject, eventdata, handles)
function edit22_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit27_Callback(hObject, eventdata, handles)
function edit27_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit30_Callback(hObject, eventdata, handles)
function edit30_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



%% [Radiobutton] Change to sample coordinate
function radiobutton7_Callback(hObject, eventdata, handles)

if (get(handles.radiobutton7,'Value') == get(handles.radiobutton7,'Max')), % if this button is selected
    handles.decl             = handles.filedata{handles.Columns2g(4)};
    handles.incl             = handles.filedata{handles.Columns2g(5)};
    handles.East             = handles.Intensity.*cosd(handles.filedata{handles.Columns2g(5)}).*sind(handles.filedata{handles.Columns2g(4)});
    handles.North            = handles.Intensity.*cosd(handles.filedata{handles.Columns2g(5)}).*cosd(handles.filedata{handles.Columns2g(4)});
    handles.Vertical         = handles.Intensity.*sind(handles.filedata{handles.Columns2g(5)}); 
    
    handles.HoldZplotAxesNorthUp = [min(handles.East) max(handles.East) min([handles.North; -handles.Vertical]) max([handles.North; -handles.Vertical])];
    handles.HoldZplotAxesWestUp  = [min(handles.North) max(handles.North) min([-handles.East; -handles.Vertical]) max([-handles.East; -handles.Vertical])];
    handles.Hold3dAxes           = [min(handles.East) max(handles.East) min(handles.North) max(handles.North) min(-handles.Vertical) max(-handles.Vertical)];
    
    [hObject, eventdata, handles] = Update_UniformPCA(hObject, eventdata, handles);
    [hObject, eventdata, handles] = Update_PCAplots(hObject, eventdata, handles);
    [hObject, eventdata, handles] = Update_PositionRelated(hObject, eventdata, handles);
end
guidata(hObject,handles);
    

%% [Radiobutton] Change to geographic coordinate
function radiobutton5_Callback(hObject, eventdata, handles)

if (get(handles.radiobutton5,'Value') == get(handles.radiobutton5,'Max')), % if this button is selected
    handles.decl             = handles.filedata{handles.Columns2g(6)};
    handles.incl             = handles.filedata{handles.Columns2g(7)};
    handles.East             = handles.Intensity.*cosd(handles.filedata{handles.Columns2g(7)}).*sind(handles.filedata{handles.Columns2g(6)});
    handles.North            = handles.Intensity.*cosd(handles.filedata{handles.Columns2g(7)}).*cosd(handles.filedata{handles.Columns2g(6)});
    handles.Vertical         = handles.Intensity.*sind(handles.filedata{handles.Columns2g(7)}); 
    
    handles.HoldZplotAxesNorthUp = [min(handles.East) max(handles.East) min([handles.North; -handles.Vertical]) max([handles.North; -handles.Vertical])];
    handles.HoldZplotAxesWestUp  = [min(handles.North) max(handles.North) min([-handles.East; -handles.Vertical]) max([-handles.East; -handles.Vertical])];
    handles.Hold3dAxes           = [min(handles.East) max(handles.East) min(handles.North) max(handles.North) min(-handles.Vertical) max(-handles.Vertical)];
    
    [hObject, eventdata, handles] = Update_UniformPCA(hObject, eventdata, handles);
    [hObject, eventdata, handles] = Update_PCAplots(hObject, eventdata, handles);
    [hObject, eventdata, handles] = Update_PositionRelated(hObject, eventdata, handles);
end
guidata(hObject,handles);


%% [Radiobutton] Change to bedding corrected coordinate
function radiobutton6_Callback(hObject, eventdata, handles)

if (get(handles.radiobutton6,'Value') == get(handles.radiobutton6,'Max')), % if this button is selected
    handles.decl             = handles.filedata{handles.Columns2g(8)};
    handles.incl             = handles.filedata{handles.Columns2g(9)};
    handles.East             = handles.Intensity.*cosd(handles.filedata{handles.Columns2g(9)}).*sind(handles.filedata{handles.Columns2g(8)});
    handles.North            = handles.Intensity.*cosd(handles.filedata{handles.Columns2g(9)}).*cosd(handles.filedata{handles.Columns2g(8)});
    handles.Vertical         = handles.Intensity.*sind(handles.filedata{handles.Columns2g(9)}); 
    
    handles.HoldZplotAxesNorthUp = [min(handles.East) max(handles.East) min([handles.North; -handles.Vertical]) max([handles.North; -handles.Vertical])];
    handles.HoldZplotAxesWestUp  = [min(handles.North) max(handles.North) min([-handles.East; -handles.Vertical]) max([-handles.East; -handles.Vertical])];
    handles.Hold3dAxes           = [min(handles.East) max(handles.East) min(handles.North) max(handles.North) min(-handles.Vertical) max(-handles.Vertical)];
    
    [hObject, eventdata, handles] = Update_UniformPCA(hObject, eventdata, handles);
    [hObject, eventdata, handles] = Update_PCAplots(hObject, eventdata, handles);
    [hObject, eventdata, handles] = Update_PositionRelated(hObject, eventdata, handles);
end
guidata(hObject,handles);


%% [Push] Show plots in full demag range
function pushbutton45_Callback(hObject, eventdata, handles)

handles.DemagStart4Plot  = handles.DemagSteps(handles.CurrentIndexes(1));      % Assumes that *.dir file were sorted ascending first by Position then by demag steps 
handles.DemagEnd4Plot    = handles.DemagSteps(handles.CurrentIndexes(end));
set(handles.popupmenu_PlotDemagBegin,'Value',find(handles.UniqueDemagSteps == handles.DemagStart4Plot));
set(handles.popupmenu_PlotDemagEnd,'Value',find(handles.UniqueDemagSteps == handles.DemagEnd4Plot)); 
Update_zdplots(hObject, eventdata, handles);
Update_IntDemagPlot(hObject, eventdata, handles);

guidata(hObject,handles);


%% [Push] Calculate PCA in default range
function pushbutton46_Callback(hObject, eventdata, handles)

if length(handles.CurrentIndexes) < 5,
   handles.DemagStart4PCA   = handles.DemagSteps(handles.CurrentIndexes(1));
   handles.DemagEnd4PCA     = handles.DemagSteps(handles.CurrentIndexes(end));
   handles.IntPlotDemag     = ceil(length(handles.CurrentIndexes)./2);
else 
   handles.DemagStart4PCA   = handles.DemagSteps(handles.CurrentIndexes(2)); % if >= dmage steps done for this position, PCA calculating start from 2nd demag step
   handles.DemagEnd4PCA     = handles.DemagSteps(handles.CurrentIndexes(end-1));
   handles.IntPlotDemag     = 5;
end
set(handles.popupmenu_PcaDemagBegin,'Value',find(handles.UniqueDemagSteps == handles.DemagStart4PCA));
set(handles.popupmenu_PcaDemagEnd  ,'Value',find(handles.UniqueDemagSteps ==handles.DemagEnd4PCA));
[hObject, eventdata, handles] = Update_UniformPCA(hObject, eventdata, handles);
Update_PCAboxes(hObject, eventdata, handles);
[hObject, eventdata, handles] = Update_PCAplots(hObject, eventdata, handles);
guidata(hObject,handles);



%% [Radios] VGP PlOT
function [hObject, eventdata, handles] = radiobutton9_Callback(hObject, eventdata, handles)

if (get(handles.radiobutton9,'Value') == get(handles.radiobutton9,'Max')), % if this button is selected
    
    if  handles.vgpSiteLat == 999,
        vgpDefaultInput = 1;    % FIRST TIME CALCULATION
    else
        vgpDefaultInput = 0;    % USE PREVIOUS VALUES
        setappdata(0, 'vgpDeclCorr'     , handles.vgpDeclCorr);          
        setappdata(0, 'vgpSiteLat'      , handles.vgpSiteLat);    
        setappdata(0, 'vgpSiteLong'     , handles.vgpSiteLong);          
        setappdata(0, 'vgpMapOriginLat' , handles.vgpMapOriginLat);
        setappdata(0, 'vgpMapOriginLong', handles.vgpMapOriginLong);
        setappdata(0, 'vgpMapLatLim'    , handles.vgpMapLatLim);
        setappdata(0, 'vgpMapLongLim'   , handles.vgpMapLongLim);
        setappdata(0, 'vgpDefaultInput' , handles.vgpMapLongLim);
        setappdata(0, 'vgpMapProjectionValue', handles.vgpMapProjectionValue);                             
    end
   
    setappdata(0, 'vgpDefaultInput', vgpDefaultInput);
    H = udir_VGP_Input_dlg;
    uiwait(H);
    handles.vgpCalcDecision  = getappdata(0, 'vgpCalcDecision');
    
    if handles.vgpCalcDecision == 0, 
       msgbox('VGP Calculation Cancelled.', 'Cancellation Confirmation','warn'); return;
    end;
    
    handles.vgpDeclCorr      = getappdata(0, 'vgpDeclCorr');
    handles.vgpSiteLat       = getappdata(0, 'vgpSiteLat');
    handles.vgpSiteLong      = getappdata(0, 'vgpSiteLong');     
    handles.vgpMapOriginLat  = getappdata(0, 'vgpMapOriginLat');      
    handles.vgpMapOriginLong = getappdata(0, 'vgpMapOriginLong');     
    handles.vgpMapLatLim     = getappdata(0, 'vgpMapLatLim');
    handles.vgpMapLongLim    = getappdata(0, 'vgpMapLongLim');
    handles.vgpMapProjection = getappdata(0, 'vgpMapProjection');
    handles.vgpMapProjectionValue = getappdata(0, 'vgpMapProjectionValue');
    
    rmappdata(0, 'vgpDeclCorr');
    rmappdata(0, 'vgpDefaultInput');
    rmappdata(0, 'vgpCalcDecision');
    rmappdata(0, 'vgpSiteLat');
    rmappdata(0, 'vgpSiteLong');
    rmappdata(0, 'vgpMapOriginLong');
    rmappdata(0, 'vgpMapLatLim');
    rmappdata(0, 'vgpMapLongLim');
    rmappdata(0, 'vgpMapProjection');
    rmappdata(0, 'vgpMapProjectionValue');
     
    cla(handles.axes3);
    cla(handles.axes4);
    cla(handles.axes6);
    cla(handles.axes7);
    cla(handles.AX3(1));
    cla(handles.AX3(2));
    cla(handles.AX4(1));   
    cla(handles.AX4(2));  
    
    set(handles.axes3, 'Visible','off');
    set(handles.axes4, 'Visible','off');
    set(handles.axes5, 'Visible','on');
    set(handles.axes6, 'Visible','off');
    set(handles.axes7, 'Visible','off');
    set(handles.AX3, 'Visible','off');
    set(handles.AX4, 'Visible','off');
       
    [handles.vgplat, handles.vgplong] = vgp_calc(handles.vgpDeclCorr+handles.UniformPCA(:,2), handles.UniformPCA(:,3), handles.vgpSiteLat, handles.vgpSiteLong);
    guidata(hObject,handles);
    [hObject, eventdata, handles] = Update_VGPplot(hObject, eventdata, handles);
    
end
guidata(hObject,handles);


%% [Radio] PCA/Int Plot
function radiobutton8_Callback(hObject, eventdata, handles)

if (get(handles.radiobutton8,'Value') == get(handles.radiobutton8,'Max')), % if this button is selected
    
    cla(handles.axes5);    
    cla(handles.axes6);
    cla(handles.axes7);

    set(handles.axes3, 'Visible','on');
    set(handles.axes4, 'Visible','on');
    set(handles.AX3, 'Visible','on');
    set(handles.AX4, 'Visible','on');
    set(handles.axes5, 'Visible','off');
    set(handles.axes6, 'Visible','off');
    set(handles.axes7, 'Visible','off');
    [hObject, eventdata, handles] = Update_UniformPCA(hObject, eventdata, handles);
    [hObject, eventdata, handles] = Update_PCAplots(hObject, eventdata, handles);
    [hObject, eventdata, handles] = Update_PositionRelated(hObject, eventdata, handles);
end
guidata(hObject,handles);


%% [RadioButtons] Stereographic Plot
function radiobutton10_Callback(hObject, eventdata, handles)

if (get(handles.radiobutton10,'Value') == get(handles.radiobutton10,'Max')), % if this button is selected
    
    cla(handles.axes3);
    cla(handles.axes4);
    cla(handles.axes5);    
    cla(handles.AX3(1));
    cla(handles.AX3(2));
    cla(handles.AX4(1));   
    cla(handles.AX4(2));  

    set(handles.axes3, 'Visible','off');
    set(handles.axes4, 'Visible','off');
    set(handles.AX3, 'Visible','off');
    set(handles.AX4, 'Visible','off');
    set(handles.axes5, 'Visible','off');
    set(handles.axes6, 'Visible','on');
    set(handles.axes7, 'Visible','on');
    
    axes(handles.axes6), 
    equalareaplot(handles.UniformPCA(:,2), handles.UniformPCA(:,3));hold on;
    
    decl = handles.UniformPCA(handles.PositionIndexNow, 2);
    incl = handles.UniformPCA(handles.PositionIndexNow, 3);
    if incl>=0,
       x = (90-incl).*sind(decl);
       y = (90-incl).*cosd(decl);
    else
       x = (90+incl).*sind(180+decl);
       y = (90+incl).*cosd(180+decl);
    end
    plot(x, y, 'ko', 'markerfacecolor', 'g', 'markersize', 6);
    hold off;
    
    axes(handles.axes7), 
    equalareaplot(handles.decl(handles.CurrentIndexes), handles.incl(handles.CurrentIndexes));    
    
end
guidata(hObject,handles);


%% [Function] VGP Calculation
function [vgplat, vgplong] = vgp_calc(decl, incl, site_lat, site_long)

p = 90-atand((tand(incl))./2);
sindvgplat = sind(site_lat).*cosd(p)+cosd(site_lat).*sind(p).*cosd(decl);
vgplat = asind(sindvgplat);
longdir = sind(site_lat).*sindvgplat-cosd(p);
beta = asind((sind(p).*sind(decl))./(cosd(vgplat)));
vgplong = zeros(size(vgplat));

for k = 1:length(longdir),
    
    if longdir(k) > 0,
       vgplong(k) = site_long + 180 - beta(k);
    else
       vgplong(k) = site_long + beta(k);
    end
    
    vgplong(k) = vgplong(k)-360;
    
    if vgplong(k)>180,
       vgplong(k) = vgplong(k)-360;
    elseif vgplong(k) < -180,
       vgplong(k) = vgplong(k)+360;
    end
    
end


%% [Function] Update VGP Plot
function [hObject, eventdata, handles] = Update_VGPplot(hObject, eventdata, handles)

axes(handles.axes5),
if  strcmpi(handles.vgpMapProjection, 'globe'),
    cla;
    hold off;
    axesm(handles.vgpMapProjection, 'Frame', 'on', 'Grid', 'on',...
                                 'origin',[handles.vgpMapOriginLat handles.vgpMapOriginLong])
                                 
    gridm('GLineStyle','-','Gcolor',[.7 .7 .7],'Galtitude', .002);
    load coast;
    plotm(lat, long, 'color', [0.5 0.5 0.5]);
    base = zeros(180,360); baseref = [1 90 0];
    meshm(base,baseref,size(base));
    colormap copper;
    camlight right;
    material([.8 .9 .4]);
    view(3);
    hold on; plot3m(handles.vgplat, handles.vgplong,0.01, 'bo', 'markerfacecolor','w','markersize',5);
    for kk = 1:length(handles.vgplat)-1,
        [latc,lonc] = track2(handles.vgplat(kk), handles.vgplong(kk), handles.vgplat(kk+1), handles.vgplong(kk+1));
        plot3m(latc,lonc,0.01,'b','linewidth',1);
    end
    plot3m(handles.vgplat(1),handles.vgplong(1),0.01,'bs','markerfacecolor','g','markersize',6);
    plot3m(handles.vgplat(end),handles.vgplong(end),0.01,'bv','markerfacecolor','g','markersize',6);
    plot3m(handles.vgplat(handles.PositionIndexNow),handles.vgplong(handles.PositionIndexNow),0.01,'marker','o','markerfacecolor','r','markeredgecolor','k','markersize',7);
       
    camposm(60, 265, 2.5);
    camva(30);
    axis off;
    hidem(gca);
else
    cla;
    axesm(handles.vgpMapProjection, 'Frame', 'on', 'Grid', 'on','origin',[handles.vgpMapOriginLat handles.vgpMapOriginLong],...
                                 'MapLatLimit',handles.vgpMapLatLim, 'MapLonLim', handles.vgpMapLongLim);
    gridm('GLineStyle','-','Gcolor',[.7 .7 .7]);
    geoshow('landareas.shp','FaceColor', [1 1 .5],'edgecolor', [0.8 0.8 0.8]);
    hold on; plotm(handles.vgplat, handles.vgplong, 'bo-', 'markerfacecolor','w','markersize',5);
    hold on; plotm(handles.vgplat(1),handles.vgplong(1),'bs','markerfacecolor','g','markersize',6);
    hold on; plotm(handles.vgplat(end),handles.vgplong(end),'bv','markerfacecolor','g','markersize',6);
    hold on; plotm(handles.vgplat(handles.PositionIndexNow),handles.vgplong(handles.PositionIndexNow),...
                                    'marker','o','markerfacecolor','r','markeredgecolor','k','markersize',7);
    view(2);
    axis off;
    hold off;
end
guidata(hObject,handles);


%% [Function] Equal Area Plot
function equalareaplot(decl, incl)

t=linspace(0,2*pi,10000);
xx = 90*cos(t);
yy = 90*sin(t);

% ---------add white background
area(xx, yy, 'facecolor', 'w', 'edgecolor', 'w');hold on;
   
% ---------draw a circle
plot(xx,yy,'k','LineWidth',1);
axis equal;
axis off;

% ---------Add incl ticks
inclstick = (10:10:80)';
inclstick = 90*sqrt(2)*sind(45-inclstick./2);
plot(              0,               0,'k+','markersize',8,'MarkerFaceColor','k');
plot(              0,  (90-inclstick),'k+','markersize',8,'MarkerFaceColor','k');
plot(              0, -(90-inclstick),'k+','markersize',8,'MarkerFaceColor','k');
plot( (90-inclstick),               0,'k+','markersize',8,'MarkerFaceColor','k');
plot(-(90-inclstick),               0,'k+','markersize',8,'MarkerFaceColor','k');

% ---------Add Decl tick
xdata = [90*sind(  0), 93*sind(  0), NaN, ...
         90*sind( 30), 93*sind( 30), NaN, ...
         90*sind( 60), 93*sind( 60), NaN, ...
         90*sind( 90), 93*sind( 90), NaN, ...
         90*sind(120), 93*sind(120), NaN, ...
         90*sind(150), 93*sind(150), NaN, ...
         90*sind(180), 93*sind(180), NaN, ...
         90*sind(210), 93*sind(210), NaN, ...
         90*sind(240), 93*sind(240), NaN, ...
         90*sind(270), 93*sind(270), NaN, ...
         90*sind(300), 93*sind(300), NaN, ...
         90*sind(330), 93*sind(330), NaN, ...
         90*sind(360), 93*sind(360), NaN];   
ydata = [90*cosd(  0), 93*cosd(  0), NaN, ...
         90*cosd( 30), 93*cosd( 30), NaN, ...
         90*cosd( 60), 93*cosd( 60), NaN, ...
         90*cosd( 90), 93*cosd( 90), NaN, ...
         90*cosd(120), 93*cosd(120), NaN, ...
         90*cosd(150), 93*cosd(150), NaN, ...         
         90*cosd(180), 93*cosd(180), NaN, ...
         90*cosd(210), 93*cosd(210), NaN, ...
         90*cosd(240), 93*cosd(240), NaN, ...
         90*cosd(270), 93*cosd(270), NaN, ...
         90*cosd(300), 93*cosd(300), NaN, ...
         90*cosd(330), 93*cosd(330), NaN, ...
         90*cosd(360), 93*cosd(360), NaN];         
line('xdata', xdata, 'ydata', ydata);

% ----------Add label
text(0  ,  93, 'N (0\circ)'  , 'verticalalignment', 'bottom', 'horizontalalignment', 'center');
text(93 ,   0, 'E (90\circ)' , 'verticalalignment', 'middle', 'horizontalalignment', 'left');
text(0  , -93, 'S (180\circ)', 'verticalalignment', 'top'   , 'horizontalalignment', 'center');
text(-93,   0, 'W (270\circ)', 'verticalalignment', 'middle', 'horizontalalignment', 'right');

% ----------Add data
indexp = find(incl>=0);
indexn = find(incl<0);
declp = decl(indexp);
decln = decl(indexn);
inclp = incl(indexp);
incln = incl(indexn);

dp  = 90*sqrt(2)*sind(45-inclp./2);
dn  = 90*sqrt(2)*sind(45+incln./2);
xcp = dp.*sind(declp);
ycp = dp.*cosd(declp);
xcn = dn.*sind(180+decln);
ycn = dn.*cosd(180+decln);

% xcp = (90-inclp).*sind(declp);
% ycp = (90-inclp).*cosd(declp);
% xcn = (90+incln).*sind(180+decln);
% ycn = (90+incln).*cosd(180+decln);

plot(xcp, ycp, 'ko', 'markerfacecolor', 'r', 'markersize', 4);
plot(xcn, ycn, 'ko', 'markerfacecolor', 'c', 'markersize', 4);
hold off;


%% [TOGGLE] AUTO DISPLAY
function togglebutton16_Callback(hObject, eventdata, handles)

if  get(handles.togglebutton16,'Value') == get(handles.togglebutton16,'Max'), 

    movespeed =  str2double(get(handles.edit17,'String'));
%   set(handles.togglebutton13,'Value',get(handles.togglebutton13,'Min'));

    if get(handles.checkbox6,'Value') == get(handles.checkbox6,'Max'), 
        for autoindex = handles.PositionIndexNow:-1:1,
            if get(handles.togglebutton16,'Value') == get(handles.togglebutton16,'Min'), break; end
            handles.PositionIndexNow = handles.PositionIndexNow - 1;
            if handles.PositionIndexNow >= 1,
               [hObject, eventdata, handles] = Update_PositionRelated(hObject, eventdata, handles);
            else
               handles.PositionIndexNow = handles.PositionIndexNow + 1; 
               set(handles.edit2,'String','Reach Start');
               set(handles.togglebutton16,'Value',get(handles.togglebutton16,'Min'));
               break;
            end      
           pause(movespeed);  
        end   
    else
        for autoindex = handles.PositionIndexNow:length(handles.UniquePositions),
            if get(handles.togglebutton16,'Value') == get(handles.togglebutton16,'Min'), break; end
            handles.PositionIndexNow = handles.PositionIndexNow + 1;
            if handles.PositionIndexNow <= length(handles.UniquePositions),
               [hObject, eventdata, handles] = Update_PositionRelated(hObject, eventdata, handles);
            else
               handles.PositionIndexNow = handles.PositionIndexNow - 1; 
               set(handles.edit2,'String','Reach End');    
               set(handles.togglebutton16,'Value',get(handles.togglebutton16,'Min'));
               break;
            end
           pause(movespeed);  
        end
    end
else
    return
end

guidata(hObject,handles);


%% [Popummenu]

function popupmenu_PlotDemagBegin_Callback(hObject, eventdata, handles)
function popupmenu_PlotDemagBegin_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function popupmenu_PlotDemagEnd_Callback(hObject, eventdata, handles)
function popupmenu_PlotDemagEnd_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function popupmenu_PcaDemagBegin_Callback(hObject, eventdata, handles)
function popupmenu_PcaDemagBegin_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function popupmenu_PcaDemagEnd_Callback(hObject, eventdata, handles)
function popupmenu_PcaDemagEnd_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



%% [Menu] File
function MenuFilePrint_Callback(hObject, eventdata, handles)
uipushtool_Print_ClickedCallback(hObject, eventdata, handles);

function MenuFileSavePcaUniform_Callback(hObject, eventdata, handles)
pushbutton33_Callback(hObject, eventdata, handles);

function MenuFileSaveVGP_Callback(hObject, eventdata, handles)
pushbutton47_Callback(hObject, eventdata, handles);

function MenuFileOpenDIR_Callback(hObject, eventdata, handles)
pushbutton3_Callback(hObject, eventdata, handles);

function MenuFileSavePCA_Callback(hObject, eventdata, handles)

function MenuFileSavePcaOpt_Callback(hObject, eventdata, handles)
pushbutton31_Callback(hObject, eventdata, handles);

function MenuFileSavePlot_Callback(hObject, eventdata, handles)
pushbutton23_Callback(hObject, eventdata, handles); 

function MenuFile_Callback(hObject, eventdata, handles)


%% [Menu] Plot
function MenuPlot_Callback(hObject, eventdata, handles)

function MenuPlotChooseRange_Callback(hObject, eventdata, handles)
prompt={'Demag Step Starts at: ',...
        'Demag Step Ends at: '};
name='Plot Range';
numlines = 1;
defaultbegin = handles.UniqueDemagSteps(get(handles.popupmenu_PlotDemagBegin, 'value'));
defaultend   = handles.UniqueDemagSteps(get(handles.popupmenu_PlotDemagEnd, 'value'));
defaultanswer={num2str(defaultbegin), num2str(defaultend)};
answer = inputdlg(prompt,name,numlines,defaultanswer);
if ~isempty(answer), 
   startvalue = find(handles.UniqueDemagSteps == str2double(answer{1}));
   endvalue   = find(handles.UniqueDemagSteps == str2double(answer{2}));
   if any([isempty(startvalue), isempty(endvalue)]),
      msgbox('Bad Range, Please re-allocate.','Bad Plot Range','help'); return;
   end
   set(handles.popupmenu_PlotDemagBegin,'Value',startvalue);    
   set(handles.popupmenu_PlotDemagEnd,'Value',endvalue); 
   pushbutton27_Callback(hObject, eventdata, handles);
end

function MenuPlotMouseRange_Callback(hObject, eventdata, handles)
set(handles.togglebutton5,'Value', get(handles.togglebutton5,'Max'));
togglebutton5_Callback(hObject, eventdata, handles);

function MenuPlotShowAll_Callback(hObject, eventdata, handles)
pushbutton45_Callback(hObject, eventdata, handles);

function MenuPlotZoomIn_Callback(hObject, eventdata, handles)
set(handles.togglebutton2,'Value',get(handles.togglebutton2,'Max'));
togglebutton2_Callback(hObject, eventdata, handles);

function MenuPlotZoomOff_Callback(hObject, eventdata, handles)
set(handles.togglebutton2,'Value',get(handles.togglebutton2,'Min'));
togglebutton2_Callback(hObject, eventdata, handles);

function MenuPlotPanOn_Callback(hObject, eventdata, handles)
pan on;

function MenuPlotPanOff_Callback(hObject, eventdata, handles)
pan off;

function MenuPlotRotateOn_Callback(hObject, eventdata, handles)
set(handles.togglebutton12,'Value',get(handles.togglebutton12,'Max'));
togglebutton12_Callback(hObject, eventdata, handles);

function MenuPlotRotateOff_Callback(hObject, eventdata, handles)
set(handles.togglebutton12,'Value',get(handles.togglebutton12,'Min'));
togglebutton12_Callback(hObject, eventdata, handles);

function MenuPlotGridOn_Callback(hObject, eventdata, handles)
set(handles.togglebutton17,'Value',get(handles.togglebutton17,'Max'));
togglebutton17_Callback(hObject, eventdata, handles);

function MenuPlotGridOff_Callback(hObject, eventdata, handles)
set(handles.togglebutton17,'Value',get(handles.togglebutton17,'Min'));
togglebutton17_Callback(hObject, eventdata, handles);

function MenuPlotTitleOn_Callback(hObject, eventdata, handles)
set(handles.togglebutton18,'Value',get(handles.togglebutton18,'Max'));
togglebutton18_Callback(hObject, eventdata, handles);

function MenuPlotTitleOff_Callback(hObject, eventdata, handles)
set(handles.togglebutton18,'Value',get(handles.togglebutton18,'Min'));
togglebutton18_Callback(hObject, eventdata, handles);

function MenuPlotHoldOn_Callback(hObject, eventdata, handles)
set(handles.togglebutton8,'Value',get(handles.togglebutton8,'Max'));
togglebutton8_Callback(hObject, eventdata, handles);

function MenuPlotHoldOff_Callback(hObject, eventdata, handles)
set(handles.togglebutton8,'Value',get(handles.togglebutton8,'Min'));
togglebutton8_Callback(hObject, eventdata, handles);

function MenuPlotDataCursorOn_Callback(hObject, eventdata, handles)
datacursormode on;

function MenuPlotDataCursorOff_Callback(hObject, eventdata, handles)
datacursormode off;


%% [Menu] PCA
function MenuPCA_Callback(hObject, eventdata, handles)

function MenuPcaChooseRange_Callback(hObject, eventdata, handles)
prompt={'Demag Step Starts at: ',...
        'Demag Step Ends at: '};
name='PCA Range';
numlines = 1;
defaultbegin = handles.UniqueDemagSteps(get(handles.popupmenu_PcaDemagBegin, 'value'));
defaultend   = handles.UniqueDemagSteps(get(handles.popupmenu_PcaDemagEnd, 'value'));
defaultanswer={num2str(defaultbegin), num2str(defaultend)};
answer = inputdlg(prompt,name,numlines,defaultanswer);
if ~isempty(answer), 
   startvalue = find(handles.UniqueDemagSteps == str2double(answer{1}));
   endvalue   = find(handles.UniqueDemagSteps == str2double(answer{2}));
   if any([isempty(startvalue), isempty(endvalue)]),
      msgbox('Bad Range, Please re-allocate.','Bad PCA Range','help'); return;
   end
   set(handles.popupmenu_PcaDemagBegin,'Value',startvalue);    
   set(handles.popupmenu_PcaDemagEnd,'Value',endvalue); 
   pushbutton26_Callback(hObject, eventdata, handles) 
end

function MenuPcaMouseRange_Callback(hObject, eventdata, handles)
set(handles.togglebutton6,'Value', get(handles.togglebutton6,'Max')),
togglebutton6_Callback(hObject, eventdata, handles);

function MenuPcaDefualtRange_Callback(hObject, eventdata, handles)
pushbutton46_Callback(hObject, eventdata, handles);


function MenuPcaAnchorOrigin_Callback(hObject, eventdata, handles)
set(handles.checkbox1,'Value', get(handles.checkbox1,'Max')),
checkbox1_Callback(hObject, eventdata, handles);

function MenuPcaExcludeOrigin_Callback(hObject, eventdata, handles)
set(handles.checkbox1,'Value', get(handles.checkbox1,'Min')),
checkbox1_Callback(hObject, eventdata, handles);



%% [Menu] VGP
function MenuVGP_Callback(hObject, eventdata, handles)

function MenuVgpChangeInfo_Callback(hObject, eventdata, handles)
set(handles.radiobutton9,'Value',1);
radiobutton9_Callback(hObject, eventdata, handles);


%% [Menu] View
function MenuView_Callback(hObject, eventdata, handles)

function MenuViewAuto_Callback(hObject, eventdata, handles)
set(handles.togglebutton16,'Value', get(handles.togglebutton16,'Max'));
togglebutton16_Callback(hObject, eventdata, handles)


function MenuViewStopAuto_Callback(hObject, eventdata, handles)
set(handles.togglebutton16,'Value', get(handles.togglebutton16,'Min'));

function MenuViewPreviousPosition_Callback(hObject, eventdata, handles)
pushbutton7_Callback(hObject, eventdata, handles);

function MenuViewNextPosition_Callback(hObject, eventdata, handles)
pushbutton4_Callback(hObject, eventdata, handles);

function MenuViewGotoPosition_Callback(hObject, eventdata, handles)
prompt={'Enter the Position:'};
name='Go to Position';
numlines=1;
defaultanswer={num2str(handles.CurrentPosition)};
answer = inputdlg(prompt,name,numlines,defaultanswer);
if ~isempty(answer),
    set(handles.edit4,'String',answer);
    pushbutton28_Callback(hObject, eventdata, handles);
end

%% [Menu] Layout
function MenuLayout_Callback(hObject, eventdata, handles)

function MenuLayoutWestUp_Callback(hObject, eventdata, handles)
set(handles.togglebutton9,'Value',get(handles.togglebutton9,'Max'));
togglebutton9_Callback(hObject, eventdata, handles);

function MenuLayOut3D_Callback(hObject, eventdata, handles)
set(handles.togglebutton11,'Value',get(handles.togglebutton11,'Max'));
togglebutton11_Callback(hObject, eventdata, handles);

function MenuLayoutVgpOnTop_Callback(hObject, eventdata, handles)
set(handles.radiobutton9,'Value',1);
radiobutton9_Callback(hObject, eventdata, handles);

function MenuLayoutEqualAreaOnTop_Callback(hObject, eventdata, handles)
set(handles.radiobutton10,'Value',1);
radiobutton10_Callback(hObject, eventdata, handles);

function MenuLayoutPositionVsPcaOnTop_Callback(hObject, eventdata, handles)
set(handles.radiobutton8,'Value',1);
radiobutton8_Callback(hObject, eventdata, handles);


%% [Menus] UVIEW
function MenuTools_Callback(hObject, eventdata, handles)



%% [Toolbar] Open
function uipushtool_Open_ClickedCallback(hObject, eventdata, handles)
pushbutton3_Callback(hObject, eventdata, handles);




%% [Toolbar] Save
function uipushtool_Save_ClickedCallback(hObject, eventdata, handles)

H = udir_SaveOption_dlg;
uiwait(H);

saveOptionUDIR = getappdata(0, 'saveOptionUDIR');
rmappdata(0, 'saveOptionUDIR');

switch saveOptionUDIR
    case 0    % cancelled, no data for saving
         return;
    case 1    
         pushbutton33_Callback(hObject, eventdata, handles);     
    case 2    
         pushbutton47_Callback(hObject, eventdata, handles);
    case 3    
         pushbutton31_Callback(hObject, eventdata, handles);
    case 4    
         pushbutton23_Callback(hObject, eventdata, handles);         
end


%% [Toolbar] Print
function uipushtool_Print_ClickedCallback(hObject, eventdata, handles)

[filename, pathname] =  uiputfile({  '*.pdf','PDF file (*.pdf)'},...
                        'Print Whole Figure to PDF file',...
                        [handles.PathName,'\UDIR_Prints.pdf']);

if  ~isequal(filename,0),   
    set(gcf, 'PaperPositionMode', 'auto');
    set(gcf, 'InvertHardCopy', 'off');
    set(gcf, 'PaperType', 'usletter');
    set(gcf, 'PaperOrientation', 'landscape');
    orient rotated; 
    print([pathname,filename], '-loose', '-dpdf', '-r600');
end


%% [Toolbar] SHOW PCA AND INT ON TOP
function uipushtool_ShowPcaOnTop_ClickedCallback(hObject, eventdata, handles)

set(handles.radiobutton8,'Value',1);
radiobutton8_Callback(hObject, eventdata, handles);

%% [Toolbar] Show VGP Plot on Top
function uipushtool_ShowVgpOnTop_ClickedCallback(hObject, eventdata, handles)

set(handles.radiobutton9,'Value',1);
radiobutton9_Callback(hObject, eventdata, handles);


%% [Toolbar] Show Equal Area Plot on Top
function uipushtool_ShowEqualAreaOnTop_ClickedCallback(hObject, eventdata, handles)

set(handles.radiobutton10,'Value',1);
radiobutton10_Callback(hObject, eventdata, handles);


%% [Toolbar] West/Up on
function uitoggletool_WestUp_OnCallback(hObject, eventdata, handles)

set(handles.togglebutton9,'Value',get(handles.togglebutton9,'Max'));
togglebutton9_Callback(hObject, eventdata, handles);



%% [Toolbar] West/Up off
function uitoggletool_WestUp_OffCallback(hObject, eventdata, handles)

set(handles.togglebutton9,'Value',get(handles.togglebutton9,'Min'));
togglebutton9_Callback(hObject, eventdata, handles);


%% [Toolbar] 3-D on
function uitoggletool_3DProjection_OnCallback(hObject, eventdata, handles)

set(handles.togglebutton11,'Value',get(handles.togglebutton11,'Max'));
togglebutton11_Callback(hObject, eventdata, handles)


%% [Toolbar] 3-D off
function uitoggletool_3DProjection_OffCallback(hObject, eventdata, handles)

set(handles.togglebutton11,'Value',get(handles.togglebutton11,'Min'));
togglebutton11_Callback(hObject, eventdata, handles)


%% [Toolbar] Hold off
function uitoggletool_HoldOnAxes_OffCallback(hObject, eventdata, handles)

set(handles.togglebutton8,'Value',get(handles.togglebutton8,'Min'));
togglebutton8_Callback(hObject, eventdata, handles);


%% [Toolbar] Hold on
function uitoggletool_HoldOnAxes_OnCallback(hObject, eventdata, handles)

set(handles.togglebutton8,'Value',get(handles.togglebutton8,'Max'));
togglebutton8_Callback(hObject, eventdata, handles);



