%% [Matlab] Main function
function varargout = UINT(varargin)

% UINT reads *.int files exported from UVIEW, estimates, displays, and saves RPI data 
% using slopes of the best line fit and averages of ratios for NRM and Normalizer 
% intensity data with selectable demagnetization range. 

% Last Modified by Chuang Xuan 15-Apr-2009

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @UINT_OpeningFcn, ...
                   'gui_OutputFcn',  @UINT_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


%% [Matlab] Openning function
function UINT_OpeningFcn(hObject, eventdata, handles, varargin)

set(handles.axes8, 'visible', 'off');
set(handles.axes9, 'visible', 'off');

axes(handles.axes5),
   xlabel('Demag Step');
   ylabel('Normalized Int');
   set(gca,'XMinorTick','on');
   set(gca,'YMinorTick','on');
   set(gca,'XTickLabel','');  
   set(gca,'YTickLabel',''); 
   set(gca,'Ticklength',[0.03;0.08]);
   box on;

axes(handles.axes1),
   xlabel('NRM');
   ylabel('Normalizer');
   set(gca,'XMinorTick','on');
   set(gca,'YMinorTick','on');
   set(gca,'XTickLabel','');  
   set(gca,'YTickLabel',''); 
   set(gca,'Ticklength',[0.03;0.08]);
   box on;

axes(handles.axes4),
   xlabel('Demag Step #');
   ylabel('Ratio');
   set(gca,'XMinorTick','on');
   set(gca,'YMinorTick','on');
   set(gca,'XTickLabel','');  
   set(gca,'YTickLabel',''); 
   set(gca,'Ticklength',[0.03;0.08]);
   box on;

 axes(handles.axes2),
    ylabel('Slope & R');
    set(gca,'YTickLabel',''); 
    set(gca,'XTickLabel','');  
    set(gca,'XMinorTick','on');
    set(gca,'YMinorTick','on');
    set(gca,'Ticklength',[0.01;0.03]);
    box on;
    
axes(handles.axes6),
    ylabel('NRM Ints');
    set(gca,'YTickLabel',''); 
    set(gca,'XTickLabel','');  
    set(gca,'XMinorTick','on');
    set(gca,'YMinorTick','on');
    set(gca,'Ticklength',[0.01;0.03]);
    box on;
    
axes(handles.axes7),
    ylabel('Normalizer Ints');
    set(gca,'YTickLabel',''); 
    set(gca,'XTickLabel','');  
    set(gca,'XMinorTick','on');
    set(gca,'YMinorTick','on');
    set(gca,'Ticklength',[0.01;0.03]);
    box on;    
    
axes(handles.axes3),
   ylabel('Average Ratio & Std');
   xlabel('Row Number');
   set(gca,'YTickLabel',''); 
   set(gca,'XTickLabel','');  
   set(gca,'XMinorTick','on');
   set(gca,'YMinorTick','on');
    set(gca,'Ticklength',[0.01;0.03]);
   box on;
   
handles.grid = 0;
handles.output = hObject;
guidata(hObject, handles);


%% [Matlab] Output function
function varargout = UINT_OutputFcn(hObject, eventdata, handles) 

varargout{1} = handles.output;


%% [Push] Load NRM intensity data
function [hObject, handles] = pushbutton27_Callback(hObject, eventdata, handles)

[FileName,PathName] = uigetfile2({'*.int'},'Load NRM INT Data');
if  ~isequal(FileName,0), % FILE HAS BEEN SELECTED
    handles.filename = FileName;
    handles.pathname = PathName;
    handles.pathnamestring = strrep(PathName, '\', '\\');
    file  = [PathName,FileName];   
    fid = fopen(file);    
        nrmhead     = textscan(fid, '%s', 1, 'delimiter','\n');
        headstring  = nrmhead{1}{1};
        demagCol    = strfind(headstring, 'Int'); 
        handles.nrmNumCol   = 2 + length(demagCol);
        demagstring = headstring(demagCol(1):end);
        demagstring = strrep(demagstring, 'Int', '');
        handles.nrmdemags  = str2num(demagstring);            

        nrmFormatString = '%s  %s';
        for kk = 1:handles.nrmNumCol-2,
            nrmFormatString = [nrmFormatString, '	%f'];  
        end
        
        fseek(fid, 0, 'bof');
        handles.nrmall = textscan(fid, nrmFormatString,'delimiter','\t','headerlines', 1);
   
    fclose(fid); 
    
    handles.nrmNumRow = length(handles.nrmall{1});
    handles.sampleid = handles.nrmall{1};
    handles.position = handles.nrmall{2};
    set(handles.edit_NrmFileName,'String',FileName);
    set(handles.edit_NrmNumRow,'String',num2str(handles.nrmNumRow));
    set(handles.edit_NrmNumDemag,'String',num2str(handles.nrmNumCol-2));
    set(handles.popupmenu_NrmDemagList, 'String', num2cell(handles.nrmdemags));
      
    nrm = handles.nrmall{3};
    for colinrange = 4:handles.nrmNumCol,
        nrm = [nrm, handles.nrmall{colinrange}];
    end
    handles.nrm = nrm;
       
  axes(handles.axes6),
    hold off;
    handles.h6 = plot((1:handles.nrmNumRow)',handles.nrm); hold on;
    ylabel('NRM Ints');
    set(handles.axes6,'XMinorTick','on');
    set(handles.axes6,'YMinorTick','on');
    set(handles.axes6,'Ticklength',[0.01;0.03]);
    set(handles.axes6, 'Xticklabel','');
    set(handles.axes6, 'Fontsize', 9);
    axis tight;
  axes(handles.axes5),
    plot(handles.nrmdemags, handles.nrm(1,:)./max(handles.nrm(1,:)), 'k-o', 'markerfacecolor','r','markersize',5, 'linewidth', 1);
    axis tight;
    xloc = xlim;
    yloc = ylim;
    text(xloc(2), yloc(2), {'\color{red}NRM/NRM(max)'},...
                             'HorizontalAlignment','right', 'verticalalignment', 'top','fontsize', 8); 
    hold off;
    ylabel('Normalized Int');
    xlabel('Demag Step');
    set(handles.axes5,'XMinorTick','on');
    set(handles.axes5,'YMinorTick','on');
    set(handles.axes5,'Ticklength',[0.03;0.08]);
    set(handles.axes5,'Fontsize', 9);    
    if handles.grid == 1, grid on; else grid off; end;
    set(handles.edit_CurrentRow, 'string', '1');
else
    msgbox('Operation cancelled by user.', 'Data loading confirmation','warn') ; return; 
    
end

guidata(hObject, handles);


%% [Push] Load Normalizer intensity data
function [hObject, handles] = pushbutton28_Callback(hObject, eventdata, handles)

[FileName,PathName] = uigetfile2({'*.int'},'Load Normalizer INT Data');

if  ~isequal(FileName,0), % FILE HAS BEEN SELECTED
    file  = [PathName,FileName];  
    fid = fopen(file);  
        armhead           = textscan(fid, '%s', 1, 'delimiter','\n');
        headstring        = armhead{1}{1};
        demagCol          = strfind(headstring, 'Int'); 
        handles.armNumCol = 2 + length(demagCol);
        demagstring       = headstring(demagCol(1):end);
        demagstring       = strrep(demagstring, 'Int', '');
        handles.armdemags = str2num(demagstring);            
        armFormatString   = '%s  %s';
        for kk = 1:handles.armNumCol-2,
            armFormatString = [armFormatString, '	%f'];  
        end
        fseek(fid, 0, 'bof');
        handles.armall = textscan(fid, armFormatString,'delimiter','\t','headerlines', 1);  
    fclose(fid); 
    
    handles.armNumRow = length(handles.armall{1});
    set(handles.edit_ArmFileName,'String',FileName);
    set(handles.edit_ArmNumRow,'String',num2str(handles.armNumRow));
    set(handles.edit_ArmNumDemag,'String',num2str(handles.armNumCol-2));
    set(handles.popupmenu_ArmDemagList, 'String', num2cell(handles.armdemags));
    
    handles.rowstart = 1;
    handles.rowend = min(handles.nrmNumRow, handles.armNumRow);
    handles.demagstart = max(min(handles.nrmdemags), min(handles.armdemags));
    handles.demagend   = min(max(handles.nrmdemags), max(handles.armdemags(1:end-1)));
    handles.alldemags = unique([handles.nrmdemags, handles.armdemags]);
    set(handles.edit_RowStart,'String',num2str(handles.rowstart));
    set(handles.edit_RowEnd,'String',num2str(handles.rowend));
    set(handles.popupmenu_DemagStart,'String',num2cell(handles.alldemags));
    set(handles.popupmenu_DemagEnd,'String',num2cell(handles.alldemags));
    set(handles.popupmenu_DemagStart, 'value', find(handles.alldemags == handles.demagstart));
    set(handles.popupmenu_DemagEnd, 'value', find(handles.alldemags == handles.demagend));
    
    arm = handles.armall{3};
    for colinrange = 4:handles.armNumCol,
        arm = [arm, handles.armall{colinrange}];
    end
    handles.arm = arm;
    
  axes(handles.axes7),
    hold off;
    handles.h7 = plot((1:handles.armNumRow)',handles.arm); hold on;
    ylabel('Normalizer Ints');
    set(handles.axes7,'XMinorTick','on');
    set(handles.axes7,'YMinorTick','on');
    set(handles.axes7,'Ticklength',[0.01;0.03]);
    set(handles.axes7, 'Xticklabel','');
    set(handles.axes7,'Fontsize', 9);
    axis tight;   
  axes(handles.axes5),
    plot(handles.nrmdemags, handles.nrm(1,:)./max(handles.nrm(1,:)), 'k-o', 'markerfacecolor','r','markersize',5, 'linewidth', 1);
    hold on, plot(handles.armdemags, handles.arm(1,:)./max(handles.arm(1,:)), 'k-o', 'markerfacecolor','g','markersize',5, 'linewidth', 1);
    axis tight;
    xloc = xlim;
    yloc = ylim;
    text(xloc(2), yloc(2), {'\color{red}NRM/NRM(max)'; '\color[rgb]{0 .5 0}Normalizer/Normalizer(max)'},...
                             'HorizontalAlignment','right', 'verticalalignment', 'top','fontsize', 8); 
    hold off;
    ylabel('Normalized Int');
    xlabel('Demag Step');
    set(handles.axes5,'XMinorTick','on');
    set(handles.axes5,'YMinorTick','on');
    set(handles.axes5,'Ticklength',[0.03;0.08]);
    set(handles.axes5,'Fontsize', 9);
    if handles.grid == 1, grid on; else grid off; end;    
    set(handles.edit_CurrentRow, 'string', '1');
else
    msgbox('Operation cancelled by user.', 'Data loading confirmation','warn') ; return;   
end
guidata(hObject, handles);


%% [Push] Apply selected data range
function pushbutton37_Callback(hObject, eventdata, handles)

%----------------Prepare Data---------------------    
handles.rowstart   = str2double(get(handles.edit_RowStart, 'string'));
handles.rowend     = str2double(get(handles.edit_RowEnd, 'string'));
handles.demagstart = handles.alldemags(get(handles.popupmenu_DemagStart, 'value'));
handles.demagend   = handles.alldemags(get(handles.popupmenu_DemagEnd, 'value'));
if   any([handles.rowstart > handles.rowend,...
         handles.rowstart > handles.nrmNumRow,...
         handles.rowstart > handles.armNumRow,... 
         handles.rowend   > handles.nrmNumRow,...
         handles.rowend   > handles.armNumRow]),
     msgbox('Bad row range, please check and reallocate.', 'Bad row range message','warn') ; return; 
end
if   any([handles.demagstart > handles.demagend,...
         handles.demagstart > max(handles.nrmdemags),...
         handles.demagstart > max(handles.armdemags),...
         handles.demagend   > max(handles.nrmdemags),...
         handles.demagend   > max(handles.armdemags)]),
     msgbox('Bad demag range, please check and reallocate.', 'Bad demag range message','warn') ; return; 
end
nrmdemags = handles.nrmdemags(find(handles.nrmdemags >= handles.demagstart & handles.nrmdemags <= handles.demagend));
armdemags = handles.armdemags(find(handles.armdemags >= handles.demagstart & handles.armdemags <= handles.demagend));
if any(~(size(nrmdemags) == size(armdemags))),
   msgbox('Bad demag range, please check and reallocate.', 'Bad demag range message','warn') ; return; 
elseif any(~(nrmdemags == armdemags)),
   msgbox('Bad demag range, please check and reallocate.', 'Bad demag range message','warn') ; return; 
end

%----------------Data Initiation---------------------  
handles.row      = (handles.rowstart:handles.rowend)';
handles.rvalue   = nan(size(handles.row));
handles.slope    = nan(size(handles.row));
handles.averatio = nan(size(handles.row));
handles.stdratio = nan(size(handles.row));

handles.nrmstartCol = find(handles.nrmdemags == handles.demagstart);
handles.nrmendCol   = find(handles.nrmdemags == handles.demagend);
handles.armstartCol = find(handles.armdemags == handles.demagstart);
handles.armendCol   = find(handles.armdemags == handles.demagend);
handles.numSelectedDemag = handles.nrmendCol - handles.nrmstartCol + 1;

handles.nrmselected = handles.nrm(handles.rowstart:handles.rowend,handles.nrmstartCol:handles.nrmendCol);
handles.armselected = handles.arm(handles.rowstart:handles.rowend,handles.armstartCol:handles.armendCol);

handles.nrmselected2 = nan(size(handles.nrmselected));
handles.ratios = nan(size(handles.nrmselected));

%----------------Show Selected Data---------------------  
axes(handles.axes6),
    hold off;    
    handles.h6 = plot(handles.row,handles.nrmselected); hold on;
    ylabel('NRM Int');
    set(handles.axes6,'XMinorTick','on');
    set(handles.axes6,'YMinorTick','on');
    set(handles.axes6,'Ticklength',[0.01;0.03]);
    set(handles.axes6,'Xticklabel','');
    set(handles.axes6,'Fontsize', 9);
    axis tight;
    handles.lineonnrm = line([handles.row(1), handles.row(1)], ylim);        
    set(handles.lineonnrm,'linestyle',':','color', 'r', 'EraseMode','xor','parent',handles.axes6);
    handles.markeronnrm = line(handles.row(1).*ones(1,handles.numSelectedDemag),handles.nrmselected(1,:),...
                                'marker','x','markerfacecolor','k','markersize',6,'EraseMode','xor','parent',handles.axes6); 

axes(handles.axes7),
    hold off;    
    handles.h7 = plot(handles.row,handles.armselected); hold on;
    ylabel('Normalizer Int');
    set(handles.axes7,'XMinorTick','on');
    set(handles.axes7,'YMinorTick','on');
    set(handles.axes7,'Ticklength',[0.01;0.03]);
    set(handles.axes7,'Xticklabel','');
    set(handles.axes7,'Fontsize', 9);
    axis tight;
    handles.lineonarm = line([handles.row(1), handles.row(1)], ylim);        
    set(handles.lineonarm,'linestyle',':','color', 'r', 'EraseMode','xor','parent',handles.axes7);
    handles.markeronarm = line(handles.row(1).*ones(1,handles.numSelectedDemag),handles.armselected(1,:),...
                                'marker','x','markerfacecolor','k','markersize',6,'EraseMode','xor','parent',handles.axes7);   

%-------------Calculaton-----------------------
for kk = 1:length(handles.row),
    
    b = polyfit(handles.armselected(kk,:), handles.nrmselected(kk, :),1);
    handles.slope(kk) = b(1);
    handles.nrmselected2(kk,:) = polyval(b, handles.armselected(kk,:));
    R = corrcoef(handles.nrmselected(kk,:), handles.nrmselected2(kk,:));
    handles.rvalue(kk) = R(1,2);
    
    handles.ratios(kk,:) = handles.nrmselected(kk,:)./handles.armselected(kk,:);
    handles.averatio(kk) = mean(handles.ratios(kk,:));
    handles.stdratio(kk) = std(handles.ratios(kk,:));     
    
end 


%-----------Show Calculated Data------------------

handles.rowindexnow = 1;
guidata(hObject, handles);

axes(handles.axes2),
    hold off;
    plot(handles.row, handles.slope, 'marker','o','MarkerSize',3,'color', [1 0 0],'MarkerFaceColor','w'); hold on;
    ylabel('Slope');
    set(gca,'Ycolor',[1 0 0],'Fontsize', 9,'Xticklabel','','Box','off','Ticklength',[0.010;0.03],'XMinorTick','on','YMinorTick','on');
    axis tight;
    handles.lineonax2 = line([handles.row(handles.rowindexnow), handles.row(handles.rowindexnow)], ylim);        
    set(handles.lineonax2,'linestyle',':','color', 'r', 'EraseMode','xor','parent',handles.axes2);
    handles.markeronslope = line(handles.row(handles.rowindexnow),handles.slope(handles.rowindexnow),'marker','o','markerfacecolor','r',...
                                 'markeredgecolor','r','markersize',5,'EraseMode','xor','parent',handles.axes2);    
    
axes(handles.axes8),
    hold off;
    plot(handles.row, handles.rvalue,'marker','o','MarkerSize',3,'color', [0 0 1],'MarkerFaceColor','w'); hold on; 
    axis tight;
    ylabel('R Value');
    set(gca,'Ycolor',[0 0 1],'Fontsize', 9,'Xticklabel','','Box','off','Ticklength',[0.010;0.03],'XMinorTick','on','YMinorTick','on',...
        'Xlim',get(handles.axes2,'Xlim'),'XaxisLocation', 'Top', 'YAxisLocation','right','Color','none','XTickLabel',[],'Layer','top');
    handles.markeronr = line(handles.row(handles.rowindexnow),handles.rvalue(handles.rowindexnow),'marker','o','markerfacecolor','r','markeredgecolor','r',...
                             'markersize',5,'EraseMode','xor','parent',handles.axes8);          
    linkaxes([handles.axes2 handles.axes8],'x');     
    
axes(handles.axes3),
    hold off;
    plot(handles.row, handles.averatio, 'marker','o','MarkerSize',3,'color', [0 0 0],'MarkerFaceColor','w'); hold on;
    ylabel('Ave. Ratio');
    xlabel('Row Number');
    set(gca,'Ycolor',[0 0 0],'Fontsize', 9,'Box','off','Ticklength',[0.010;0.03],'XMinorTick','on','YMinorTick','on');
    axis tight;
    handles.lineonax3 = line([handles.row(handles.rowindexnow), handles.row(handles.rowindexnow)], ylim);        
    set(handles.lineonax3,'linestyle',':','color', 'r', 'EraseMode','xor','parent',handles.axes3);
    handles.markeronaveratio = line(handles.row(handles.rowindexnow),handles.averatio(handles.rowindexnow),'marker','o','markerfacecolor','r',...
                                 'markeredgecolor','r','markersize',5,'EraseMode','xor','parent',handles.axes3);                     
                             
axes(handles.axes9),
    hold off;
    plot(handles.row, handles.stdratio,'marker','o','MarkerSize',3,'color', [0 0.5 0],'MarkerFaceColor','w'); hold on; 
    axis tight;
    ylabel('Std. Ratio');
    set(gca,'Ycolor',[0 0.5 0],'Fontsize', 9,'Xticklabel','','Box','off','Ticklength',[0.010;0.03],'XMinorTick','on','YMinorTick','on',...
        'Xlim',get(handles.axes3,'Xlim'),'XaxisLocation', 'Top', 'YAxisLocation','right','YDir','Reverse','Color','none','XTickLabel',[],'Layer','top');
    handles.markeronstdratio = line(handles.row(handles.rowindexnow),handles.stdratio(handles.rowindexnow),'marker','o','markerfacecolor','r','markeredgecolor','r',...
                             'markersize',5,'EraseMode','xor','parent',handles.axes9);                           
    linkaxes([handles.axes3 handles.axes9],'x');   
    
    Update_RowRelated(hObject, handles);
    guidata(hObject, handles);


%% [Push] Previous row
function pushbutton7_Callback(hObject, eventdata, handles)

handles.rowindexnow = handles.rowindexnow - 1;
if handles.rowindexnow >= 1,
   [hObject, handles] = Update_RowRelated(hObject, handles);
else
   handles.rowindexnow = handles.rowindexnow + 1;
   set(handles.edit_CurrentRow,'String','Reached 1st Row');         
end
guidata(hObject,handles);


%% [Push] Next row
function pushbutton5_Callback(hObject, eventdata, handles)

handles.rowindexnow = handles.rowindexnow + 1;
if handles.rowindexnow <= length(handles.row),
   [hObject, handles] = Update_RowRelated(hObject, handles);
else
   handles.rowindexnow = handles.rowindexnow - 1;
   set(handles.edit_CurrentRow,'String','Reached Last Row');         
end
guidata(hObject,handles);


%% [Push] Go to row
function pushbutton8_Callback(hObject, eventdata, handles)

previousindex = handles.rowindexnow;
InputRow = str2double(get(handles.edit_GotoRow,'String'));
handles.rowindexnow = find(handles.row == InputRow);
if ~isempty(handles.rowindexnow),
   [hObject, handles] = Update_RowRelated(hObject, handles);
else
   handles.rowindexnow = previousindex;
   set(handles.edit_CurrentRow,'String','Not a Valid Row');         
end
guidata(hObject,handles);


%% [Push] Export/save plots
function pushbutton31_Callback(hObject, eventdata, handles)

H = uint_SavePlotOption_dlg;
uiwait(H);

savePlotOption = getappdata(0, 'savePlotOption');
rmappdata(0, 'savePlotOption');

switch savePlotOption
    case 0    % cancelled, no data for saving
         return;
    case 1    
         plotstring = 'DemagInt.bmp';
         h  = findobj(handles.axes5,'type','axes');
         xlimit = get(handles.axes5,'xlim');
         ylimit = get(handles.axes5,'ylim');        
    case 2    
         plotstring = 'NrmNormalizer.bmp';
         h  = findobj(handles.axes1,'type','axes');   
         xlimit = get(handles.axes1,'xlim');
         ylimit = get(handles.axes1,'ylim');         
    case 3    
         plotstring = 'DemagRatio.bmp';
         h  = findobj(handles.axes4,'type','axes'); 
         xlimit = get(handles.axes4,'xlim');
         ylimit = get(handles.axes4,'ylim');         
    case 4    
         plotstring = 'RowNrm.bmp';   
         h  = findobj(handles.axes6,'type','axes'); 
         xlimit = get(handles.axes6,'xlim');
         ylimit = get(handles.axes6,'ylim');         
    case 5    
         plotstring = 'RowNormalizer.bmp';
         h  = findobj(handles.axes7,'type','axes');
         xlimit = get(handles.axes7,'xlim');
         ylimit = get(handles.axes7,'ylim');         
    case 6   
         plotstring = 'RowSlopeR.bmp';
         h1  = findobj(handles.axes2,'type','axes'); 
         h2  = findobj(handles.axes8,'type','axes');
         xlimit = get(handles.axes2,'xlim');
         ylimit1 = get(handles.axes2,'ylim'); 
         ylimit2 = get(handles.axes8,'ylim'); 
    case 7    
         plotstring = 'RowRatios.bmp';
         h1  = findobj(handles.axes3,'type','axes'); 
         h2  = findobj(handles.axes9,'type','axes');
         xlimit = get(handles.axes3,'xlim');
         ylimit1 = get(handles.axes3,'ylim'); 
         ylimit2 = get(handles.axes9,'ylim');        
end

filename = strtok(handles.filename,'.');  
[filename, pathname, FilterIndex] =  uiputfile({  '*.bmp','Windows bitmap (*.bmp)';
                                    '*.fig','MATLAB figure (*.fig)';
                                    '*.eps','EPS Level2 (*.eps)';
                                    '*.tif','TIFF image (*.tif)';
                                    '*.png','Portable Network Graphics (*.png)';
                                    '*.ai','Adobe Illustrator (*.ai)';
                                    '*.jpg','JPEG image (*.jpg)';
                                    '*.pdf','Portable Document Format (*.pdf)';
                                    '*.emf','Enhanced metafile (*.emf)'},...
                                    'Save selected plot as',...
                                    [handles.pathnamestring,'\',filename, ' ', plotstring]);

if  ~isequal(filename,0), 
    
            if savePlotOption >= 1 && savePlotOption <=3,
               newFig = figure('Units', 'Inches', 'Position', [3,3,4.5,3.8]);
               newAxes = copyobj(h,newFig); 
               set(newAxes,'Units','normalized','Position',[0.13 0.11 0.8 0.8]);
               set(newAxes, 'xlim', xlimit);
               set(newAxes, 'ylim', ylimit);
            elseif savePlotOption >= 4 && savePlotOption <=5,
               newFig = figure('Units', 'Inches', 'Position', [3,3,8,2]);
               newAxes = copyobj(h,newFig);                 
               set(newAxes,'Units','normalized','Position',[0.13 0.11 0.8 0.8]);
               set(newAxes, 'xlim', xlimit);
               set(newAxes, 'ylim', ylimit);    
            elseif savePlotOption >= 6 && savePlotOption <=7,
               newFig = figure('Units', 'Inches', 'Position', [3,3,8,2]);
               newAxes1 = copyobj(h1,newFig); 
               newAxes2 = copyobj(h2,newFig);
               set(newAxes1,'Units','normalized','Position',[0.1 0.1 0.75 0.8]);
               set(newAxes2,'Units','normalized','Position',[0.1 0.1 0.75 0.8]);               
               set(newAxes1, 'xlim', xlimit);
               set(newAxes1, 'ylim', ylimit1);     
               set(newAxes2, 'xlim', xlimit);
               set(newAxes2, 'ylim', ylimit2);                 
            end
            
    if FilterIndex == 3,
       saveas(newFig,[pathname,filename], 'psc2');
    else   
       saveas(newFig,[pathname,filename]);
    end
    
    close(newFig);
    
end


%% [Push] Export/save normalized intensity data
function pushbutton9_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton9 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

filename = strtok(handles.filename,'.');  
[filename, pathname] = uiputfile({  '*.txt','Text File (*.txt)'},...
                                    'Export Normalized Intensity Data As',...
                                    [handles.pathnamestring,'\',filename,'.rpi.txt']);
if  ~isequal(filename,0),                            
    rpiout = [handles.slope, handles.rvalue, handles.averatio, handles.stdratio];
    fid = fopen([pathname,filename], 'wt');
        fprintf(fid, 'Sample_ID	Position    Slope   R_Value Ave_Ratio   Std_Ratio\n');
        for kk = 1:length(handles.row),
            fprintf(fid, [handles.sampleid{handles.rowstart-1+kk},...
                          '    ',handles.position{handles.rowstart-1+kk},...
                          '   ', '%10.5e  %10.5e  %10.5e  %10.5e\n'],rpiout(kk,:));
        end
    fclose(fid); 
end


%% [TOGGLE] Automatic display
function togglebutton1_Callback(hObject, eventdata, handles)

if  get(handles.togglebutton1,'Value') == get(handles.togglebutton1,'Max'), 

    movespeed =  str2double(get(handles.edit_AutoSpeed,'String'));

    if get(handles.checkbox_AutoDir,'Value') == get(handles.checkbox_AutoDir,'Max'), 
        for autoindex = handles.rowindexnow:-1:1,
            if get(handles.togglebutton1,'Value') == get(handles.togglebutton1,'Min'), break; end
            handles.rowindexnow = handles.rowindexnow - 1;
            if handles.rowindexnow >= 1,
               [hObject, handles] = Update_RowRelated(hObject, handles);
            else
               handles.rowindexnow = handles.rowindexnow + 1; 
               set(handles.edit_CurrentRow,'String','Reached 1st Row');
               set(handles.togglebutton1,'Value',get(handles.togglebutton1,'Min'));
               break;
            end      
           pause(movespeed);  
        end   
    else
        for autoindex = handles.rowindexnow:length(handles.row),
            if get(handles.togglebutton1,'Value') == get(handles.togglebutton1,'Min'), break; end
            handles.rowindexnow = handles.rowindexnow + 1;
            if handles.rowindexnow <= length(handles.row),
               [hObject, handles] = Update_RowRelated(hObject,handles);
            else
               handles.rowindexnow = handles.rowindexnow - 1; 
               set(handles.edit_CurrentRow,'String','Reached Last Row');    
               set(handles.togglebutton1,'Value',get(handles.togglebutton1,'Min'));
               break;
            end
           pause(movespeed);  
        end
    end
else
    return
end

guidata(hObject,handles);
    
    
%% [Function] Update row related items (edits & plots)
function [hObject, handles] = Update_RowRelated(hObject, handles)

set(handles.edit_CurrentRow, 'string', handles.row(handles.rowindexnow));
set(handles.edit_GotoRow, 'string', handles.row(handles.rowindexnow));
[hObject,handles] = Update_plotsAtrow(hObject,handles);


%% [Function] Update row related plots
function [hObject, handles] = Update_plotsAtrow(hObject, handles)

ylimax2  = get(handles.axes2, 'ylim');
ylimax3  = get(handles.axes3,'ylim');
ylimax6  = get(handles.axes6, 'ylim');
ylimax7  = get(handles.axes7, 'ylim');

set(handles.lineonnrm, 'xdata',[handles.row(handles.rowindexnow), handles.row(handles.rowindexnow)],'ydata',ylimax6);
set(handles.markeronnrm, 'xdata',handles.row(handles.rowindexnow).*ones(1,handles.numSelectedDemag),'ydata',handles.nrmselected(handles.rowindexnow,:));

set(handles.lineonarm, 'xdata',[handles.row(handles.rowindexnow), handles.row(handles.rowindexnow)],'ydata',ylimax7);
set(handles.markeronarm, 'xdata',handles.row(handles.rowindexnow).*ones(1,handles.numSelectedDemag),'ydata',handles.armselected(handles.rowindexnow,:));

set(handles.lineonax2, 'xdata',[handles.row(handles.rowindexnow), handles.row(handles.rowindexnow)],'ydata',ylimax2);
set(handles.markeronslope, 'xdata',handles.row(handles.rowindexnow),'ydata',handles.slope(handles.rowindexnow));
set(handles.markeronr, 'xdata',handles.row(handles.rowindexnow),'ydata',handles.rvalue(handles.rowindexnow));

set(handles.lineonax3, 'xdata',[handles.row(handles.rowindexnow), handles.row(handles.rowindexnow)],'ydata',ylimax3);
set(handles.markeronaveratio, 'xdata',handles.row(handles.rowindexnow),'ydata',handles.averatio(handles.rowindexnow));
set(handles.markeronstdratio, 'xdata',handles.row(handles.rowindexnow),'ydata',handles.stdratio(handles.rowindexnow));

drawnow;
Update_coercivityplot(hObject, handles);
Update_slopeplot(hObject, handles);
Update_ratioplot(hObject, handles);


%% [Function] Update slope vs demag plot
function Update_slopeplot(hObject, handles)

axes(handles.axes1),
    plot(handles.nrmselected(handles.rowindexnow,:), handles.armselected(handles.rowindexnow,:), 'ko','markersize', 5,'markerfacecolor', 'r');
    hold on, plot(handles.nrmselected2(handles.rowindexnow,:), handles.armselected(handles.rowindexnow,:),'b-', 'linewidth',1);
    xloc = xlim;
    yloc = ylim;
    text(xloc(2), yloc(2), {['Slope: ', num2str(handles.slope(handles.rowindexnow))];...
                            ['R: ', num2str(handles.rvalue(handles.rowindexnow))]},...
                             'HorizontalAlignment','right', 'verticalalignment', 'top','color',[0.87    0.49   0],'fontsize', 8); 
    set(gca,'XMinorTick','on');
    set(gca,'YMinorTick','on');
    ylabel('Normalizer');
    xlabel('NRM');
    set(gca,'Ticklength',[0.03;0.08]);
    set(gca, 'fontsize', 9);
    if handles.grid == 1, grid on; else grid off; end;
    hold off;  

    
%% [Function] Update ratio vs demag plot
function  Update_ratioplot(hObject, handles)   
    
axes(handles.axes4),
    plot(1:handles.nrmendCol-handles.nrmstartCol+1, handles.ratios(handles.rowindexnow,:), 'ks','markersize', 5,'markerfacecolor', 'g');
    hold on, line(xlim, [handles.averatio(handles.rowindexnow,:),handles.averatio(handles.rowindexnow,:)], 'linewidth',1, 'color','b','linestyle',':');
    xloc = xlim;
    yloc = ylim;
    text(xloc(2), yloc(2), {['Ave. Ratio: ', num2str(handles.averatio(handles.rowindexnow))];...
                            ['Std.: ', num2str(handles.stdratio(handles.rowindexnow))]},...
                             'HorizontalAlignment','right', 'verticalalignment', 'top','color',[0.87    0.49   0],'fontsize', 8); 
    set(gca,'XMinorTick','on');
    set(gca,'YMinorTick','on');
    ylabel('Ratios');
    xlabel('Demag Step #');
    set(gca,'Ticklength',[0.03;0.08]);
    set(gca,'fontsize', 9);
    if handles.grid == 1, grid on; else grid off; end;    
    hold off; 
    
%% [Function] Update int vs demag plot
function  Update_coercivityplot(hObject, handles)   
    
axes(handles.axes5),
    plot(handles.nrmdemags(handles.nrmstartCol:handles.nrmendCol), handles.nrmselected(handles.rowindexnow,:)./max(handles.nrmselected(handles.rowindexnow,:)), 'k-o', 'markerfacecolor','r','markersize',5, 'linewidth', 1);
    hold on, plot(handles.armdemags(handles.armstartCol:handles.armendCol), handles.armselected(handles.rowindexnow,:)./max(handles.armselected(handles.rowindexnow,:)), 'k-o', 'markerfacecolor','g','markersize',5, 'linewidth', 1);
    axis tight;
    xloc = xlim;
    yloc = ylim;
    text(xloc(2), yloc(2), {'\color{red}NRM/NRM(max)'; '\color[rgb]{0 .5 0}Normalizer/Normalizer(max)'},...
                             'HorizontalAlignment','right', 'verticalalignment', 'top','fontsize', 8); 
    hold off;
    ylabel('Normalized Int');
    xlabel('Demag Step');
    set(handles.axes5,'XMinorTick','on');
    set(handles.axes5,'YMinorTick','on');
    set(handles.axes5,'Ticklength',[0.03;0.08]);
    set(handles.axes5,'Fontsize', 9);
    if handles.grid == 1, grid on; else grid off; end;    


%% [Function] uigetfile2
function [filename, pathname, filterindex] = uigetfile2(varargin)

%UIGETFILE2 Standard open file dialog box which remembers last opened folder
%   UIGETFILE2 is a wrapper for Matlab's UIGETFILE function which adds the
%   ability to remember the last folder opened.  UIGETFILE2 stores
%   information about the last folder opened in a mat file which it looks
%   for when called.
%
%   UIGETFILE2 can only remember the folder used if the current directory
%   is writable so that a mat file can be stored.  Only successful file
%   selections update the folder remembered.  If the user cancels the file
%   dialog box then the remembered path is left the same.
%
%   Usage is the same as UIGETFILE.
%
%
%   See also UIGETFILE, UIPUTFILE, UIGETDIR.

%   Written by Chris J Cannell and Aditya Gadre
%   Contact ccannell@mindspring.com for questions or comments.
%   12/05/2005

% name of mat file to save last used directory information
lastDirMat = 'lastUsedDir.mat';
% save the present working directory
savePath = pwd;
% set default dialog open directory to the present working directory
lastDir = savePath;
% load last data directory
if exist(lastDirMat, 'file') ~= 0
    % lastDirMat mat file exists, load it
    load('-mat', lastDirMat)
    % check if lastDataDir variable exists and contains a valid path
    if (exist('lastUsedDir', 'var') == 1) && ...
            (exist(lastUsedDir, 'dir') == 7)
        % set default dialog open directory
        lastDir = lastUsedDir;
    end
end

% load folder to open dialog box in
cd(lastDir);
% call uigetfile with arguments passed from uigetfile2 function
[filename, pathname, filterindex] = uigetfile(varargin{:});
% change path back to original working folder
cd(savePath);

% if the user did not cancel the file dialog then update lastDirMat mat
% file with the folder used
if ~isequal(filename,0) && ~isequal(pathname,0)
    try
        % save last folder used to lastDirMat mat file
        lastUsedDir = pathname;
        save(lastDirMat, 'lastUsedDir');
    catch
        % error saving lastDirMat mat file, display warning, the folder
        % will not be remembered
        disp(['Warning: Could not save file ''', lastDirMat, '''']);
    end
end


%% [popupmenu]
function popupmenu_ArmDemagList_Callback(hObject, eventdata, handles)
function popupmenu_ArmDemagList_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function popupmenu_NrmDemagList_Callback(hObject, eventdata, handles)
function popupmenu_NrmDemagList_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function popupmenu_DemagStart_Callback(hObject, eventdata, handles)
function popupmenu_DemagStart_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function popupmenu_DemagEnd_Callback(hObject, eventdata, handles)
function popupmenu_DemagEnd_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


%% [Edit]
function edit_NrmFileName_Callback(hObject, eventdata, handles)
function edit_NrmFileName_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit_NrmNumRow_Callback(hObject, eventdata, handles)
function edit_NrmNumRow_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit_NrmNumDemag_Callback(hObject, eventdata, handles)
function edit_NrmNumDemag_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit_ArmFileName_Callback(hObject, eventdata, handles)
function edit_ArmFileName_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit_ArmNumRow_Callback(hObject, eventdata, handles)
function edit_ArmNumRow_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit_ArmNumDemag_Callback(hObject, eventdata, handles)
function edit_ArmNumDemag_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit_CurrentRow_Callback(hObject, eventdata, handles)
function edit_CurrentRow_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit_AutoSpeed_Callback(hObject, eventdata, handles)
function edit_AutoSpeed_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit_GotoRow_Callback(hObject, eventdata, handles)
function edit_GotoRow_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit_RowStart_Callback(hObject, eventdata, handles)
function edit_RowStart_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit_RowEnd_Callback(hObject, eventdata, handles)
function edit_RowEnd_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


%% [Checkbox]
function checkbox_AutoDir_Callback(hObject, eventdata, handles)

    
%% [MENU] File
function MenuFile_Callback(hObject, eventdata, handles)

function MenuFileLoadNrm_Callback(hObject, eventdata, handles)
pushbutton27_Callback(hObject, eventdata, handles);

function MenuFileLoadArm_Callback(hObject, eventdata, handles)
pushbutton28_Callback(hObject, eventdata, handles);

function MenuFileSaveData_Callback(hObject, eventdata, handles)
pushbutton9_Callback(hObject, eventdata, handles);

function MenuFileSavePlot_Callback(hObject, eventdata, handles)
pushbutton31_Callback(hObject, eventdata, handles);

function MenuFilePrintFigure_Callback(hObject, eventdata, handles)
uipushtool6_ClickedCallback(hObject, eventdata, handles);


%% [MENU] Plot
function MenuPlot_Callback(hObject, eventdata, handles)

function MenuPlotZoomOn_Callback(hObject, eventdata, handles)

function MenuPlotZoomOff_Callback(hObject, eventdata, handles)

function MenuPlotPanOn_Callback(hObject, eventdata, handles)

function MenuPlotDataCursorOn_Callback(hObject, eventdata, handles)

function MenuPlotGridOn_Callback(hObject, eventdata, handles)

        handles.grid  = 1;
        axes(handles.axes6),grid on;
        axes(handles.axes7),grid on;
        axes(handles.axes2),grid on;
        axes(handles.axes8),grid on;
        axes(handles.axes3),grid on;
        axes(handles.axes9),grid on;
        guidata(hObject, handles);
        Update_RowRelated(hObject, handles);

function MenuPlotGridOff_Callback(hObject, eventdata, handles)

        handles.grid = 0;
        axes(handles.axes6),grid off;
        axes(handles.axes7),grid off;
        axes(handles.axes2),grid off;
        axes(handles.axes8),grid off;
        axes(handles.axes3),grid off;
        axes(handles.axes9),grid off;
        guidata(hObject, handles);
        Update_RowRelated(hObject, handles);
        

%% [MENU] View

function MenuView_Callback(hObject, eventdata, handles)

function MenuViewAuto_Callback(hObject, eventdata, handles)
set(handles.togglebutton1,'Value', get(handles.togglebutton1,'Max'));
togglebutton1_Callback(hObject, eventdata, handles);

function MenuViewStopAuto_Callback(hObject, eventdata, handles)
set(handles.togglebutton1,'Value', get(handles.togglebutton1,'Min'));

function MenuViewPrevious_Callback(hObject, eventdata, handles)
pushbutton7_Callback(hObject, eventdata, handles);

function MenuViewNext_Callback(hObject, eventdata, handles)
pushbutton5_Callback(hObject, eventdata, handles);

function MenuViewGoto_Callback(hObject, eventdata, handles)
prompt={'Enter the Row number:'};
name='Go to Row';
numlines=1;
defaultanswer={num2str(handles.rowindexnow)};
answer = inputdlg(prompt,name,numlines,defaultanswer);

if ~isempty(answer),
    set(handles.edit_GotoRow,'String',answer);
    pushbutton8_Callback(hObject, eventdata, handles);
end


%% [MENU] Tools

function MenuTools_Callback(hObject, eventdata, handles)

function MenuToolsUVIEW_Callback(hObject, eventdata, handles)
UVIEW;

function MenuToolsUDIR_Callback(hObject, eventdata, handles)
UDIR;

%% [Toolbar] Grid off
function uitoggletool_Grid_OffCallback(hObject, eventdata, handles)
MenuPlotGridOff_Callback(hObject, eventdata, handles)

%% [Toolbar] Grid on
function uitoggletool_Grid_OnCallback(hObject, eventdata, handles)
MenuPlotGridOn_Callback(hObject, eventdata, handles)


%% [Toolbar] Load Files
function uipushtool_LoadFile_ClickedCallback(hObject, eventdata, handles)
[hObject, handles] = pushbutton27_Callback(hObject, eventdata, handles);
[hObject, handles] = pushbutton28_Callback(hObject, eventdata, handles);
guidata(hObject, handles);


%% [Toolbar] Save
function uipushtool5_ClickedCallback(hObject, eventdata, handles)

H = uint_SaveOption_dlg;
uiwait(H);

saveOption = getappdata(0, 'saveOption');
rmappdata(0, 'saveOption');

switch saveOption
    case 0    % cancelled, no data for saving
         return;
    case 1    
         pushbutton9_Callback(hObject, eventdata, handles);     
    case 2    
         pushbutton31_Callback(hObject, eventdata, handles);
end

%% [Toolbar] Print
function uipushtool6_ClickedCallback(hObject, eventdata, handles)

[filename, pathname] =  uiputfile({  '*.pdf','PDF file (*.pdf)'},...
                        'Print Whole Figure to PDF file',...
                        [handles.pathnamestring,'\UINT_Prints.pdf']);

if  ~isequal(filename,0),   
    set(gcf, 'PaperPositionMode', 'auto');
    set(gcf, 'InvertHardCopy', 'off');
    set(gcf, 'PaperType', 'usletter');
    set(gcf, 'PaperOrientation', 'landscape');
    orient rotated; 
    print([pathname,filename], '-loose', '-dpdf', '-r600');
end



