
%% [Matlab] Main function
function varargout = UVIEW(varargin)

% UVIEW allows users to open and easily walk through direct output data file from the 
% U-channel magnetometer measurement system as well as to correct detected flux jumps 
% in the data and export *.dir and *.int files for further treatment in 
% UDIR and UINT respectively

% Last Modified by Chuang Xuan on 20-Apr-2009

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @UVIEW_OpeningFcn, ...
                   'gui_OutputFcn',  @UVIEW_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


%% [Matlab] Openning function
function UVIEW_OpeningFcn(hObject, eventdata, handles, varargin)

handles.ColumnsMeasurement = [1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,22,23];
handles.FormatStringMeasurement = '%s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %s %s %s %f %f %s %s %s %s %s';
set(handles.radiobutton4, 'value',1); % DEFAULT PLOTING PARAMETER IS 'Xint, Yint, Zint'
set(handles.axes1, 'Visible','on');
set(handles.axes2, 'Visible','off');
set(handles.axes3, 'Visible','off');
set(handles.axes4, 'Visible','off');    

handles.output = hObject;
guidata(hObject, handles);


%% [Matlab] Output function
function varargout = UVIEW_OutputFcn(hObject, eventdata, handles) 

varargout{1} = handles.output;


%% [Toolbar] OPEN
function uipushtool1_ClickedCallback(hObject, eventdata, handles)

% GET MEASUREMENT FILE FORMAT INFROMATION. 
H = uview_Data_File_Format_dlg;
uiwait(H);
dataFormatInfo = getappdata(0, 'dataFormatInfo');
rmappdata(0,'dataFormatInfo');

% IF USER ABORT FILE FORMAT CONFIRMATION, NO FURTHER ACTION NEEDED.
if any(isnan(dataFormatInfo)), 
   msgbox('Operation cancelled by user.', 'Operation Message','warn') ; 
   return;
end

% IF USED CONFIRMED FILE FORMAT, IDENTIFY DATA TYPE FOR FUTURE CITING
switch dataFormatInfo(1), 
    case 1
         handles.DataType = 'NRM';
    case 2
         handles.DataType = 'ARM';
    case 3
         handles.DataType = 'ARMAQ';
    case 4
         handles.DataType = 'IRM';
    case 5
         handles.DataType = 'BACK300';
    case 6
         handles.DataType = 'BACK950';
end

% IF FILE IS NOT IN UF DEFAULT FORMAT, ASK FOR FORMAT FILE
if  dataFormatInfo(2)==0, 
    [FileName1,PathName1] = uigetfile2({'*.txt'},'Load Your Measurement Format File');
    if  ~isequal(FileName1,0), % FILE HAS BEEN SELECTED
        file  = [PathName1,FileName1];
        fid = fopen(file);
        filestring = textscan(fid, '%s   %s','delimiter','\t','headerlines', 47);
        fclose(fid); 
        handles.FormatStringMeasurement = filestring{2}{1};
        kkend = length(filestring{2})-1;
        ColumnsMeasurement = zeros(kkend, 1);
        for kk = 1:kkend,
            ColumnsMeasurement(kk) = str2num(filestring{2}{kk+1});
        end
        handles.ColumnsMeasurement = ColumnsMeasurement;
        button2 = questdlg('Your Measurement Format File has been loaded. Locate and load your Measurement File now?','Load Measurement File Confirmation','Yes');
        if ~strcmp(button2, 'Yes'), return; end;    
    else 
        msgbox('Operation cancelled by user, no format file loaded.', 'Format file loading confirmation','warn') ; return; 
    end
end


% LOAD MEASUREMENT FILE AND GET DATA OUT FROM IT
[FileName,PathName] = uigetfile2({'*.dat'; '*.DAT'; '*.TXT'; '*.txt'},'Load Your Measurement Data File');

if  ~isequal(FileName,0), % FILE HAS BEEN SELECTED
    
    % RECORD MEASUREMENT FILE NAME, PATH, PATHSTRING FOR POSSIBLE FUTURE CITING
    handles.filename = FileName;
    handles.pathname = PathName;
    handles.pathnamestring = strrep(PathName, '\', '\\');
    set(handles.edit5,'String',FileName);
    
    % LOAD FILE
    handles.numCol = length(strfind(handles.FormatStringMeasurement, '%'));
    inputString = '%s';
    for kk = 1:handles.numCol-1,
        inputString = [inputString, '  %s'];
    end
    file  = [PathName,FileName];
    
    fid = fopen(file);
        handles.filehead = textscan(fid, inputString, 1, 'delimiter','\t');
        fseek(fid, 0, 'bof');
        handles.cellstring = textscan(fid, inputString,'delimiter','\t','headerlines', 1);    
        fseek(fid, 0, 'bof');
        handles.celldata = textscan(fid, handles.FormatStringMeasurement,'delimiter','\t','headerlines', 1);
    fclose(fid);   
 
    % DEFINE DEMAG AXIS FROW WHICH DEMAG STEPS WILL BE ACQUIRED (USUALLY, AF Z)
    demagaxis = handles.ColumnsMeasurement(6);
    
    % IF ZXY DEMAG SEQUENCE IS  USED (QUITE SPECIAL, IN MY CASE, ONLY NRM FOR SOME
    % ARCTIC SAMPLES), USE AF Y TO GET DEMAG STEPS 
    if ~isempty(strfind(FileName, 'zxy')) || ~isempty(strfind(FileName, 'ZXY')) || strcmp(handles.DataType, 'ARM'),      
       demagaxis = handles.ColumnsMeasurement(5);
    end

    % GET DATA FROM MEASUREMENT FILE
    handles.sampleid  =  handles.celldata{handles.ColumnsMeasurement(1)};
    handles.position  =  handles.celldata{handles.ColumnsMeasurement(2)};
    handles.demag     =  handles.celldata{demagaxis}; 
    
    handles.decl      =  handles.celldata{handles.ColumnsMeasurement(7)};
    handles.incl      =  handles.celldata{handles.ColumnsMeasurement(8)};
    handles.int       =  handles.celldata{handles.ColumnsMeasurement(9)};
    
    handles.xint      =  handles.celldata{handles.ColumnsMeasurement(10)}; % XINT = XVT.*XCORR [UNIT: A/m^2].
    handles.xmean     =  handles.celldata{handles.ColumnsMeasurement(11)}; % XMEAN IS DERECT MEASUREMENT [UNIT:VOLTAGE] USEFUL FOR FJ CORRECTION.
    handles.xcorr     =  handles.celldata{handles.ColumnsMeasurement(12)}; % XCORR = XMEAN-DRIFT-TRAY [UNIT:VOLTAGE]. DRIFT IS THE LINE LINKING THE FIRST AND LAST READING OF XMEAN.
    
    handles.yint      =  handles.celldata{handles.ColumnsMeasurement(13)};
    handles.ymean     =  handles.celldata{handles.ColumnsMeasurement(14)};
    handles.ycorr     =  handles.celldata{handles.ColumnsMeasurement(15)};    
    
    handles.zint      =  handles.celldata{handles.ColumnsMeasurement(16)};
    handles.zmean     =  handles.celldata{handles.ColumnsMeasurement(17)};
    handles.zcorr     =  handles.celldata{handles.ColumnsMeasurement(18)};    
    
    handles.leader    =  handles.celldata{handles.ColumnsMeasurement(19)};
    handles.trailer   =  handles.celldata{handles.ColumnsMeasurement(20)};

    % INITIAL PROCESSING OF DATA    
    handles.xvt = handles.xcorr./handles.xint;
    handles.yvt = handles.ycorr./handles.yint; 
    handles.zvt = handles.zcorr./handles.zint;
    % CONVERT FACTOR FROM VOLTAGE TO A/m^2, SHOULD BE CONSTANT, TO BE MORE
    % RELIABLE, IT HAS BEEN CALCULATED FROM THE ORIGINAL DATA FOR EACH POSITION,
    % AND WILL BE SUSED FOR CALCULATING NEW XINT, YINT, OR ZINT IF ANY FJ 
    % CORRECTION IS APPLIED.
    
    handles.numRow = length(handles.sampleid);
    
    handles.samples = unique(handles.sampleid);
    handles.samplenum = length(handles.samples);
    set(handles.edit15,'String',num2str(handles.samplenum));
    set(handles.listbox1,'String',handles.samples);
    
    handles.demags = unique(handles.demag);
    handles.demagnum = length(handles.demags);
    set(handles.edit14,'String',num2str(handles.demagnum));  
    
    % SET INITIAL SAMPLE AND DEMAG STEP FOR VIEWING
    handles.SampleIndexNow = 1;
    handles.DemagIndexNow = 1;
    
    guidata(hObject,handles); % SAVE HANDLES DATA
         
    update_index(hObject, handles);
    handles = guidata(gcbo);  % GET UPDATED HANDLES DATA
    set(handles.popupmenu4, 'string', handles.currentdemags);
    set(handles.popupmenu4, 'value', 1);
    set(handles.popupmenu6, 'string', handles.currentdemags);
    set(handles.popupmenu6, 'value', length(handles.currentdemags));
    
    set(handles.listbox1, 'value', handles.SampleIndexNow);
    set(handles.listbox3,'String',num2cell(handles.demags));
    set(handles.listbox3, 'value', handles.DemagIndexNow);
    set(handles.edit2,'String',handles.samples(handles.SampleIndexNow));
    set(handles.edit3,'String',handles.currentdemags(handles.DemagIndexNow));

    update_data(hObject, handles);

else
    msgbox('Operation cancelled by user, no measurement file loaded.', 'Measurement file loading confirmation','warn') ; return; 
    
end

guidata(hObject,handles);



%% [PUSH] PREVIOUS SAMPLE
function pushbutton16_Callback(hObject, eventdata, handles)

if  handles.samplenum == 1,
    set(handles.edit2,'String','Only 1 sample in file');
    pause (0.5);
    set(handles.edit2,'String',handles.samples(handles.SampleIndexNow));
    return
else
    
    handles.SampleIndexNow = handles.SampleIndexNow - 1;

    if handles.SampleIndexNow >= 1,
       handles.DemagIndexNow = 1;
       guidata(hObject,handles);
       
       update_index(hObject, handles); 
       handles = guidata(gcbo);
       set(handles.popupmenu4, 'string', handles.currentdemags);
       set(handles.popupmenu4, 'value', 1);
       set(handles.popupmenu6, 'string', handles.currentdemags);
       set(handles.popupmenu6, 'value', length(handles.currentdemags));
       update_data(hObject, handles);    
       set(handles.listbox1, 'value', handles.SampleIndexNow);
       set(handles.listbox3, 'string', num2cell(handles.currentdemags));
       set(handles.listbox3, 'value', handles.DemagIndexNow);
       set(handles.edit2,'String',handles.samples(handles.SampleIndexNow));
       set(handles.edit3,'String',num2str(handles.currentdemags(handles.DemagIndexNow)));
       
    else
        handles.SampleIndexNow = handles.SampleIndexNow + 1;
        guidata(hObject,handles);
        set(handles.edit2,'String','Reached First Sample.');
        pause (0.5);
        set(handles.edit2,'String',handles.samples(handles.SampleIndexNow));

    end
end


%% [PUSH] NEXT SAMPLE
function pushbutton14_Callback(hObject, eventdata, handles)

if  handles.samplenum == 1,
    set(handles.edit2,'String','Only 1 sample in file');
    pause (0.5);
    set(handles.edit2,'String',handles.samples(handles.SampleIndexNow));
    return
else
    
    handles.SampleIndexNow = handles.SampleIndexNow + 1;

    if handles.SampleIndexNow <= handles.samplenum,
       handles.DemagIndexNow = 1;
       guidata(hObject,handles);
       
       update_index(hObject, handles);  
       handles = guidata(gcbo);
       set(handles.popupmenu4, 'string', handles.currentdemags);
       set(handles.popupmenu4, 'value', 1);
       set(handles.popupmenu6, 'string', handles.currentdemags);
       set(handles.popupmenu6, 'value', length(handles.currentdemags));
       update_data(hObject, handles);      
       set(handles.listbox1, 'value', handles.SampleIndexNow);
       set(handles.listbox3, 'string', num2cell(handles.currentdemags));
       set(handles.listbox3, 'value', handles.DemagIndexNow);
       set(handles.edit2,'String',handles.samples(handles.SampleIndexNow));
       set(handles.edit3,'String',num2str(handles.currentdemags(handles.DemagIndexNow)));
              
    else
        handles.SampleIndexNow = handles.SampleIndexNow - 1;
        guidata(hObject,handles);
        set(handles.edit2,'String','Reached Last Sample.');
        pause (0.5);
        set(handles.edit2,'String',handles.samples(handles.SampleIndexNow));

    end
end
   
   
%% [PUSH] PREVIOUS DEMAG
function pushbutton3_Callback(hObject, eventdata, handles)

if get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
  msgbox('Multiple demag steps data are shown. To view data from individual demag step, please toggle off ''View Multiple Steps of This Sample''.', 'Warning message','warn'); 
  return        
end  

handles.DemagIndexNow = handles.DemagIndexNow - 1;
guidata(hObject,handles);

if handles.DemagIndexNow >= 1,
   update_index(hObject,  handles);
   handles = guidata(gcbo);
   update_data(hObject, handles);   
   set(handles.listbox3, 'value', handles.DemagIndexNow);
   set(handles.edit3,'String',num2str(handles.currentdemags(handles.DemagIndexNow)));
   
else
   handles.DemagIndexNow = handles.DemagIndexNow + 1;
   guidata(hObject,handles);
   set(handles.edit3,'String','Reached First Demag');
   pause (0.5);
   set(handles.edit3,'String',num2str(handles.currentdemags(handles.DemagIndexNow)));
    
end



%% [PUSH] NEXT DEMAG
function pushbutton15_Callback(hObject, eventdata, handles)

if get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
  msgbox('Multiple demag steps data are shown. To view data from individual demag step, please toggle off ''View Multiple Steps of This Sample''.', 'Warning message','warn'); 
  return        
end  

handles.DemagIndexNow = handles.DemagIndexNow + 1;
guidata(hObject,handles);

if handles.DemagIndexNow <= length(handles.currentdemags),
   update_index(hObject, handles);
   handles = guidata(gcbo);
   update_data(hObject, handles);   
   set(handles.listbox3, 'value', handles.DemagIndexNow);
   set(handles.edit3,'String',num2str(handles.currentdemags(handles.DemagIndexNow)));
   
else
   handles.DemagIndexNow = handles.DemagIndexNow - 1;
   guidata(hObject,handles);
   set(handles.edit3,'String','Reached Last Demag');
   pause (0.5);
   set(handles.edit3,'String',num2str(handles.currentdemags(handles.DemagIndexNow)));
    
end



%% [PUSH] FJ CORRECTION
function pushbutton21_Callback(hObject, eventdata, handles)


currentSample = handles.samples(handles.SampleIndexNow);
currentDemag  = num2str(handles.currentdemags(handles.DemagIndexNow));
setappdata(0, 'currentSample', currentSample);
setappdata(0, 'currentDemag' , currentDemag );
H = uview_FJ_Check_Axis_dlg;
uiwait(H);

axisOption = getappdata(0, 'axisOption');
rmappdata(0, 'currentSample');
rmappdata(0, 'currentDemag' );
rmappdata(0, 'axisOption'   );

switch axisOption
    case 0
         return;
    case 1
         set(handles.radiobutton16, 'Value', get(handles.radiobutton16,'Max'));
         fjData = handles.xmean(handles.currentview);
         ylabelstring = 'Xmean';
    case 2
         set(handles.radiobutton20, 'Value', get(handles.radiobutton20,'Max'));
         fjData = handles.ymean(handles.currentview);
         ylabelstring = 'Ymean';
    case 3
         set(handles.radiobutton23, 'Value', get(handles.radiobutton23,'Max'));
         fjData = handles.zmean(handles.currentview);  
         ylabelstring = 'Zmean';
end

N = 2;
fjExit = 0;

while fjExit == 0,
    
      update_data(hObject, handles);
      
      fjThreshold = str2double(get(handles.edit9,'String'));
      setappdata(0, 'fjThreshold', fjThreshold);
      H = uview_FJ_Location_dlg;
      uiwait(H);
      fjOption = getappdata(0, 'fjOption');
      rmappdata(0, 'fjOption');
      
      switch fjOption          
          case 0
              return;
          case 1 
            fjLocation = getappdata(0, 'fjLocation');
            rmappdata(0, 'fjLocation');
            fjIndex  = zeros(size(fjLocation));
            for kk = 1:length(fjLocation),
                fjIndex(kk) = find(handles.position(handles.currentview) == fjLocation(kk));
            end                
          case 2
            fjThreshold = getappdata(0, 'fjThreshold');
            set(handles.edit9, 'string', num2str(fjThreshold));
            rmappdata(0, 'fjThreshold');
            fjIndex = fjdetector(fjData,fjThreshold,N);
      end

      if isempty(fjIndex), % No FJ inputed or detected
          button = questdlg( 'No Flux Jump Inputed or Detected!',...
                             'No Flux Jump Found',...
                             'Ok',...
                             'Re-Checking',...
                             'Ok');
          switch button
              case 'Ok'
                  return;
              case 'Re-Checking'
                  continue;
          end  
          
      else                 % FJ inputed or detected
          
        % 1 show fj on current plot
        axes(handles.axes1),
        hold on;
        text(handles.position(handles.currentview(fjIndex)),fjData(fjIndex),...
             {'\fontsize{12}\downarrow'},...
             'HorizontalAlignment','center',...
             'VerticalAlignment'  ,'bottom',...
             'color'              ,'red',...
             'fontsize'           ,16,...
             'fontweigh'          ,'bold',...
             'BackgroundColor','none');
        hold off;          

        % 2 show message window, indicate fj inputed/detected, ask
        % whether to correct them, ask for interp1 method, if not, abort
        
        numFJ = num2str(length(fjIndex));
        setappdata(0, 'numFJ', numFJ);
        H = uview_FJ_Continue_Correction_dlg;
        uiwait(H);
        fjContinue = getappdata(0, 'fjContinue');
        rmappdata(0, 'fjContinue');
        rmappdata(0, 'numFJ');

        switch fjContinue
            case 0
                return;
            case 1
                fjMethod = getappdata(0, 'fjMethod');
                rmappdata(0, 'fjMethod');
            case 2
                continue;
        end

        % 3 correct the fj(s), show results on current plot (before
        % correction and after correction, data previous demag and next
        % demag if available. correction will be done by a function
        % called fjcorrect(varin)
        
        CorrFJdata = fjcorrect(fjData, fjIndex, fjMethod);
        plot(handles.position(handles.currentview), fjData, 'bo-', handles.position(handles.currentview), CorrFJdata, 'rs-', 'linewidth',1,'markerfacecolor','w','markersize',5);
        legend('Before FJ Correction', 'After FJ Correction');
        text(handles.position(handles.currentview(fjIndex)),fjData(fjIndex),...
             {'\fontsize{12}\downarrow'},...
             'HorizontalAlignment','center',...
             'VerticalAlignment'  ,'bottom',...
             'color'              ,'green',...
             'fontsize'           ,20,...
             'fontweigh'          ,'bold',...
             'BackgroundColor','none');
        hold off;          
        xlabel('Position (cm)');
        ylabel(ylabelstring);
        set(gca,'XMinorTick','on');
        set(gca,'YMinorTick','on');
        set(gca,'Ticklength',[0.015;0.04]);
        box on;
        axis tight;

        % 4 ask whether accept the correction, yes, update related data,
        % not abort
         button = questdlg(  'Do you accept the FJ correction?',...
                             'Accept FJ correction',...
                             'Accept Correction',...
                             'Recheck FJ',...
                             'Abort',...
                             'Accept Correction');
          switch button
              case 'Accept Correction'
                 % update related data;
                 t = (1:length(fjData))';
                 newDrift = (linspace(CorrFJdata(1),CorrFJdata(end),length(CorrFJdata)))';                               
                 switch axisOption
                    case 1
                        drift = polyval(polyfit(t,handles.xmean(handles.currentview)-handles.xcorr(handles.currentview),1),t);
                        tray = handles.xmean(handles.currentview)-handles.xcorr(handles.currentview)-drift;
                        handles.xmean(handles.currentview) = CorrFJdata;
                        handles.xcorr(handles.currentview) = CorrFJdata - newDrift - tray;
                        handles.xint(handles.currentview)  = handles.xcorr(handles.currentview)./handles.xvt(handles.currentview);                         
                    case 2
                        drift = polyval(polyfit(t,handles.ymean(handles.currentview)-handles.ycorr(handles.currentview),1),t);
                        tray = handles.ymean(handles.currentview)-handles.ycorr(handles.currentview)-drift;
                        handles.ymean(handles.currentview) = CorrFJdata;
                        handles.ycorr(handles.currentview) = CorrFJdata - newDrift - tray;
                        handles.yint(handles.currentview)  = handles.ycorr(handles.currentview)./handles.yvt(handles.currentview);  
                    case 3
                        drift = polyval(polyfit(t,handles.zmean(handles.currentview)-handles.zcorr(handles.currentview),1),t);
                        tray = handles.zmean(handles.currentview)-handles.zcorr(handles.currentview)-drift;
                        handles.zmean(handles.currentview) = CorrFJdata;
                        handles.zcorr(handles.currentview) = CorrFJdata - newDrift - tray;
                        handles.zint(handles.currentview)  = handles.zcorr(handles.currentview)./handles.zvt(handles.currentview);  
                end
                handles.int(handles.currentview)   =  sqrt((handles.xint(handles.currentview)).^2+...
                                                           (handles.yint(handles.currentview)).^2+...
                                                           (handles.zint(handles.currentview)).^2);
                % Based on Long Core v3.0 User's Guide (Page 10:2)
                handles.incl(handles.currentview) = atand(handles.zint(handles.currentview)./sqrt(handles.xint(handles.currentview).^2+handles.yint(handles.currentview).^2));
                for kk = handles.currentview(1):handles.currentview(end),
                    if     handles.xint(kk)<0,
                                handles.decl(kk) = atand(handles.yint(kk)./handles.xint(kk))+180;
                    elseif handles.xint(kk)>0 && handles.yint(kk)<=0,
                                handles.decl(kk) = atand(handles.yint(kk)./handles.xint(kk))+360;
                    else   handles.decl(kk) = atand(handles.yint(kk)./handles.xint(kk));
                    end
                end                           
                guidata(hObject,handles);                 
                % update current plot with corrected data;
                update_data(hObject, handles);
                return;
              case 'Recheck FJ'
                  continue;
              case 'Abort'
                  return;
          end  
      end
end



%% [PUSH] SAVE CORRECTED DATA (TO FILE)
function pushbutton22_Callback(hObject, eventdata, handles)
filename = strtok(handles.filename,'.');  
[filename, pathname] = uiputfile({  '*.dat','Data file (*.dat)'},...
                                    'Save FJ corrected data as',...
                                    [handles.pathnamestring,'\',filename,'.fjc.dat']);

% prepare new handles.cellstring. columns need to be changed including decl incl int
% xmean xcorr xint ymean ycorr yint zmean zcorr zint, all other column
% remains the same.
if  ~isequal(filename,0),   
    handles.cellstring{handles.ColumnsMeasurement(7)}  = cellstr(num2str(handles.decl, '%6.2f'));
    handles.cellstring{handles.ColumnsMeasurement(8)}  = cellstr(num2str(handles.incl, '%6.2f'));
    handles.cellstring{handles.ColumnsMeasurement(9)}  = cellstr(num2str(handles.int , '%10.4E'));

    handles.cellstring{handles.ColumnsMeasurement(10)} = cellstr(num2str(handles.xint , '%10.4E'));
    handles.cellstring{handles.ColumnsMeasurement(11)} = cellstr(num2str(handles.xmean, '%10.4E'));
    handles.cellstring{handles.ColumnsMeasurement(12)} = cellstr(num2str(handles.xcorr, '%10.4E'));

    handles.cellstring{handles.ColumnsMeasurement(13)} = cellstr(num2str(handles.yint , '%10.4E'));
    handles.cellstring{handles.ColumnsMeasurement(14)} = cellstr(num2str(handles.ymean, '%10.4E'));
    handles.cellstring{handles.ColumnsMeasurement(15)} = cellstr(num2str(handles.ycorr, '%10.4E'));

    handles.cellstring{handles.ColumnsMeasurement(16)} = cellstr(num2str(handles.zint , '%10.4E'));
    handles.cellstring{handles.ColumnsMeasurement(17)} = cellstr(num2str(handles.zmean, '%10.4E'));
    handles.cellstring{handles.ColumnsMeasurement(18)} = cellstr(num2str(handles.zcorr, '%10.4E'));                          

    header = handles.filehead{1}{1};
    for kk = 2:handles.numCol,
        header = [header, '	', handles.filehead{kk}{1}];
    end

    fid = fopen([pathname,filename], 'wt');
        fprintf(fid, '%s\n', header);
        for kk = 1:handles.numRow,
            currentrow = char(handles.cellstring{1}{kk});
            for jj = 2:handles.numCol,
                currentrow = [currentrow, '	',char(handles.cellstring{jj}{kk})];
            end
            fprintf(fid, '%s\n',currentrow);
        end
    fclose(fid); 
end


%% [PUSH] EXPORT *.int FILES
function pushbutton24_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton24 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

for kk = 1:length(handles.samples),
    index = find(strcmp(handles.sampleid, handles.samples(kk)));
    demags = unique(handles.demag(index));
    demagnum = length(demags);      
        
    sampledata = [handles.position(index), handles.demag(index), 100000.*handles.int(index)];
    % the Lamont convention is J = magnetic moment x 1e-4 emu
    % here they use magnetization [emu/cc] for a 10cc standard sample therefore
    % we multiply by 1e5: Int = $Int*100000;
   
    sampledata_sorted = sortrows(sampledata, [1 2]);
    leader = handles.leader(index(1));
    trailer = handles.trailer(index(1));
    sampledata_w = sampledata_sorted((leader*demagnum+1):(end-trailer*demagnum),:); % GET RID OF LEADERS AND TRAILERS
    sampledata = sortrows(sampledata_w, [2 1]);
     
    steprownum = size(sampledata,1)/demagnum;
    if rem(steprownum, 1) > 1e-6, 
       msgbox('Measured positions for different demag steps are not the same for this sample! ', 'Error message','error'); 
       return 
    end  
    position = sampledata(1:steprownum,1);
    intout = [position, reshape(sampledata(:,end), steprownum, demagnum)];
    
    formatout = '	%9.4E';
    demagstring = ['	Int ', num2str(demags(1))];
    for ki = 1:demagnum-1,
        formatout = [formatout,'	%9.4E'];
        demagstring = [demagstring, '	Int ', num2str(demags(ki+1))];
    end
    
    fid = fopen([handles.pathname,handles.samples{kk},'.',handles.DataType,'.int'], 'wt');
    fprintf(fid, ['Sample_ID	Position',demagstring,' \n']);   
    fprintf(fid, [handles.samples{kk}, '	%-6.0f',formatout,' \n'],intout');
    fclose(fid);
    
end

msgbox([num2str(length(handles.samples)),' *.int file(s) have been generated from ', handles.filename,...
'. You may now use the ''UINT'' tool to view these data'],'*.int file(s) generation confirmation','help') ;  


%% [PUSH] EXPORT *.dir FILES
function pushbutton25_Callback(hObject, eventdata, handles)

for kk = 1:length(handles.samples),
    index = find(strcmp(handles.sampleid, handles.samples(kk)));
    demagnum = length(unique(handles.demag(index)));

    % put data of the same id together and sort it first by position then
    % by demagsteps (1. SORT BY POSITION THEN BY DEMAG;
    % 2. FIRST AND LAST 10 MEASUREMENTS OF EACH POSITION NEED TO BE REMOVED)

    sampledata = [handles.position(index), handles.demag(index), 100000.*handles.int(index), handles.decl(index), handles.incl(index)];
    % the Lamont convention is J = magnetic moment x 1e-4 emu
    % here they use magnetization [emu/cc] for a 10cc standard sample therefore
    % we multiply by 1e5: Int = $Int*100000;

    sampledata_sorted = sortrows(sampledata, [1 2]);
    sampledata = [sampledata_sorted(:,1:2), zeros(length(index),1), sampledata_sorted(:,3), sampledata_sorted(:,4:5),sampledata_sorted(:,4:5),sampledata_sorted(:,4:5),zeros(length(index),2)];
    leader = handles.leader(index(1));
    trailer = handles.trailer(index(1));
    sampledata_w = sampledata((leader*demagnum+1):(end-trailer*demagnum),:);

    % write the sorted data of that sampe to a file

    fid = fopen([handles.pathname,handles.samples{kk},'.',handles.DataType,'.dir'], 'wt');
    fprintf(fid, '-----------------------------------------------------------------------------------------------  \n');
    fprintf(fid, [handles.samples{kk},'.',handles.DataType,'.dir   (Converted from "', handles.pathnamestring, handles.filename,  '") \n']);
    fprintf(fid, '-----------------------------------------------------------------------------------------------  \n');
    fprintf(fid, 'POSITION  TREAT  IC  CD       J       CDECL    CINCL  GDECL    GINCL  BDECL    BINCL  SUSC  V/M \n');
    fprintf(fid, '----------------------------------------------------------------------------------------------- \n');
    fprintf(fid, ['%-8.2f  %5.0f', '  Cm', '  %2.0f  %9.4E  %6.2f  %6.2f  %6.2f  %6.2f  %6.2f  %6.2f  %4.0f  %3.0f \n'], sampledata_w');
    fclose(fid); 
end

msgbox([num2str(length(handles.samples)),' *.dir file(s) have been generated from ', handles.filename,...
'. You may now use the ''UDIR'' tool to view these data'],'*.dir file(s) generation confirmation','help') ;  

   
%% []PUSH] EXPORT CURRENT PLOT
function pushbutton29_Callback(hObject, eventdata, handles)

[filename, pathname,FilterIndex] =  uiputfile({  '*.bmp','Windows bitmap (*.bmp)';
                                    '*.fig','MATLAB figure (*.fig)';
                                    '*.eps','EPS Level2 (*.eps)';
                                    '*.tif','TIFF image (*.tif)';
                                    '*.png','Portable Network Graphics (*.png)';
                                    '*.ai','Adobe Illustrator (*.ai)';
                                    '*.jpg','JPEG image (*.jpg)';
                                    '*.pdf','Portable Document Format (*.pdf)';
                                    '*.emf','Enhanced metafile (*.emf)'},...
                                    'Save current plot as',...
                                   [handles.pathnamestring,'\UVIEW_plot.bmp']);

if  ~isequal(filename,0),   
    
    if get(handles.radiobutton15,'Value') == get(handles.radiobutton15,'Max'),
        h2 = findobj(handles.axes2,'type','axes');
        h3 = findobj(handles.axes3,'type','axes');
        h4 = findobj(handles.axes4,'type','axes');
        newFig = figure;
        newAxes2 = copyobj(h2, newFig);
        set(newAxes2,'Units','normalized','Position',[0.1 0.66 0.85 0.27]);
        newAxes3 = copyobj(h3, newFig);
        set(newAxes3,'Units','normalized','Position',[0.1 0.38 0.85 0.27]);
        newAxes4 = copyobj(h4, newFig); 
        set(newAxes4,'Units','normalized','Position',[0.1 0.10 0.85 0.27]);
        
    else        
        h1  = findobj(handles.axes1,'type','axes');
        newFig = figure;
        newAxes = copyobj(h1,newFig); 
        set(newAxes,'Units','default','Position','default');
    end
    
    if FilterIndex == 3,
       saveas(newFig,[pathname,filename], 'psc2');
    else   
       saveas(newFig,[pathname,filename]);
    end
    close(newFig);
    
end


%% [TOGGLE] VIEW MULTIPLE STEPS DATA
function togglebutton1_Callback(hObject, eventdata, handles)

if get(handles.togglebutton1, 'value') == 1,
    
    set(handles.edit3,'String','Multiple demag steps');
    if    get(handles.radiobutton4,'Value') == get(handles.radiobutton4,'Max')...% 'Xint, Yint, Zint' Selected
       || get(handles.radiobutton2,'Value') == get(handles.radiobutton2,'Max')...% 'Xmean, Ymean, Zmean' Selected
       || get(handles.radiobutton3,'Value') == get(handles.radiobutton3,'Max'),  % 'Xcorr, Ycorr, Zcorr' Selected
    
       h = msgbox(['This function does not work on ''Xint, Yint, Zint'', ''Xmean, Ymean, Zmean'', or ''Xcorr, Ycorr, Zcorr''.',...
               '''Plot Parameters'' will now be changed to ''Int'''], 'Warning message','warn') ;
       uiwait(h);
       set(handles.radiobutton8, 'value', 1);
       
    end
    
else    
    set(handles.edit3,'String',num2str(handles.currentdemags(handles.DemagIndexNow)));
     
end

update_data(hObject, handles);




%% [LISTBOX] SAMPLE LIST
function listbox1_Callback(hObject, eventdata, handles)

handles.SampleIndexNow = get(handles.listbox1, 'value');
guidata(hObject,handles);
update_index(hObject, handles);  
handles = guidata(gcbo);
set(handles.popupmenu4, 'string', handles.currentdemags);
set(handles.popupmenu4, 'value', 1);
set(handles.popupmenu6, 'string', handles.currentdemags);
set(handles.popupmenu6, 'value', length(handles.currentdemags));
update_data(hObject, handles);   

% set(handles.listbox1, 'value', handles.SampleIndexNow);
set(handles.listbox3, 'string', num2cell(handles.currentdemags));
set(handles.listbox3, 'value', handles.DemagIndexNow);
set(handles.edit2,'String',handles.samples(handles.SampleIndexNow));
set(handles.edit3,'String',num2str(handles.currentdemags(handles.DemagIndexNow)));


function listbox1_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



%% [LISTBOX] DEMAG STEP LIST
function listbox3_Callback(hObject, eventdata, handles)

if get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
  msgbox('Multiple demag steps data are shown. To view data from individual demag step, please toggle off ''View Multiple Steps of This Sample.''', 'Warning message','warn'); 
  return        
end  

handles.DemagIndexNow = get(handles.listbox3, 'value');
guidata(hObject,handles);

update_index(hObject, handles);  
handles = guidata(gcbo);
update_data(hObject, handles);   

% set(handles.listbox1, 'value', handles.SampleIndexNow);
% set(handles.listbox3, 'string', num2cell(handles.currentdemags));
% set(handles.listbox3, 'value', handles.DemagIndexNow);
% set(handles.edit2,'String',handles.samples(handles.SampleIndexNow));
set(handles.edit3,'String',num2str(handles.currentdemags(handles.DemagIndexNow)));


function listbox3_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



%% [FUNCTION] FJDETECTOR
function fjindex = fjdetector(signal,FJfac,N)

% if ymean difference between two adjacent positions is at least FJfac times bigger than the mean
% difference of the surrounding N positions (N/2 before and N/2 after, in this case, N = 2), 
% AND at least 2*FJfac times bigger than mean difference of all positions, then FJ
% is defined for that Postion. An IRD shall not be detected as an FJ.

dsignal = diff(signal); % Note that length(dymean) = length(handles.ymean)-1
fjindex = zeros(size(dsignal)); 
for kk = 1+N/2:length(dsignal)-N/2,
    if abs(dsignal(kk)) > FJfac*mean(abs(dsignal([kk-N/2:kk-1;kk+1:kk+N/2]))) && abs(dsignal(kk)) > 2*FJfac*mean(abs(dsignal)),
       fjindex(kk) = kk+1;    % index qq in the diff(ymean) data corresponding to index qq+1 in ymean!
    end
end
fjindex(fjindex==0)=[]; % Delete zero elements

          
%% [FUNCTION] FJCORRECT
function fjData2 = fjcorrect(fjData, fjIndex, fjMethod)

dt = (1:length(fjData)-1)'; 
dt1 = dt;
dfjData = diff(fjData);

dt1(fjIndex-1) = [];    % index k in the fjData corresponding to index k-1 in diff(fjData)!
dfjData(fjIndex-1) = [];

dfjData2 = interp1(dt1,dfjData, dt, fjMethod);
fjData2 = zeros(size(fjData));
fjData2(1) = fjData(1);

for k = 2:length(fjData2),
    fjData2(k) = fjData2(k-1)+dfjData2(k-1);
end
    
%% [FUNCTION] UPDATE LEGEND
function update_legend(hObject, handles)

if  get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),    % showing multiple steps
    
    demagStarts       = handles.currentdemags(get(handles.popupmenu4, 'value'));
    demagEnds         = handles.currentdemags(get(handles.popupmenu6, 'value'));
    SelectedDemags    = find(handles.currentdemags >= demagStarts & handles.currentdemags <= demagEnds);
    legendstring      = num2str(handles.currentdemags(SelectedDemags));
    
    if     get(handles.radiobutton4,'Value') == get(handles.radiobutton4,'Max'),  % 'Xint, Yint, Zint' Selected
           legendstring = ['Xint'; 'Yint'; 'Zint'];
    elseif get(handles.radiobutton2,'Value') == get(handles.radiobutton2,'Max'),  % 'Xmean, Ymean, Zmean' Selected
           legendstring = ['Xmean'; 'Ymean'; 'Zmean'];
    elseif get(handles.radiobutton3,'Value') == get(handles.radiobutton3,'Max'),  % 'Xcorr, Ycorr, Zcorr' Selected
           legendstring = ['Xcorr'; 'Ycorr'; 'Zcorr'];
    end
    
    if get(handles.radiobutton15,'Value') == get(handles.radiobutton15,'Max'), % 'Int, Decl, Incl' Selected  
       axes(handles.axes2), legend(legendstring); 
       axes(handles.axes3), legend(legendstring); 
       axes(handles.axes4), legend(legendstring); 
    else   
       legend(legendstring);
    end
    
else 
    if     get(handles.radiobutton4,'Value') == get(handles.radiobutton4,'Max'), % 'Xint, Yint, Zint' Selected
           legendstring = ['Xint'; 'Yint'; 'Zint'];  
           legend(legendstring);
    elseif get(handles.radiobutton2,'Value') == get(handles.radiobutton2,'Max'), % 'Xmean, Ymean, Zmean' Selected
           legendstring = ['Xmean'; 'Ymean'; 'Zmean'];
           legend(legendstring);           
    elseif get(handles.radiobutton3,'Value') == get(handles.radiobutton3,'Max'), % 'Xcorr, Ycorr, Zcorr' Selected
           legendstring = ['Xcorr'; 'Ycorr'; 'Zcorr']; 
           legend(legendstring);           
    elseif get(handles.radiobutton8,'Value') == get(handles.radiobutton8,'Max'), % 'Int' Selected
           legendstring = {'Int'};     
           legend(legendstring);           
    elseif get(handles.radiobutton13,'Value') == get(handles.radiobutton13,'Max'), % 'Incl' Selected
           legendstring = {'Incl'};          
           legend(legendstring);
    elseif get(handles.radiobutton14,'Value') == get(handles.radiobutton14,'Max'), % 'Decl' Selected
           legendstring = {'Decl'};    
           legend(legendstring);           
    elseif get(handles.radiobutton15,'Value') == get(handles.radiobutton15,'Max'), % 'Int, Decl, Incl' Selected   
           legendstring = {'Int', 'Decl','Incl'};    
           axes(handles.axes2), legend(legendstring{1}); 
           axes(handles.axes3), legend(legendstring{2}); 
           axes(handles.axes4), legend(legendstring{3}); 
    elseif get(handles.radiobutton19,'Value') == get(handles.radiobutton19,'Max'), % 'Xint' Selected
           legendstring = {'Xint'};       
           legend(legendstring);
    elseif get(handles.radiobutton22,'Value') == get(handles.radiobutton22,'Max'), % 'Yint' Selected
           legendstring = {'Yint'};       
           legend(legendstring);
    elseif get(handles.radiobutton25,'Value') == get(handles.radiobutton25,'Max'), % 'Zint' Selected
           legendstring = {'Zint'};  
           legend(legendstring);
    elseif get(handles.radiobutton16,'Value') == get(handles.radiobutton16,'Max'), % 'Xmean' Selected
           legendstring = {'Xmean'};  
           legend(legendstring);
    elseif get(handles.radiobutton20,'Value') == get(handles.radiobutton20,'Max'), % 'Ymean' Selected
           legendstring = {'Ymean'};  
           legend(legendstring);           
    elseif get(handles.radiobutton23,'Value') == get(handles.radiobutton23,'Max'), % 'Zmean' Selected
           legendstring = {'Zmean'};        
           legend(legendstring);
    elseif get(handles.radiobutton18,'Value') == get(handles.radiobutton18,'Max'), % 'Xcorr' Selected
           legendstring = {'Xcorr'};         
           legend(legendstring);
    elseif get(handles.radiobutton21,'Value') == get(handles.radiobutton21,'Max'), % 'Ycorr' Selected
           legendstring = {'Ycorr'};        
           legend(legendstring);
    elseif get(handles.radiobutton24,'Value') == get(handles.radiobutton24,'Max'), % 'Zcorr' Selected
           legendstring = {'Zcorr'};  
           legend(legendstring);
    end        
end

handles.legendstring = legendstring;
guidata(hObject, handles);

%% [FUNCTION] UPDATE INDEX
function update_index(hObject, handles)

handles.currentsamplerow = find(strcmp(handles.sampleid,handles.samples(handles.SampleIndexNow)));
handles.currentdemags = unique(handles.demag(handles.currentsamplerow));
if length(handles.currentdemags) < handles.DemagIndexNow,
    messageString = strcat({'Maximum demag step of sample '}, handles.samples(handles.SampleIndexNow),{' is '},...
                        num2str(handles.currentdemags(end)),'! Current plot will now show data from this maximum demag step.');
    h =  msgbox(messageString, 'Warning message','warn'); 
    uiwait(h);
    handles.DemagIndexNow = length(handles.currentdemags);
end
handles.currentview = handles.currentsamplerow(find(handles.demag(handles.currentsamplerow) == handles.currentdemags(handles.DemagIndexNow)));
guidata(hObject,handles);

%% [FUNCTION] UPDATE DATA
function data4plot = update_data(hObject, handles)

if     get(handles.radiobutton4,'Value') == get(handles.radiobutton4,'Max'), % 'Xint, Yint, Zint' Selected
       
       if get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
          msgbox('Cannot show multiple demag steps data for ''Xint, Yint, Zint'', ''Xmean, Ymean, Zmean'', or ''Xcorr, Ycorr, Zcorr''.', 'Warning message','warn'); 
          return        
       end      
       data4plot = [handles.position(handles.currentview),handles.xint(handles.currentview),handles.yint(handles.currentview),handles.zint(handles.currentview)];
       cla(handles.axes2);
       cla(handles.axes3);
       cla(handles.axes4);
       set(handles.axes1, 'Visible','on');
       set(handles.axes2, 'Visible','off');
       set(handles.axes3, 'Visible','off');
       set(handles.axes4, 'Visible','off');
       axes(handles.axes1),update_plot(hObject, handles,data4plot);
       ylabel(' \color{blue}Xint        \color[rgb]{0 0.5 0}Yint        \color{red}Zint');
       
elseif get(handles.radiobutton2,'Value') == get(handles.radiobutton2,'Max'), % 'Xmean, Ymean, Zmean' Selected
       
       if get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
          msgbox('Cannot show multiple demag steps data for ''Xint, Yint, Zint'', ''Xmean, Ymean, Zmean'', or ''Xcorr, Ycorr, Zcorr''.', 'Warning message','warn'); 
          return        
       end   
       data4plot = [handles.position(handles.currentview),handles.xmean(handles.currentview),handles.ymean(handles.currentview),handles.zmean(handles.currentview)];
       cla(handles.axes2);
       cla(handles.axes3);
       cla(handles.axes4);
       set(handles.axes1, 'Visible','on');
       set(handles.axes2, 'Visible','off');
       set(handles.axes3, 'Visible','off');
       set(handles.axes4, 'Visible','off');
       axes(handles.axes1),update_plot(hObject, handles,data4plot);
       ylabel(' \color{blue}Xmean        \color[rgb]{0 0.5 0}Ymean        \color{red}Zmean');
       
elseif get(handles.radiobutton3,'Value') == get(handles.radiobutton3,'Max'), % 'Xcorr, Ycorr, Zcorr' Selected
    
       if get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
          msgbox('Cannot show multiple demag steps data for ''Xint, Yint, Zint'', ''Xmean, Ymean, Zmean'', or ''Xcorr, Ycorr, Zcorr''.', 'Warning message','warn'); 
          return        
       end 
       data4plot = [handles.position(handles.currentview),handles.xcorr(handles.currentview),handles.ycorr(handles.currentview),handles.zcorr(handles.currentview)];
       cla(handles.axes2);
       cla(handles.axes3);
       cla(handles.axes4);
       set(handles.axes1, 'Visible','on');
       set(handles.axes2, 'Visible','off');
       set(handles.axes3, 'Visible','off');
       set(handles.axes4, 'Visible','off');
       axes(handles.axes1),update_plot(hObject, handles,data4plot);
       ylabel(' \color{blue}Xcorr        \color[rgb]{0 0.5 0}Ycorr        \color{red}Zcorr');
              
elseif get(handles.radiobutton8,'Value') == get(handles.radiobutton8,'Max'), % 'Int' Selected
    
       if  get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
           demagStarts       = handles.currentdemags(get(handles.popupmenu4, 'value'));
           demagEnds         = handles.currentdemags(get(handles.popupmenu6, 'value'));
           numSelectedDemags = length(find(handles.currentdemags >= demagStarts & handles.currentdemags <= demagEnds));
           selectedDemagRows = handles.currentsamplerow(find(handles.demag(handles.currentsamplerow) >= demagStarts & handles.demag(handles.currentsamplerow) <= demagEnds));
           data = [handles.position(selectedDemagRows),handles.demag(selectedDemagRows),handles.int(selectedDemagRows)];
           data = sortrows(data, [2 1]);
           steprownum = length(data)./numSelectedDemags;
           if rem(steprownum, 1) > 1e-6, 
              msgbox('Measured positions for different demag steps are not the same for this sample! ', 'Error message','error'); 
              return 
           end
           data4plot = [handles.position(handles.currentview), reshape(data(:,end), steprownum, numSelectedDemags)];

       else
           data4plot = [handles.position(handles.currentview),handles.int(handles.currentview)];           

       end      

       cla(handles.axes2);
       cla(handles.axes3);
       cla(handles.axes4);
       set(handles.axes1, 'Visible','on');
       set(handles.axes2, 'Visible','off');
       set(handles.axes3, 'Visible','off');
       set(handles.axes4, 'Visible','off');
       axes(handles.axes1),update_plot(hObject, handles,data4plot);
       ylabel(' \color[rgb]{0 0.5 0}Int');
       
elseif get(handles.radiobutton13,'Value') == get(handles.radiobutton13,'Max'), % 'Incl' Selected

        if  get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
           demagStarts       = handles.currentdemags(get(handles.popupmenu4, 'value'));
           demagEnds         = handles.currentdemags(get(handles.popupmenu6, 'value'));
           numSelectedDemags = length(find(handles.currentdemags >= demagStarts & handles.currentdemags <= demagEnds));
           selectedDemagRows = handles.currentsamplerow(find(handles.demag(handles.currentsamplerow) >= demagStarts & handles.demag(handles.currentsamplerow) <= demagEnds));      
           data = [handles.position(selectedDemagRows),handles.demag(selectedDemagRows),handles.incl(selectedDemagRows)];
           data = sortrows(data, [2 1]);
           steprownum = length(data)./numSelectedDemags;
           if rem(steprownum, 1) > 1e-6, 
              msgbox('Measured positions for different demag steps are not the same for this sample! ', 'Error message','error'); 
              return 
           end
           data4plot = [handles.position(handles.currentview), reshape(data(:,end), steprownum, numSelectedDemags)];

       else
           data4plot = [handles.position(handles.currentview),handles.incl(handles.currentview)];           

       end   
    
       cla(handles.axes2);
       cla(handles.axes3);
       cla(handles.axes4);
       set(handles.axes1, 'Visible','on');
       set(handles.axes2, 'Visible','off');
       set(handles.axes3, 'Visible','off');
       set(handles.axes4, 'Visible','off');
       axes(handles.axes1),update_plot(hObject, handles,data4plot);
       ylabel(' \color[rgb]{0 0.5 0}Incl');       
              
elseif get(handles.radiobutton14,'Value') == get(handles.radiobutton14,'Max'), % 'Decl' Selected

       if  get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
           demagStarts       = handles.currentdemags(get(handles.popupmenu4, 'value'));
           demagEnds         = handles.currentdemags(get(handles.popupmenu6, 'value'));
           numSelectedDemags = length(find(handles.currentdemags >= demagStarts & handles.currentdemags <= demagEnds));
           selectedDemagRows = handles.currentsamplerow(find(handles.demag(handles.currentsamplerow) >= demagStarts & handles.demag(handles.currentsamplerow) <= demagEnds));      
           data = [handles.position(selectedDemagRows),handles.demag(selectedDemagRows),handles.decl(selectedDemagRows)];
           data = sortrows(data, [2 1]);
           steprownum = length(data)./numSelectedDemags;
           if rem(steprownum, 1) > 1e-6, 
              msgbox('Measured positions for different demag steps are not the same for this sample! ', 'Error message','error'); 
              return 
           end
           data4plot = [handles.position(handles.currentview), reshape(data(:,end), steprownum, numSelectedDemags)];

       else
           data4plot = [handles.position(handles.currentview),handles.decl(handles.currentview)];           

       end   
       
       cla(handles.axes2);
       cla(handles.axes3);
       cla(handles.axes4);
       set(handles.axes1, 'Visible','on');
       set(handles.axes2, 'Visible','off');
       set(handles.axes3, 'Visible','off');
       set(handles.axes4, 'Visible','off');
       axes(handles.axes1),update_plot(hObject, handles,data4plot);
       ylabel(' \color[rgb]{0 0.5 0}Decl');
       
elseif get(handles.radiobutton15,'Value') == get(handles.radiobutton15,'Max'), % 'Int, Decl, Incl' Selected   
        
       if  get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
           demagStarts       = handles.currentdemags(get(handles.popupmenu4, 'value'));
           demagEnds         = handles.currentdemags(get(handles.popupmenu6, 'value'));
           numSelectedDemags = length(find(handles.currentdemags >= demagStarts & handles.currentdemags <= demagEnds));
           selectedDemagRows = handles.currentsamplerow(find(handles.demag(handles.currentsamplerow) >= demagStarts & handles.demag(handles.currentsamplerow) <= demagEnds));      
           int = [handles.position(selectedDemagRows),handles.demag(selectedDemagRows),handles.int(selectedDemagRows)];
           int = sortrows(int, [2 1]);
           steprownum = length(int)./numSelectedDemags;
           if rem(steprownum, 1) > 1e-6, 
              msgbox('Measured positions for different demag steps are not the same for this sample! ', 'Error message','error'); 
              return 
           end
           decl = [handles.position(selectedDemagRows),handles.demag(selectedDemagRows),handles.decl(selectedDemagRows)];
           decl = sortrows(decl, [2 1]);
           incl = [handles.position(selectedDemagRows),handles.demag(selectedDemagRows),handles.incl(selectedDemagRows)];
           incl = sortrows(incl, [2 1]);           
                      
           data4plot = [handles.position(handles.currentview), reshape(int(:,end), steprownum, numSelectedDemags),...
                                                               reshape(decl(:,end), steprownum, numSelectedDemags),...
                                                               reshape(incl(:,end), steprownum, numSelectedDemags)];

       else
           data4plot = [handles.position(handles.currentview),handles.int(handles.currentview),handles.decl(handles.currentview),handles.incl(handles.currentview)];      

       end  
       
       cla(handles.axes1);
       set(handles.axes1, 'Visible','off');
       set(handles.axes2, 'Visible','on');
       set(handles.axes3, 'Visible','on');
       set(handles.axes4, 'Visible','on');
       update_plot2(hObject, handles, data4plot);
              
elseif get(handles.radiobutton19,'Value') == get(handles.radiobutton19,'Max'), % 'Xint' Selected
       
       if  get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
           demagStarts       = handles.currentdemags(get(handles.popupmenu4, 'value'));
           demagEnds         = handles.currentdemags(get(handles.popupmenu6, 'value'));
           numSelectedDemags = length(find(handles.currentdemags >= demagStarts & handles.currentdemags <= demagEnds));
           selectedDemagRows = handles.currentsamplerow(find(handles.demag(handles.currentsamplerow) >= demagStarts & handles.demag(handles.currentsamplerow) <= demagEnds));      
           data = [handles.position(selectedDemagRows),handles.demag(selectedDemagRows),handles.xint(selectedDemagRows)];
           data = sortrows(data, [2 1]);
           steprownum = length(data)./numSelectedDemags;
           if rem(steprownum, 1) > 1e-6, 
              msgbox('Measured positions for different demag steps are not the same for this sample! ', 'Error message','error'); 
              return 
           end
           data4plot = [handles.position(handles.currentview), reshape(data(:,end), steprownum, numSelectedDemags)];

       else
           data4plot = [handles.position(handles.currentview),handles.xint(handles.currentview)];           

       end   
       
       cla(handles.axes2);
       cla(handles.axes3);
       cla(handles.axes4);
       set(handles.axes1, 'Visible','on');
       set(handles.axes2, 'Visible','off');
       set(handles.axes3, 'Visible','off');
       set(handles.axes4, 'Visible','off');
       axes(handles.axes1), update_plot(hObject, handles,data4plot);
       ylabel(' \color[rgb]{0 0.5 0}Xint');
       
elseif get(handles.radiobutton22,'Value') == get(handles.radiobutton22,'Max'), % 'Yint' Selected
       
       if  get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
           demagStarts       = handles.currentdemags(get(handles.popupmenu4, 'value'));
           demagEnds         = handles.currentdemags(get(handles.popupmenu6, 'value'));
           numSelectedDemags = length(find(handles.currentdemags >= demagStarts & handles.currentdemags <= demagEnds));
           selectedDemagRows = handles.currentsamplerow(find(handles.demag(handles.currentsamplerow) >= demagStarts & handles.demag(handles.currentsamplerow) <= demagEnds));      
           data = [handles.position(selectedDemagRows),handles.demag(selectedDemagRows),handles.yint(selectedDemagRows)];
           data = sortrows(data, [2 1]);
           steprownum = length(data)./numSelectedDemags;
           if rem(steprownum, 1) > 1e-6, 
              msgbox('Measured positions for different demag steps are not the same for this sample! ', 'Error message','error'); 
              return 
           end
           data4plot = [handles.position(handles.currentview), reshape(data(:,end), steprownum, numSelectedDemags)];

       else
           data4plot = [handles.position(handles.currentview),handles.yint(handles.currentview)];           

       end   
       
       cla(handles.axes2);
       cla(handles.axes3);
       cla(handles.axes4);
       set(handles.axes1, 'Visible','on');
       set(handles.axes2, 'Visible','off');
       set(handles.axes3, 'Visible','off');
       set(handles.axes4, 'Visible','off');
       axes(handles.axes1),update_plot(hObject, handles,data4plot);
       ylabel(' \color[rgb]{0 0.5 0}Yint');
       
elseif get(handles.radiobutton25,'Value') == get(handles.radiobutton25,'Max'), % 'Zint' Selected
       
       if  get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
           demagStarts       = handles.currentdemags(get(handles.popupmenu4, 'value'));
           demagEnds         = handles.currentdemags(get(handles.popupmenu6, 'value'));
           numSelectedDemags = length(find(handles.currentdemags >= demagStarts & handles.currentdemags <= demagEnds));
           selectedDemagRows = handles.currentsamplerow(find(handles.demag(handles.currentsamplerow) >= demagStarts & handles.demag(handles.currentsamplerow) <= demagEnds));      
           data = [handles.position(selectedDemagRows),handles.demag(selectedDemagRows),handles.zint(selectedDemagRows)];
           data = sortrows(data, [2 1]);
           steprownum = length(data)./numSelectedDemags;
           if rem(steprownum, 1) > 1e-6, 
              msgbox('Measured positions for different demag steps are not the same for this sample! ', 'Error message','error'); 
              return 
           end
           data4plot = [handles.position(handles.currentview), reshape(data(:,end), steprownum, numSelectedDemags)];

       else
           data4plot = [handles.position(handles.currentview),handles.zint(handles.currentview)];           

       end   
       
       cla(handles.axes2);
       cla(handles.axes3);
       cla(handles.axes4);
       set(handles.axes1, 'Visible','on');
       set(handles.axes2, 'Visible','off');
       set(handles.axes3, 'Visible','off');
       set(handles.axes4, 'Visible','off');
       axes(handles.axes1),update_plot(hObject, handles,data4plot);
       ylabel(' \color[rgb]{0 0.5 0}Zint');
       
elseif get(handles.radiobutton16,'Value') == get(handles.radiobutton16,'Max'), % 'Xmean' Selected
       
       if  get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
           demagStarts       = handles.currentdemags(get(handles.popupmenu4, 'value'));
           demagEnds         = handles.currentdemags(get(handles.popupmenu6, 'value'));
           numSelectedDemags = length(find(handles.currentdemags >= demagStarts & handles.currentdemags <= demagEnds));
           selectedDemagRows = handles.currentsamplerow(find(handles.demag(handles.currentsamplerow) >= demagStarts & handles.demag(handles.currentsamplerow) <= demagEnds));      
           data = [handles.position(selectedDemagRows),handles.demag(selectedDemagRows),handles.xmean(selectedDemagRows)];
           data = sortrows(data, [2 1]);
           steprownum = length(data)./numSelectedDemags;
           if rem(steprownum, 1) > 1e-6, 
              msgbox('Measured positions for different demag steps are not the same for this sample! ', 'Error message','error'); 
              return 
           end
           data4plot = [handles.position(handles.currentview), reshape(data(:,end), steprownum, numSelectedDemags)];

       else
           data4plot = [handles.position(handles.currentview),handles.xmean(handles.currentview)];           

       end   
       
       cla(handles.axes2);
       cla(handles.axes3);
       cla(handles.axes4);
       set(handles.axes1, 'Visible','on');
       set(handles.axes2, 'Visible','off');
       set(handles.axes3, 'Visible','off');
       set(handles.axes4, 'Visible','off');
       axes(handles.axes1),update_plot(hObject, handles,data4plot);
       ylabel(' \color[rgb]{0 0.5 0}Xmean');
       
elseif get(handles.radiobutton20,'Value') == get(handles.radiobutton20,'Max'), % 'Ymean' Selected
       
       if  get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
           demagStarts       = handles.currentdemags(get(handles.popupmenu4, 'value'));
           demagEnds         = handles.currentdemags(get(handles.popupmenu6, 'value'));
           numSelectedDemags = length(find(handles.currentdemags >= demagStarts & handles.currentdemags <= demagEnds));
           selectedDemagRows = handles.currentsamplerow(find(handles.demag(handles.currentsamplerow) >= demagStarts & handles.demag(handles.currentsamplerow) <= demagEnds));      
           data = [handles.position(selectedDemagRows),handles.demag(selectedDemagRows),handles.ymean(selectedDemagRows)];
           data = sortrows(data, [2 1]);
           steprownum = length(data)./numSelectedDemags;
           if rem(steprownum, 1) > 1e-6, 
              msgbox('Measured positions for different demag steps are not the same for this sample! ', 'Error message','error'); 
              return 
           end
           data4plot = [handles.position(handles.currentview), reshape(data(:,end), steprownum, numSelectedDemags)];

       else
           data4plot = [handles.position(handles.currentview),handles.ymean(handles.currentview)];           

       end   
       
       cla(handles.axes2);
       cla(handles.axes3);
       cla(handles.axes4);
       set(handles.axes1, 'Visible','on');
       set(handles.axes2, 'Visible','off');
       set(handles.axes3, 'Visible','off');
       set(handles.axes4, 'Visible','off');
       axes(handles.axes1),update_plot(hObject, handles,data4plot);
       ylabel(' \color[rgb]{0 0.5 0}Ymean');
       
elseif get(handles.radiobutton23,'Value') == get(handles.radiobutton23,'Max'), % 'Zmean' Selected
       
       if  get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
           demagStarts       = handles.currentdemags(get(handles.popupmenu4, 'value'));
           demagEnds         = handles.currentdemags(get(handles.popupmenu6, 'value'));
           numSelectedDemags = length(find(handles.currentdemags >= demagStarts & handles.currentdemags <= demagEnds));
           selectedDemagRows = handles.currentsamplerow(find(handles.demag(handles.currentsamplerow) >= demagStarts & handles.demag(handles.currentsamplerow) <= demagEnds));      
           data = [handles.position(selectedDemagRows),handles.demag(selectedDemagRows),handles.zmean(selectedDemagRows)];
           data = sortrows(data, [2 1]);
           steprownum = length(data)./numSelectedDemags;
           if rem(steprownum, 1) > 1e-6, 
              msgbox('Measured positions for different demag steps are not the same for this sample! ', 'Error message','error'); 
              return 
           end
           data4plot = [handles.position(handles.currentview), reshape(data(:,end), steprownum, numSelectedDemags)];

       else
           data4plot = [handles.position(handles.currentview),handles.zmean(handles.currentview)];           

       end   
       
       cla(handles.axes2);
       cla(handles.axes3);
       cla(handles.axes4);
       set(handles.axes1, 'Visible','on');
       set(handles.axes2, 'Visible','off');
       set(handles.axes3, 'Visible','off');
       set(handles.axes4, 'Visible','off');
       axes(handles.axes1),update_plot(hObject, handles,data4plot);
       ylabel(' \color[rgb]{0 0.5 0}Zmean');
       
elseif get(handles.radiobutton18,'Value') == get(handles.radiobutton18,'Max'), % 'Xcorr' Selected
       
       if  get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
           demagStarts       = handles.currentdemags(get(handles.popupmenu4, 'value'));
           demagEnds         = handles.currentdemags(get(handles.popupmenu6, 'value'));
           numSelectedDemags = length(find(handles.currentdemags >= demagStarts & handles.currentdemags <= demagEnds));
           selectedDemagRows = handles.currentsamplerow(find(handles.demag(handles.currentsamplerow) >= demagStarts & handles.demag(handles.currentsamplerow) <= demagEnds));      
           data = [handles.position(selectedDemagRows),handles.demag(selectedDemagRows),handles.xcorr(selectedDemagRows)];
           data = sortrows(data, [2 1]);
           steprownum = length(data)./numSelectedDemags;
           if rem(steprownum, 1) > 1e-6, 
              msgbox('Measured positions for different demag steps are not the same for this sample! ', 'Error message','error'); 
              return 
           end
           data4plot = [handles.position(handles.currentview), reshape(data(:,end), steprownum, numSelectedDemags)];

       else
           data4plot = [handles.position(handles.currentview),handles.xcorr(handles.currentview)];           

       end   
       
       set(handles.axes1, 'Visible','on');
       set(handles.axes2, 'Visible','off');
       set(handles.axes3, 'Visible','off');
       set(handles.axes4, 'Visible','off');
       axes(handles.axes1),update_plot(hObject, handles,data4plot);
       ylabel(' \color[rgb]{0 0.5 0}Xcorr');
       
elseif get(handles.radiobutton21,'Value') == get(handles.radiobutton21,'Max'), % 'Ycorr' Selected
       
       if  get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
           demagStarts       = handles.currentdemags(get(handles.popupmenu4, 'value'));
           demagEnds         = handles.currentdemags(get(handles.popupmenu6, 'value'));
           numSelectedDemags = length(find(handles.currentdemags >= demagStarts & handles.currentdemags <= demagEnds));
           selectedDemagRows = handles.currentsamplerow(find(handles.demag(handles.currentsamplerow) >= demagStarts & handles.demag(handles.currentsamplerow) <= demagEnds));      
           data = [handles.position(selectedDemagRows),handles.demag(selectedDemagRows),handles.ycorr(selectedDemagRows)];
           data = sortrows(data, [2 1]);
           steprownum = length(data)./numSelectedDemags;
           if rem(steprownum, 1) > 1e-6, 
              msgbox('Measured positions for different demag steps are not the same for this sample! ', 'Error message','error'); 
              return 
           end
           data4plot = [handles.position(handles.currentview), reshape(data(:,end), steprownum, numSelectedDemags)];

       else
           data4plot = [handles.position(handles.currentview),handles.ycorr(handles.currentview)];           

       end   
       
       cla(handles.axes2);
       cla(handles.axes3);
       cla(handles.axes4);
       set(handles.axes1, 'Visible','on');
       set(handles.axes2, 'Visible','off');
       set(handles.axes3, 'Visible','off');
       set(handles.axes4, 'Visible','off');
       axes(handles.axes1),update_plot(hObject, handles,data4plot);
       ylabel(' \color[rgb]{0 0.5 0}Ycorr');
              
elseif get(handles.radiobutton24,'Value') == get(handles.radiobutton24,'Max'), % 'Zcorr' Selected
       
       if  get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
           demagStarts       = handles.currentdemags(get(handles.popupmenu4, 'value'));
           demagEnds         = handles.currentdemags(get(handles.popupmenu6, 'value'));
           numSelectedDemags = length(find(handles.currentdemags >= demagStarts & handles.currentdemags <= demagEnds));
           selectedDemagRows = handles.currentsamplerow(find(handles.demag(handles.currentsamplerow) >= demagStarts & handles.demag(handles.currentsamplerow) <= demagEnds));      
           data = [handles.position(selectedDemagRows),handles.demag(selectedDemagRows),handles.zcorr(selectedDemagRows)];
           data = sortrows(data, [2 1]);
           steprownum = length(data)./numSelectedDemags;
           if rem(steprownum, 1) > 1e-6, 
              msgbox('Measured positions for different demag steps are not the same for this sample! ', 'Error message','error'); 
              return 
           end
           data4plot = [handles.position(handles.currentview), reshape(data(:,end), steprownum, numSelectedDemags)];
       else
           data4plot = [handles.position(handles.currentview),handles.zcorr(handles.currentview)]; 
       end   
       
       cla(handles.axes2);
       cla(handles.axes3);
       cla(handles.axes4);
       set(handles.axes1, 'Visible','on');
       set(handles.axes2, 'Visible','off');
       set(handles.axes3, 'Visible','off');
       set(handles.axes4, 'Visible','off');
       axes(handles.axes1),update_plot(hObject, handles,data4plot);
       ylabel(' \color[rgb]{0 0.5 0}Zcorr');
       
end
   
%% [FUNCTION] UPDATE PLOT
function update_plot(hObject, handles, data4plot) 

x = data4plot(:,1);
y = data4plot(:,2:end);

set(gcf,'DefaultAxesColorOrder',[ 0       0      1;              % 1      blue
                                  0       0.5    0;              % 2    dark green
                                  1       0      0;              % 3      red
                                  0.75    0      0.75;           % 4    dark purple
                                  0       0      0;              % 5      black
                                  0       0.75   0.75;           % 6      cyan
                                  0.87    0.49   0;              % 7      orange
                                  0.75    0.75   0;              % 8    yellow green
                                  0       1      0;              % 9      green
                                  0.08    0.17   0.55;           % 10   dark blue
                                  1       1      0;              % 11     yellow
                                  0.6     0.2    0;              % 12   dark orange
                                  1       0      1;              % 13     purple
                                  0.7     0.7    0.7]);          % 14     gray

if get(handles.togglebutton1, 'value') == get(handles.togglebutton1, 'Max'),
   plot(x,y);
else
    if size(y,2)==1,
       plot(x,y,'o-','linewidth',1,'markerfacecolor','w','markersize', 5);
    elseif size(y,2)==3,
       plot(x,y(:,1),'o-',x,y(:,2),'o-',x,y(:,3),'o-','linewidth',1,'markerfacecolor','w','markersize',5);
    end
end

xlabel('Position (cm)');
set(gca,'XMinorTick','on');
set(gca,'YMinorTick','on');
set(gca,'Ticklength',[0.015;0.04]);
xlim([x(1) x(end)]);
box on;
axis tight;
if strcmpi(get(handles.uitoggletool5, 'state'), 'on'), update_legend(hObject, handles); end
if strcmpi(get(handles.uitoggletool6, 'state'), 'on'), grid on; end
if strcmpi(get(handles.uitoggletool7, 'state'), 'on'), hold on; end
if strcmpi(get(handles.uitoggletool10, 'state'), 'on'), 
    title(strcat({'Sample:  '}, handles.samples(handles.SampleIndexNow), {', on Demag Step:  '},...
          num2str(handles.currentdemags(handles.DemagIndexNow))));
else
    title('');
end

%% [FUNCTION] UPDATE PLOT2
function update_plot2(hObject, handles, data4plot)

if size(data4plot,2) == 4,
   step = 1;
else
   step = (size(data4plot,2)-1)/3;
end

axes(handles.axes2),
if step==1, 
   plot(data4plot(:,1),data4plot(:,2:2+step-1),'bo-','markerfacecolor','w','markersize',5);
else
   plot(data4plot(:,1),data4plot(:,2:2+step-1));
end
ylabel('\color{blue}Int');
set(gca,'XMinorTick','on');
set(gca,'YMinorTick','on');
set(gca,'Ticklength',[0.015;0.04]);
set(gca,'xticklabel','');
xlim([data4plot(1,1) data4plot(end,1)]);
box on;
axis tight;
% if strcmpi(get(handles.uitoggletool5, 'state'), 'on'), update_legend(hObject, handles); end
if strcmpi(get(handles.uitoggletool6, 'state'), 'on'), grid on; end
if strcmpi(get(handles.uitoggletool7, 'state'), 'on'), hold on; end
if strcmpi(get(handles.uitoggletool10, 'state'), 'on'), 
    title(strcat({'Sample:  '}, handles.samples(handles.SampleIndexNow), {', on Demag Step:  '},...
          num2str(handles.currentdemags(handles.DemagIndexNow))));
else
    title('');
end

axes(handles.axes3),
if step==1, 
   plot(data4plot(:,1),data4plot(:,2+step:2+step+step-1),'o-','markerfacecolor','w','markersize',5,'color', [0 0.5 0]);
else
   plot(data4plot(:,1),data4plot(:,2+step:2+step+step-1));
end
ylabel('\color[rgb]{0 0.5 0}Decl');
set(gca,'XMinorTick','on');
set(gca,'YMinorTick','on');
set(gca,'Ticklength',[0.015;0.04]);
set(gca,'Ytick',0:60:360);
labelstring = num2cell(0:60:360);
labelstring{1} = ' ';
set(gca, 'Yticklabel', labelstring);
set(gca,'xticklabel','');
xlim([data4plot(1,1) data4plot(end,1)]);
ylim([0 360]);
box on;
% if strcmpi(get(handles.uitoggletool5, 'state'), 'on'), update_legend(hObject, handles); end
if strcmpi(get(handles.uitoggletool6, 'state'), 'on'), grid on; end
if strcmpi(get(handles.uitoggletool7, 'state'), 'on'), hold on; end

axes(handles.axes4),
if step==1, 
   plot(data4plot(:,1),data4plot(:,2+step+step:2+step+step+step-1),'ro-','markerfacecolor','w','markersize',5);
else
   plot(data4plot(:,1),data4plot(:,2+step+step:2+step+step+step-1));
end
ylabel('\color{red}Incl');
set(gca,'XMinorTick','on');
set(gca,'YMinorTick','on');
set(gca,'Ticklength',[0.015;0.04]);
set(gca,'Ytick',-90:30:90);
set(gca, 'Yticklabel', num2cell(-90:30:90));
xlim([data4plot(1,1) data4plot(end,1)]);
ylim([-90 90]);
xlabel('Position (cm)');
box on;
if strcmpi(get(handles.uitoggletool6, 'state'), 'on'), grid on; end
if strcmpi(get(handles.uitoggletool7, 'state'), 'on'), hold on; end

if strcmpi(get(handles.uitoggletool5, 'state'), 'on'), update_legend(hObject, handles); end


%% [FUNCTION] UIGETFILE2
function [filename, pathname, filterindex] = uigetfile2(varargin)

%UIGETFILE2 Standard open file dialog box which remembers last opened folder
%   UIGETFILE2 is a wrapper for Matlab's UIGETFILE function which adds the
%   ability to remember the last folder opened.  UIGETFILE2 stores
%   information about the last folder opened in a mat file which it looks
%   for when called.
%
%   UIGETFILE2 can only remember the folder used if the current directory
%   is writable so that a mat file can be stored.  Only successful file
%   selections update the folder remembered.  If the user cancels the file
%   dialog box then the remembered path is left the same.
%
%   Usage is the same as UIGETFILE.
%
%
%   See also UIGETFILE, UIPUTFILE, UIGETDIR.

%   Written by Chris J Cannell and Aditya Gadre
%   Contact ccannell@mindspring.com for questions or comments.
%   12/05/2005

% name of mat file to save last used directory information
lastDirMat = 'lastUsedDir.mat';

% save the present working directory
savePath = pwd;
% set default dialog open directory to the present working directory
lastDir = savePath;
% load last data directory
if exist(lastDirMat, 'file') ~= 0
    % lastDirMat mat file exists, load it
    load('-mat', lastDirMat)
    % check if lastDataDir variable exists and contains a valid path
    if (exist('lastUsedDir', 'var') == 1) && ...
            (exist(lastUsedDir, 'dir') == 7)
        % set default dialog open directory
        lastDir = lastUsedDir;
    end
end

% load folder to open dialog box in
cd(lastDir);
% call uigetfile with arguments passed from uigetfile2 function
[filename, pathname, filterindex] = uigetfile(varargin{:});
% change path back to original working folder
cd(savePath);

% if the user did not cancel the file dialog then update lastDirMat mat
% file with the folder used
if ~isequal(filename,0) && ~isequal(pathname,0)
    try
        % save last folder used to lastDirMat mat file
        lastUsedDir = pathname;
        save(lastDirMat, 'lastUsedDir');
    catch
        % error saving lastDirMat mat file, display warning, the folder
        % will not be remembered
        disp(['Warning: Could not save file ''', lastDirMat, '''']);
    end
end



%% [RADIOBUTTONS]
function radiobutton16_Callback(hObject, eventdata, handles)

update_data(hObject, handles);

function radiobutton4_Callback(hObject, eventdata, handles)

update_data(hObject, handles);

function radiobutton2_Callback(hObject, eventdata, handles)

update_data(hObject, handles);

function radiobutton3_Callback(hObject, eventdata, handles)

update_data(hObject, handles);

function radiobutton8_Callback(hObject, eventdata, handles)

update_data(hObject, handles);

function radiobutton13_Callback(hObject, eventdata, handles)

update_data(hObject, handles);

function radiobutton14_Callback(hObject, eventdata, handles)

update_data(hObject, handles);


function radiobutton15_Callback(hObject, eventdata, handles)

update_data(hObject, handles);


function radiobutton19_Callback(hObject, eventdata, handles)

update_data(hObject, handles);

function radiobutton22_Callback(hObject, eventdata, handles)

update_data(hObject, handles);

function radiobutton25_Callback(hObject, eventdata, handles)

update_data(hObject, handles);

function radiobutton20_Callback(hObject, eventdata, handles)

update_data(hObject, handles);

function radiobutton23_Callback(hObject, eventdata, handles)

update_data(hObject, handles);


function radiobutton18_Callback(hObject, eventdata, handles)

update_data(hObject, handles);

function radiobutton21_Callback(hObject, eventdata, handles)

update_data(hObject, handles);

function radiobutton24_Callback(hObject, eventdata, handles)

update_data(hObject, handles);


%% [EDIT] 
function edit2_Callback(hObject, eventdata, handles)
function edit2_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function edit3_Callback(hObject, eventdata, handles)
function edit3_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit5_Callback(hObject, eventdata, handles)
function edit5_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function edit8_Callback(hObject, eventdata, handles)
function edit8_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function edit9_Callback(hObject, eventdata, handles)
function edit9_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function edit14_Callback(hObject, eventdata, handles)
function edit14_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit15_Callback(hObject, eventdata, handles)
function edit15_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


%% [MENU] FILE MENU
function FileMenu_Callback(hObject, eventdata, handles)



%% [MENU] OPEN FILE
function OpenFile_Callback(hObject, eventdata, handles)
uipushtool1_ClickedCallback(hObject, eventdata, handles);


%% [MENU] SAVE FJ CORRECTED DATA
function Save_FJC_File_Callback(hObject, eventdata, handles)
pushbutton22_Callback(hObject, eventdata, handles);


%% [MENU] EXPORT *.dir Files
function Export_dir_Callback(hObject, eventdata, handles)
pushbutton25_Callback(hObject, eventdata, handles);


%% [MENU] EXPORT INT
function Export_Int_Callback(hObject, eventdata, handles)
pushbutton24_Callback(hObject, eventdata, handles);


%% [MENU] PLOT MENU
function PlotMenu_Callback(hObject, eventdata, handles)



%% [MENU] VIEW MENU
function View_Menu_Callback(hObject, eventdata, handles)



%% [MENU] TOOLS MENU
function ToolsMenu_Callback(hObject, eventdata, handles)



%% [MENU] UDIR TOOL
function ToolUDIR_Callback(hObject, eventdata, handles)
UDIR;


%% [MENU] UINT TOOL
function ToolsUINT_Callback(hObject, eventdata, handles)
UINT;


%% [MENU] SHOW XMEAN YMEAN ZMEAN
function DataXYZmean_Callback(hObject, eventdata, handles)
set(handles.radiobutton2, 'Value', 1);
update_data(hObject, handles);


%% [MENU] SHOW XCOR YCOR ZCOR
function DataXYZcorr_Callback(hObject, eventdata, handles)
set(handles.radiobutton3, 'Value', 1);
update_data(hObject, handles);


%% [MENU] SHOW XINT YINT ZINT
function DataXYZint_Callback(hObject, eventdata, handles)
set(handles.radiobutton4, 'Value', 1);
update_data(hObject, handles);


%% [MENU] SHOW INT
function DataInt_Callback(hObject, eventdata, handles)
set(handles.radiobutton8, 'Value', 1);
update_data(hObject, handles);


%% [MENU] SHOW INCL
function DataIncl_Callback(hObject, eventdata, handles)
set(handles.radiobutton13, 'Value', 1);
update_data(hObject, handles);


%% [MENU] SHOW DECL
function DataDecl_Callback(hObject, eventdata, handles)
set(handles.radiobutton14, 'Value', 1);
update_data(hObject, handles);


%% [MENU] SHOW INT INCL DECL
function DataIntInclDecl_Callback(hObject, eventdata, handles)
set(handles.radiobutton15, 'Value', 1);
update_data(hObject, handles);


%% [MENU] PREVIOUS SAMPLE
function ViewPreSample_Callback(hObject, eventdata, handles)
pushbutton16_Callback(hObject, eventdata, handles);


%% [MENU] NEXT SAMPLE
function ViewNextSample_Callback(hObject, eventdata, handles)
pushbutton14_Callback(hObject, eventdata, handles);


%% [MENU] PREVIOUS DEMAG STEP
function ViewPreDemag_Callback(hObject, eventdata, handles)
pushbutton3_Callback(hObject, eventdata, handles);


%% [MENU] NEXT DEMAG STEP
function ViewNextDemag_Callback(hObject, eventdata, handles)
pushbutton15_Callback(hObject, eventdata, handles)


%% [MENU] MULTIPLE DEMAG STEP
function MultiDemagStep_Callback(hObject, eventdata, handles)

set(handles.togglebutton1, 'value', 1);
set(handles.edit3,'String','Multiple demag steps');
if    get(handles.radiobutton4,'Value') == get(handles.radiobutton4,'Max')...% 'Xint, Yint, Zint' Selected
   || get(handles.radiobutton2,'Value') == get(handles.radiobutton2,'Max')...% 'Xmean, Ymean, Zmean' Selected
   || get(handles.radiobutton3,'Value') == get(handles.radiobutton3,'Max'),  % 'Xcorr, Ycorr, Zcorr' Selected

   h = msgbox(['This function does not work on ''Xint, Yint, Zint'', ''Xmean, Ymean, Zmean'', or ''Xcorr, Ycorr, Zcorr''.',...
           '''Plot Parameters'' will now be changed to ''Int'''], 'Warning message','warn') ;
   uiwait(h);
   set(handles.radiobutton8, 'value', 1);

end
update_data(hObject, handles);


%% [MENU] LEGEND ON
function PlotLegendOn_Callback(hObject, eventdata, handles)
update_legend(hObject, handles);


%% [MENU] LEGEND OFF
function PlotLegendOff_Callback(hObject, eventdata, handles)

if strcmpi(get(handles.axes1, 'visible'),'on'),
    axes(handles.axes1),legend off;
else
    axes(handles.axes2),legend off;
    axes(handles.axes3),legend off;
    axes(handles.axes4),legend off;
end


%% [MENU] GRID ON
function PlotGridOn_Callback(hObject, eventdata, handles)

if strcmpi(get(handles.axes1, 'visible'),'on'),
    axes(handles.axes1),grid on;
    if strcmpi(get(handles.uitoggletool5, 'state'), 'on'), legend(handles.legendstring); end
else
    axes(handles.axes2),grid on;
    axes(handles.axes3),grid on;
    axes(handles.axes4),grid on;
end


%% [MENU] GRID OFF
function PlotGridOff_Callback(hObject, eventdata, handles)

if strcmpi(get(handles.axes1, 'visible'),'on'),
    axes(handles.axes1),grid off;
    if strcmpi(get(handles.uitoggletool5, 'state'), 'on'), legend(handles.legendstring); end
else
    axes(handles.axes2),grid off;
    axes(handles.axes3),grid off;
    axes(handles.axes4),grid off;
end


%% [MENU] DATACURSOR
function PlotDataCursorOn_Callback(hObject, eventdata, handles)



%% [MENU] EXPORT CURRENT PLOT
function Export_plot_Callback(hObject, eventdata, handles)
pushbutton29_Callback(hObject, eventdata, handles);


%% [MENU] PRINT WHOLE FIGURE
function PrintWholeFigure_Callback(hObject, eventdata, handles)
uipushtool3_ClickedCallback(hObject, eventdata, handles);


%% [MENU] HOLD ON
function PlotHoldOn_Callback(hObject, eventdata, handles)

if strcmpi(get(handles.axes1, 'visible'),'on'),
    axes(handles.axes1),hold on;
    if strcmpi(get(handles.uitoggletool5, 'state'), 'on'), legend(handles.legendstring); end
else
    axes(handles.axes2),hold on;
    axes(handles.axes3),hold on;
    axes(handles.axes4),hold on;
end


%% [Toolbar] LEGEND ON
function uitoggletool5_OnCallback(hObject, eventdata, handles)
update_legend(hObject, handles);


%% [Toolbar] LEGEND OFF
function uitoggletool5_OffCallback(hObject, eventdata, handles)

if strcmpi(get(handles.axes1, 'visible'),'on'),
    axes(handles.axes1),legend off;
else
    axes(handles.axes2),legend off;
    axes(handles.axes3),legend off;
    axes(handles.axes4),legend off;
end


%% [Toolbar] GRID OFF
function uitoggletool6_OffCallback(hObject, eventdata, handles)

if strcmpi(get(handles.axes1, 'visible'),'on'),
    axes(handles.axes1),grid off;
    if strcmpi(get(handles.uitoggletool5, 'state'), 'on'), legend(handles.legendstring); end
else
    axes(handles.axes2),grid off;
    axes(handles.axes3),grid off;
    axes(handles.axes4),grid off;
end


%% [Toolbar] GRID ON
function uitoggletool6_OnCallback(hObject, eventdata, handles)

if strcmpi(get(handles.axes1, 'visible'),'on'),
    axes(handles.axes1),grid on;
    if strcmpi(get(handles.uitoggletool5, 'state'), 'on'), legend(handles.legendstring); end
else
    axes(handles.axes2),grid on;
    axes(handles.axes3),grid on;
    axes(handles.axes4),grid on;
end


function uitoggletool7_ClickedCallback(hObject, eventdata, handles)


%% [Toolbar] HOLD OFF
function uitoggletool7_OffCallback(hObject, eventdata, handles)

if strcmpi(get(handles.axes1, 'visible'),'on'),
    axes(handles.axes1),hold off;
    if strcmpi(get(handles.uitoggletool5, 'state'), 'on'), legend(handles.legendstring); end    
else
    axes(handles.axes2),hold off;
    axes(handles.axes3),hold off;
    axes(handles.axes4),hold off;
end


%% [Toolbar] HOLD On
function uitoggletool7_OnCallback(hObject, eventdata, handles)

if strcmpi(get(handles.axes1, 'visible'),'on'),
    axes(handles.axes1),hold on;
    if strcmpi(get(handles.uitoggletool5, 'state'), 'on'), legend(handles.legendstring); end
else
    axes(handles.axes2),hold on;
    axes(handles.axes3),hold on;
    axes(handles.axes4),hold on;
end


%% [Toolbar] TITLE ON
function uitoggletool10_OnCallback(hObject, eventdata, handles)
if strcmpi(get(handles.axes1, 'visible'),'on'),
    title(handles.axes1,strcat({'Sample:  '}, handles.samples(handles.SampleIndexNow), {', on Demag Step:  '},...
          num2str(handles.currentdemags(handles.DemagIndexNow))));
else
    title(handles.axes2,strcat({'Sample:  '}, handles.samples(handles.SampleIndexNow), {', on Demag Step:  '},...
          num2str(handles.currentdemags(handles.DemagIndexNow))));
end


%% [Toolbar] TITLE OFF
function uitoggletool10_OffCallback(hObject, eventdata, handles)
if strcmpi(get(handles.axes1, 'visible'),'on'),
    title(handles.axes1, '');
else
    title(handles.axes2, '');
end

function uitoggletool10_ClickedCallback(hObject, eventdata, handles)


%% [Toolbar] SAVE
function uipushtool2_ClickedCallback(hObject, eventdata, handles)

H = uview_SaveDataOption_dlg;
uiwait(H);

saveDataOption = getappdata(0, 'saveDataOption');
rmappdata(0, 'saveDataOption');

switch saveDataOption
    case 0    % cancelled, no data for saving
         return;
    case 1    % FJ corrected data
         pushbutton22_Callback(hObject, eventdata, handles);
    case 2    % dir files from this file
         pushbutton25_Callback(hObject, eventdata, handles);
    case 3    % int files from this file
         pushbutton24_Callback(hObject, eventdata, handles);
    case 4    % current plot
         pushbutton29_Callback(hObject, eventdata, handles);       
end


%% [Toolbar] PRINT
function uipushtool3_ClickedCallback(hObject, eventdata, handles)

[filename, pathname] =  uiputfile({  '*.pdf','PDF file (*.pdf)'},...
                        'Print Whole Figure to PDF file',...
                        [handles.pathnamestring,'\UVIEW_Prints.pdf']);

if  ~isequal(filename,0),   
    set(gcf, 'PaperPositionMode', 'auto');
    set(gcf, 'InvertHardCopy', 'off');
    set(gcf, 'PaperType', 'usletter');
    set(gcf, 'PaperOrientation', 'landscape');
    orient rotated; 
    print([pathname,filename], '-loose', '-dpdf', '-r600');
end


%% [Menu] HOLD OFF
function PlotHoldOff_Callback(hObject, eventdata, handles)

if strcmpi(get(handles.axes1, 'visible'),'on'),
    axes(handles.axes1),hold off;
    if strcmpi(get(handles.uitoggletool5, 'state'), 'on'), legend(handles.legendstring); end    
else
    axes(handles.axes2),hold off;
    axes(handles.axes3),hold off;
    axes(handles.axes4),hold off;
end


%% [Menu] TITLE ON
function PlotTitleOn_Callback(hObject, eventdata, handles)
if strcmpi(get(handles.axes1, 'visible'),'on'),
    title(handles.axes1,strcat({'Sample:  '}, handles.samples(handles.SampleIndexNow), {', on Demag Step:  '},...
          num2str(handles.currentdemags(handles.DemagIndexNow))));
else
    title(handles.axes2,strcat({'Sample:  '}, handles.samples(handles.SampleIndexNow), {', on Demag Step:  '},...
          num2str(handles.currentdemags(handles.DemagIndexNow))));
end


%% [Menu] TITLE OFF
function PlotTitleOff_Callback(hObject, eventdata, handles)
if strcmpi(get(handles.axes1, 'visible'),'on'),
    title(handles.axes1, '');
else
    title(handles.axes2, '');
end


%% [Menu] SHOW XMEAN
function DataXmean_Callback(hObject, eventdata, handles)
set(handles.radiobutton16, 'Value', 1);
update_data(hObject, handles);


%% [Menu] SHOW XCOR
function DataXcorr_Callback(hObject, eventdata, handles)
set(handles.radiobutton18, 'Value', 1);
update_data(hObject, handles);


%% [Menu] SHOW XINT
function DataXint_Callback(hObject, eventdata, handles)
set(handles.radiobutton19, 'Value', 1);
update_data(hObject, handles);


%% [Menu] SHOW YMEAN
function DataYmean_Callback(hObject, eventdata, handles)
set(handles.radiobutton20, 'Value', 1);
update_data(hObject, handles);


%% [Menu] SHOW YCOR
function DataYcorr_Callback(hObject, eventdata, handles)
set(handles.radiobutton21, 'Value', 1);
update_data(hObject, handles);


%% [Menu] SHOW YINT
function DataYint_Callback(hObject, eventdata, handles)
set(handles.radiobutton22, 'Value', 1);
update_data(hObject, handles);


%% [Menu] SHOW ZMEAN
function DataZmean_Callback(hObject, eventdata, handles)
set(handles.radiobutton23, 'Value', 1);
update_data(hObject, handles);


%% [Menu] SHOW ZCOR
function DataZcorr_Callback(hObject, eventdata, handles)
set(handles.radiobutton24, 'Value', 1);
update_data(hObject, handles);


%% [Menu] SHOW ZINT
function DataZint_Callback(hObject, eventdata, handles)
set(handles.radiobutton25, 'Value', 1);
update_data(hObject, handles);


%% [Menu] DATA MENU
function Data_Menu_Callback(hObject, eventdata, handles)



%% [Popupmenu] MULTI-DEMAG STARTS
function popupmenu4_Callback(hObject, eventdata, handles)
if get(handles.popupmenu4, 'value') > get(handles.popupmenu6, 'value'),
   h = msgbox('''Demag Start'' cannot be bigger than ''Demag End''', 'Warning message','warn') ;
   uiwait(h);
   set(handles.popupmenu4, 'value',1);
end
   update_data(hObject, handles);

   
function popupmenu4_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


%% [Popupmenu] MULTI-DEMAG ENDS
function popupmenu6_Callback(hObject, eventdata, handles)
if get(handles.popupmenu6, 'value') < get(handles.popupmenu4, 'value'),
   h = msgbox('''Demag End'' cannot be smaller than ''Demag Start''', 'Warning message','warn') ;
   uiwait(h);
   set(handles.popupmenu6, 'value',length(handles.currentdemags));
end
   update_data(hObject, handles);


function popupmenu6_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


